Class: Openlayer::Models::Governance::FrameworkCreateParams::ProjectSelector::Match

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/governance/framework_create_params.rb,
sig/openlayer/models/governance/framework_create_params.rbs

Defined Under Namespace

Modules: Property

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(property:, value:, operator: nil) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::Governance::FrameworkCreateParams::ProjectSelector::Match for more details.

Parameters:



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/openlayer/models/governance/framework_create_params.rb', line 86

class Match < Openlayer::Internal::Type::BaseModel
  # @!attribute property
  #   The project property to match against.
  #
  #   @return [Symbol, Openlayer::Models::Governance::FrameworkCreateParams::ProjectSelector::Match::Property]
  required :property,
           enum: -> { Openlayer::Governance::FrameworkCreateParams::ProjectSelector::Match::Property }

  # @!attribute value
  #   The value to match against. Pass an array to match any of several values, or
  #   `null` to match projects where the property is unset. Omit it for `exists` and
  #   `notExists`.
  #
  #   @return [Object]
  required :value, Openlayer::Internal::Type::Unknown

  # @!attribute operator
  #   How to compare the project property with `value`. One of `equals`, `notEquals`,
  #   `contains`, `notContains`, `startsWith`, `endsWith`, `in`, `notIn`,
  #   `greaterThan`, `greaterThanOrEqual`, `lessThan`, `lessThanOrEqual`,
  #   `equalsIgnoreCase`, `containsIgnoreCase`, `matches`, `exists`, or `notExists`.
  #
  #   @return [String, nil]
  optional :operator, String

  # @!method initialize(property:, value:, operator: nil)
  #   Some parameter documentations has been truncated, see
  #   {Openlayer::Models::Governance::FrameworkCreateParams::ProjectSelector::Match}
  #   for more details.
  #
  #   @param property [Symbol, Openlayer::Models::Governance::FrameworkCreateParams::ProjectSelector::Match::Property] The project property to match against.
  #
  #   @param value [Object] The value to match against. Pass an array to match any of several values, or `nu
  #
  #   @param operator [String] How to compare the project property with `value`. One of `equals`, `notEquals`,

  # The project property to match against.
  #
  # @see Openlayer::Models::Governance::FrameworkCreateParams::ProjectSelector::Match#property
  module Property
    extend Openlayer::Internal::Type::Enum

    TASK_TYPE = :taskType
    RISK_LEVEL = :riskLevel
    RISK_TOTAL_SCORE = :riskTotalScore
    NAME = :name
    OWNER_ID = :ownerId
    MODEL_TYPES = :modelTypes

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#operator ⇒ String?

How to compare the project property with value. One of equals, notEquals, contains, notContains, startsWith, endsWith, in, notIn, greaterThan, greaterThanOrEqual, lessThan, lessThanOrEqual, equalsIgnoreCase, containsIgnoreCase, matches, exists, or notExists.

Parameters:

  • (String)

Returns:

  • (String, nil)


109
# File 'lib/openlayer/models/governance/framework_create_params.rb', line 109

optional :operator, String

#property ⇒ Symbol, Openlayer::Models::Governance::FrameworkCreateParams::ProjectSelector::Match::Property

The project property to match against.

Parameters:

  • value (Openlayer::Models::Governance::FrameworkCreateParams::ProjectSelector::Match::property)

Returns:



91
92
# File 'lib/openlayer/models/governance/framework_create_params.rb', line 91

required :property,
enum: -> { Openlayer::Governance::FrameworkCreateParams::ProjectSelector::Match::Property }

#value ⇒ Object

The value to match against. Pass an array to match any of several values, or null to match projects where the property is unset. Omit it for exists and notExists.

Parameters:

  • value (top)

Returns:

  • (Object)


100
# File 'lib/openlayer/models/governance/framework_create_params.rb', line 100

required :value, Openlayer::Internal::Type::Unknown

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


93
# File 'sig/openlayer/models/governance/framework_create_params.rbs', line 93

def to_hash: -> {