Class: Openlayer::Models::Governance::FrameworkListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openlayer/models/governance/framework_list_params.rb,
sig/openlayer/models/governance/framework_list_params.rbs

Overview

See Also:

  • Openlayer::Resources::Governance::Frameworks#list

Defined Under Namespace

Modules: CompletionOperator, SortColumn

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Openlayer

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, asc: nil, completion_operator: nil, completion_value: nil, enabled: nil, include_rule_stats: nil, page: nil, per_page: nil, project_id: nil, search_query: nil, sort_column: nil, tags: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::Governance::FrameworkListParams for more details.

Parameters:

  • workspace_id (String)
  • asc (Boolean) (defaults to: nil) —

    Whether to sort in ascending order.

  • completion_operator (Symbol, Openlayer::Models::Governance::FrameworkListParams::CompletionOperator) (defaults to: nil) —

    How to compare each framework's completion percentage with completionValue. Mu

  • completion_value (Integer) (defaults to: nil) —

    The completion percentage to compare against, from 0 to 100.

  • enabled (Boolean) (defaults to: nil) —

    Only include frameworks that are enabled (or disabled).

  • include_rule_stats (Boolean) (defaults to: nil) —

    Whether to include a ruleStats object on each framework, with its rule result

  • page (Integer) (defaults to: nil) —

    The page to return in a paginated query.

  • per_page (Integer) (defaults to: nil) —

    Maximum number of items to return per page.

  • project_id (String) (defaults to: nil) —

    Only include items that apply to this project.

  • search_query (String) (defaults to: nil) —

    Filter by a free-text search over names and descriptions.

  • sort_column (Symbol, Openlayer::Models::Governance::FrameworkListParams::SortColumn) (defaults to: nil) —

    The column to sort on.

  • tags (Array<String>) (defaults to: nil) —

    Only include frameworks carrying all of these tags.

  • request_options (Openlayer::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openlayer/models/governance/framework_list_params.rb', line 85

Instance Attribute Details

#asc ⇒ Boolean?

Whether to sort in ascending order.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


20
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 20

optional :asc, Openlayer::Internal::Type::Boolean

#completion_operator ⇒ Symbol, ...

How to compare each framework's completion percentage with completionValue. Must be sent together with completionValue.



27
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 27

optional :completion_operator, enum: -> { Openlayer::Governance::FrameworkListParams::CompletionOperator }

#completion_value ⇒ Integer?

The completion percentage to compare against, from 0 to 100.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


33
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 33

optional :completion_value, Integer

#enabled ⇒ Boolean?

Only include frameworks that are enabled (or disabled).

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


39
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 39

optional :enabled, Openlayer::Internal::Type::Boolean

#include_rule_stats ⇒ Boolean?

Whether to include a ruleStats object on each framework, with its rule result status counts and its per-project completion buckets. Computed over the returned page only.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


47
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 47

optional :include_rule_stats, Openlayer::Internal::Type::Boolean

#page ⇒ Integer?

The page to return in a paginated query.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


53
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 53

optional :page, Integer

#per_page ⇒ Integer?

Maximum number of items to return per page.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


59
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 59

optional :per_page, Integer

#project_id ⇒ String?

Only include items that apply to this project.

Parameters:

  • (String)

Returns:

  • (String, nil)


65
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 65

optional :project_id, String

#search_query ⇒ String?

Filter by a free-text search over names and descriptions.

Parameters:

  • (String)

Returns:

  • (String, nil)


71
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 71

optional :search_query, String

#sort_column ⇒ Symbol, ...

The column to sort on.



77
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 77

optional :sort_column, enum: -> { Openlayer::Governance::FrameworkListParams::SortColumn }

#tags ⇒ Array<String>?

Only include frameworks carrying all of these tags.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


83
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 83

optional :tags, Openlayer::Internal::Type::ArrayOf[String]

#workspace_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openlayer/models/governance/framework_list_params.rb', line 14

required :workspace_id, String

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/governance/framework_list_params.rb', line 127

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


91
# File 'sig/openlayer/models/governance/framework_list_params.rbs', line 91

def to_hash: -> {