Class: Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item
- Defined in:
- lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb,
sig/openlayer/models/governance/framework_list_project_rule_stats_response.rbs
Defined Under Namespace
Classes: ByRuleType
Instance Attribute Summary collapse
-
#by_rule_type ⇒ Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType?
The same counts, broken down by the type of the rule each result belongs to.
-
#project_id ⇒ String
The project id.
-
#project_name ⇒ String
The project name.
-
#task_type ⇒ String
The project's task type.
-
#total ⇒ Integer
The total number of rule results.
-
#total_due_soon ⇒ Integer
The number of rule results whose evidence is about to expire.
-
#total_error ⇒ Integer
The number of rule results that errored during evaluation.
-
#total_failing ⇒ Integer
The number of failing rule results.
-
#total_passing ⇒ Integer
The number of passing rule results.
-
#total_pending ⇒ Integer
The number of rule results that have not been satisfied yet.
-
#total_running ⇒ Integer
The number of rule results currently being evaluated.
-
#total_skipped ⇒ Integer
The number of skipped rule results.
Instance Method Summary collapse
- #initialize(project_id:, project_name:, task_type:, total:, total_due_soon:, total_error:, total_failing:, total_passing:, total_pending:, total_running:, total_skipped:, by_rule_type: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(project_id:, project_name:, task_type:, total:, total_due_soon:, total_error:, total_failing:, total_passing:, total_pending:, total_running:, total_skipped:, by_rule_type: nil) ⇒ Object
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 17 class Item < Openlayer::Internal::Type::BaseModel # @!attribute project_id # The project id. # # @return [String] required :project_id, String, api_name: :projectId # @!attribute project_name # The project name. # # @return [String] required :project_name, String, api_name: :projectName # @!attribute task_type # The project's task type. # # @return [String] required :task_type, String, api_name: :taskType # @!attribute total # The total number of rule results. # # @return [Integer] required :total, Integer # @!attribute total_due_soon # The number of rule results whose evidence is about to expire. # # @return [Integer] required :total_due_soon, Integer, api_name: :totalDueSoon # @!attribute total_error # The number of rule results that errored during evaluation. # # @return [Integer] required :total_error, Integer, api_name: :totalError # @!attribute total_failing # The number of failing rule results. # # @return [Integer] required :total_failing, Integer, api_name: :totalFailing # @!attribute total_passing # The number of passing rule results. # # @return [Integer] required :total_passing, Integer, api_name: :totalPassing # @!attribute total_pending # The number of rule results that have not been satisfied yet. # # @return [Integer] required :total_pending, Integer, api_name: :totalPending # @!attribute total_running # The number of rule results currently being evaluated. # # @return [Integer] required :total_running, Integer, api_name: :totalRunning # @!attribute total_skipped # The number of skipped rule results. # # @return [Integer] required :total_skipped, Integer, api_name: :totalSkipped # @!attribute by_rule_type # The same counts, broken down by the type of the rule each result belongs to. # # @return [Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType, nil] optional :by_rule_type, -> { Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType }, api_name: :byRuleType # @!method initialize(project_id:, project_name:, task_type:, total:, total_due_soon:, total_error:, total_failing:, total_passing:, total_pending:, total_running:, total_skipped:, by_rule_type: nil) # @param project_id [String] The project id. # # @param project_name [String] The project name. # # @param task_type [String] The project's task type. # # @param total [Integer] The total number of rule results. # # @param total_due_soon [Integer] The number of rule results whose evidence is about to expire. # # @param total_error [Integer] The number of rule results that errored during evaluation. # # @param total_failing [Integer] The number of failing rule results. # # @param total_passing [Integer] The number of passing rule results. # # @param total_pending [Integer] The number of rule results that have not been satisfied yet. # # @param total_running [Integer] The number of rule results currently being evaluated. # # @param total_skipped [Integer] The number of skipped rule results. # # @param by_rule_type [Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType] The same counts, broken down by the type of the rule each result belongs to. # @see Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item#by_rule_type class ByRuleType < Openlayer::Internal::Type::BaseModel # @!attribute evidence # # @return [Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType::Evidence, nil] optional :evidence, -> { Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType::Evidence } # @!attribute platform # # @return [Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType::Platform, nil] optional :platform, -> { Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType::Platform } # @!method initialize(evidence: nil, platform: nil) # The same counts, broken down by the type of the rule each result belongs to. # # @param evidence [Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType::Evidence] # @param platform [Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType::Platform] # @see Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType#evidence class Evidence < Openlayer::Internal::Type::BaseModel # @!attribute total # The total number of rule results. # # @return [Integer] required :total, Integer # @!attribute total_due_soon # The number of rule results whose evidence is about to expire. # # @return [Integer] required :total_due_soon, Integer, api_name: :totalDueSoon # @!attribute total_error # The number of rule results that errored during evaluation. # # @return [Integer] required :total_error, Integer, api_name: :totalError # @!attribute total_failing # The number of failing rule results. # # @return [Integer] required :total_failing, Integer, api_name: :totalFailing # @!attribute total_passing # The number of passing rule results. # # @return [Integer] required :total_passing, Integer, api_name: :totalPassing # @!attribute total_pending # The number of rule results that have not been satisfied yet. # # @return [Integer] required :total_pending, Integer, api_name: :totalPending # @!attribute total_running # The number of rule results currently being evaluated. # # @return [Integer] required :total_running, Integer, api_name: :totalRunning # @!attribute total_skipped # The number of skipped rule results. # # @return [Integer] required :total_skipped, Integer, api_name: :totalSkipped # @!method initialize(total:, total_due_soon:, total_error:, total_failing:, total_passing:, total_pending:, total_running:, total_skipped:) # @param total [Integer] The total number of rule results. # # @param total_due_soon [Integer] The number of rule results whose evidence is about to expire. # # @param total_error [Integer] The number of rule results that errored during evaluation. # # @param total_failing [Integer] The number of failing rule results. # # @param total_passing [Integer] The number of passing rule results. # # @param total_pending [Integer] The number of rule results that have not been satisfied yet. # # @param total_running [Integer] The number of rule results currently being evaluated. # # @param total_skipped [Integer] The number of skipped rule results. end # @see Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType#platform class Platform < Openlayer::Internal::Type::BaseModel # @!attribute total # The total number of rule results. # # @return [Integer] required :total, Integer # @!attribute total_due_soon # The number of rule results whose evidence is about to expire. # # @return [Integer] required :total_due_soon, Integer, api_name: :totalDueSoon # @!attribute total_error # The number of rule results that errored during evaluation. # # @return [Integer] required :total_error, Integer, api_name: :totalError # @!attribute total_failing # The number of failing rule results. # # @return [Integer] required :total_failing, Integer, api_name: :totalFailing # @!attribute total_passing # The number of passing rule results. # # @return [Integer] required :total_passing, Integer, api_name: :totalPassing # @!attribute total_pending # The number of rule results that have not been satisfied yet. # # @return [Integer] required :total_pending, Integer, api_name: :totalPending # @!attribute total_running # The number of rule results currently being evaluated. # # @return [Integer] required :total_running, Integer, api_name: :totalRunning # @!attribute total_skipped # The number of skipped rule results. # # @return [Integer] required :total_skipped, Integer, api_name: :totalSkipped # @!method initialize(total:, total_due_soon:, total_error:, total_failing:, total_passing:, total_pending:, total_running:, total_skipped:) # @param total [Integer] The total number of rule results. # # @param total_due_soon [Integer] The number of rule results whose evidence is about to expire. # # @param total_error [Integer] The number of rule results that errored during evaluation. # # @param total_failing [Integer] The number of failing rule results. # # @param total_passing [Integer] The number of passing rule results. # # @param total_pending [Integer] The number of rule results that have not been satisfied yet. # # @param total_running [Integer] The number of rule results currently being evaluated. # # @param total_skipped [Integer] The number of skipped rule results. end end end |
Instance Attribute Details
#by_rule_type ⇒ Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType?
The same counts, broken down by the type of the rule each result belongs to.
88 89 90 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 88 optional :by_rule_type, -> { Openlayer::Models::Governance::FrameworkListProjectRuleStatsResponse::Item::ByRuleType }, api_name: :byRuleType |
#project_id ⇒ String
The project id.
22 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 22 required :project_id, String, api_name: :projectId |
#project_name ⇒ String
The project name.
28 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 28 required :project_name, String, api_name: :projectName |
#task_type ⇒ String
The project's task type.
34 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 34 required :task_type, String, api_name: :taskType |
#total ⇒ Integer
The total number of rule results.
40 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 40 required :total, Integer |
#total_due_soon ⇒ Integer
The number of rule results whose evidence is about to expire.
46 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 46 required :total_due_soon, Integer, api_name: :totalDueSoon |
#total_error ⇒ Integer
The number of rule results that errored during evaluation.
52 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 52 required :total_error, Integer, api_name: :totalError |
#total_failing ⇒ Integer
The number of failing rule results.
58 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 58 required :total_failing, Integer, api_name: :totalFailing |
#total_passing ⇒ Integer
The number of passing rule results.
64 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 64 required :total_passing, Integer, api_name: :totalPassing |
#total_pending ⇒ Integer
The number of rule results that have not been satisfied yet.
70 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 70 required :total_pending, Integer, api_name: :totalPending |
#total_running ⇒ Integer
The number of rule results currently being evaluated.
76 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 76 required :total_running, Integer, api_name: :totalRunning |
#total_skipped ⇒ Integer
The number of skipped rule results.
82 |
# File 'lib/openlayer/models/governance/framework_list_project_rule_stats_response.rb', line 82 required :total_skipped, Integer, api_name: :totalSkipped |
Instance Method Details
#to_hash ⇒ {
80 |
# File 'sig/openlayer/models/governance/framework_list_project_rule_stats_response.rbs', line 80
def to_hash: -> {
|