Class: Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match
- Defined in:
- lib/openlayer/models/governance/framework_list_response.rb,
sig/openlayer/models/governance/framework_list_response.rbs
Defined Under Namespace
Modules: Property
Instance Attribute Summary collapse
-
#operator ⇒ String?
How to compare the project property with
value. -
#property ⇒ Symbol, Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match::Property
The project property to match against.
-
#value ⇒ Object
The value to match against.
Instance Method Summary collapse
-
#initialize(property:, value:, operator: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Match for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(property:, value:, operator: nil) ⇒ Object
Some parameter documentations has been truncated, see Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match for more details.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/openlayer/models/governance/framework_list_response.rb', line 214 class Match < Openlayer::Internal::Type::BaseModel # @!attribute property # The project property to match against. # # @return [Symbol, Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match::Property] required :property, enum: -> { Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match::Property } # @!attribute value # The value to match against. Pass an array to match any of several values, or # `null` to match projects where the property is unset. Omit it for `exists` and # `notExists`. # # @return [Object] required :value, Openlayer::Internal::Type::Unknown # @!attribute operator # How to compare the project property with `value`. One of `equals`, `notEquals`, # `contains`, `notContains`, `startsWith`, `endsWith`, `in`, `notIn`, # `greaterThan`, `greaterThanOrEqual`, `lessThan`, `lessThanOrEqual`, # `equalsIgnoreCase`, `containsIgnoreCase`, `matches`, `exists`, or `notExists`. # # @return [String, nil] optional :operator, String # @!method initialize(property:, value:, operator: nil) # Some parameter documentations has been truncated, see # {Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match} # for more details. # # @param property [Symbol, Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match::Property] The project property to match against. # # @param value [Object] The value to match against. Pass an array to match any of several values, or `nu # # @param operator [String] How to compare the project property with `value`. One of `equals`, `notEquals`, # The project property to match against. # # @see Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match#property module Property extend Openlayer::Internal::Type::Enum TASK_TYPE = :taskType RISK_LEVEL = :riskLevel RISK_TOTAL_SCORE = :riskTotalScore NAME = :name OWNER_ID = :ownerId MODEL_TYPES = :modelTypes # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#operator ⇒ String?
How to compare the project property with value. One of equals, notEquals,
contains, notContains, startsWith, endsWith, in, notIn,
greaterThan, greaterThanOrEqual, lessThan, lessThanOrEqual,
equalsIgnoreCase, containsIgnoreCase, matches, exists, or notExists.
237 |
# File 'lib/openlayer/models/governance/framework_list_response.rb', line 237 optional :operator, String |
#property ⇒ Symbol, Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match::Property
The project property to match against.
219 220 |
# File 'lib/openlayer/models/governance/framework_list_response.rb', line 219 required :property, enum: -> { Openlayer::Models::Governance::FrameworkListResponse::Item::ProjectSelector::Match::Property } |
#value ⇒ Object
The value to match against. Pass an array to match any of several values, or
null to match projects where the property is unset. Omit it for exists and
notExists.
228 |
# File 'lib/openlayer/models/governance/framework_list_response.rb', line 228 required :value, Openlayer::Internal::Type::Unknown |
Instance Method Details
#to_hash ⇒ {
189 |
# File 'sig/openlayer/models/governance/framework_list_response.rbs', line 189
def to_hash: -> {
|