Class: Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Framework

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/governance/framework_list_rules_response.rb,
sig/openlayer/models/governance/framework_list_rules_response.rbs

Defined Under Namespace

Classes: Avatar

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, avatar:, built_in_slug:, enabled:, name:) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Framework for more details.

`iso_

Parameters:

  • id (String) —

    The framework id.

  • avatar (Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Framework::Avatar, nil) —

    The icon shown for the framework.

  • built_in_slug (String, nil) —

    Identifies a framework that ships with Openlayer, for example eu_ai_act,

  • enabled (Boolean) —

    Whether the framework is active. Rules of a disabled framework are not evaluated

  • name (String) —

    The framework name.



# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 278

Instance Attribute Details

#avatar ⇒ Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Framework::Avatar?

The icon shown for the framework.



245
246
247
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 245

required :avatar,
-> { Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Framework::Avatar },
nil?: true

#built_in_slug ⇒ String?

Identifies a framework that ships with Openlayer, for example eu_ai_act, iso_42001, nist_ai_rmf, or traiga. null for frameworks you create yourself.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


255
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 255

required :built_in_slug, String, api_name: :builtInSlug, nil?: true

#enabled ⇒ Boolean

Whether the framework is active. Rules of a disabled framework are not evaluated and do not count towards compliance.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


262
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 262

required :enabled, Openlayer::Internal::Type::Boolean

#id ⇒ String

Returns the value of attribute id.

Returns:

  • (String)


193
194
195
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 193

def id
  @id
end

#name ⇒ String

The framework name.

Parameters:

  • value (String)

Returns:

  • (String)


268
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 268

required :name, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


203
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 203

def to_hash: -> {