Class: Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result
- Defined in:
- lib/openlayer/models/governance/framework_list_rules_response.rb,
sig/openlayer/models/governance/framework_list_rules_response.rbs
Defined Under Namespace
Modules: Status Classes: BlockedBy, Blocking
Instance Attribute Summary collapse
-
#assignee_id ⇒ String?
The user responsible for this result.
-
#blocked_by ⇒ Array<Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result::BlockedBy>?
Rule results that must pass before this one can be satisfied.
-
#blocking ⇒ Array<Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result::Blocking>?
Rule results that this one blocks.
-
#date_created ⇒ Time
Returns the value of attribute date_created.
-
#date_last_evaluated ⇒ Time?
Returns the value of attribute date_last_evaluated.
-
#date_of_latest_evidence ⇒ Time?
Returns the value of attribute date_of_latest_evidence.
-
#date_of_next_evaluation ⇒ Time?
Returns the value of attribute date_of_next_evaluation.
-
#date_of_renewal ⇒ Time?
Returns the value of attribute date_of_renewal.
-
#date_updated ⇒ Time
Returns the value of attribute date_updated.
-
#deactivated ⇒ Boolean
Whether this result is excluded from compliance calculations.
-
#deactivated_reason ⇒ String?
Why the result was excluded.
-
#id ⇒ String
Returns the value of attribute id.
-
#project_id ⇒ String?
Returns the value of attribute project_id.
-
#rule_id ⇒ String
Returns the value of attribute rule_id.
-
#status ⇒ Symbol, Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result::Status
The compliance status of the rule for this entity.
-
#status_message ⇒ String?
A human-readable explanation of the status.
-
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, date_created:, date_updated:, deactivated:, rule_id:, status:, workspace_id:, assignee_id: nil, blocked_by: nil, blocking: nil, date_last_evaluated: nil, date_of_latest_evidence: nil, date_of_next_evaluation: nil, date_of_renewal: nil, deactivated_reason: nil, project_id: nil, status_message: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, date_created:, date_updated:, deactivated:, rule_id:, status:, workspace_id:, assignee_id: nil, blocked_by: nil, blocking: nil, date_last_evaluated: nil, date_of_latest_evidence: nil, date_of_next_evaluation: nil, date_of_renewal: nil, deactivated_reason: nil, project_id: nil, status_message: nil) ⇒ Object
|
|
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 436
|
Instance Attribute Details
#assignee_id ⇒ String?
The user responsible for this result.
345 |
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 345 optional :assignee_id, String, api_name: :assigneeId, nil?: true |
#blocked_by ⇒ Array<Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result::BlockedBy>?
Rule results that must pass before this one can be satisfied.
351 352 353 |
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 351 optional :blocked_by, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result::BlockedBy] }, api_name: :blockedBy |
#blocking ⇒ Array<Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result::Blocking>?
Rule results that this one blocks.
359 360 |
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 359 optional :blocking, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result::Blocking] } |
#date_created ⇒ Time
Returns the value of attribute date_created.
292 293 294 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 292 def date_created @date_created end |
#date_last_evaluated ⇒ Time?
Returns the value of attribute date_last_evaluated.
300 301 302 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 300 def date_last_evaluated @date_last_evaluated end |
#date_of_latest_evidence ⇒ Time?
Returns the value of attribute date_of_latest_evidence.
302 303 304 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 302 def date_of_latest_evidence @date_of_latest_evidence end |
#date_of_next_evaluation ⇒ Time?
Returns the value of attribute date_of_next_evaluation.
304 305 306 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 304 def date_of_next_evaluation @date_of_next_evaluation end |
#date_of_renewal ⇒ Time?
Returns the value of attribute date_of_renewal.
306 307 308 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 306 def date_of_renewal @date_of_renewal end |
#date_updated ⇒ Time
Returns the value of attribute date_updated.
294 295 296 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 294 def date_updated @date_updated end |
#deactivated ⇒ Boolean
Whether this result is excluded from compliance calculations.
332 |
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 332 required :deactivated, Openlayer::Internal::Type::Boolean |
#deactivated_reason ⇒ String?
Why the result was excluded.
366 |
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 366 optional :deactivated_reason, String, api_name: :deactivatedReason, nil?: true |
#id ⇒ String
Returns the value of attribute id.
290 291 292 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 290 def id @id end |
#project_id ⇒ String?
Returns the value of attribute project_id.
308 309 310 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 308 def project_id @project_id end |
#rule_id ⇒ String
Returns the value of attribute rule_id.
296 297 298 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 296 def rule_id @rule_id end |
#status ⇒ Symbol, Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result::Status
The compliance status of the rule for this entity.
338 339 |
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 338 required :status, enum: -> { Openlayer::Models::Governance::FrameworkListRulesResponse::Item::Result::Status } |
#status_message ⇒ String?
A human-readable explanation of the status.
372 |
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 372 optional :status_message, String, api_name: :statusMessage, nil?: true |
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
298 299 300 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 298 def workspace_id @workspace_id end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/governance/framework_list_rules_response.rb', line 485
|
Instance Method Details
#to_hash ⇒ {
330 |
# File 'sig/openlayer/models/governance/framework_list_rules_response.rbs', line 330
def to_hash: -> {
|