Class: Openlayer::Models::Governance::FrameworkUpdateParams::ProjectSelector::Match

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/governance/framework_update_params.rb,
sig/openlayer/models/governance/framework_update_params.rbs

Defined Under Namespace

Modules: Property

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(property:, value:, operator: nil) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::Governance::FrameworkUpdateParams::ProjectSelector::Match for more details.

Parameters:



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/openlayer/models/governance/framework_update_params.rb', line 143

class Match < Openlayer::Internal::Type::BaseModel
  # @!attribute property
  #   The project property to match against.
  #
  #   @return [Symbol, Openlayer::Models::Governance::FrameworkUpdateParams::ProjectSelector::Match::Property]
  required :property,
           enum: -> { Openlayer::Governance::FrameworkUpdateParams::ProjectSelector::Match::Property }

  # @!attribute value
  #   The value to match against. Pass an array to match any of several values, or
  #   `null` to match projects where the property is unset. Omit it for `exists` and
  #   `notExists`.
  #
  #   @return [Object]
  required :value, Openlayer::Internal::Type::Unknown

  # @!attribute operator
  #   How to compare the project property with `value`. One of `equals`, `notEquals`,
  #   `contains`, `notContains`, `startsWith`, `endsWith`, `in`, `notIn`,
  #   `greaterThan`, `greaterThanOrEqual`, `lessThan`, `lessThanOrEqual`,
  #   `equalsIgnoreCase`, `containsIgnoreCase`, `matches`, `exists`, or `notExists`.
  #
  #   @return [String, nil]
  optional :operator, String

  # @!method initialize(property:, value:, operator: nil)
  #   Some parameter documentations has been truncated, see
  #   {Openlayer::Models::Governance::FrameworkUpdateParams::ProjectSelector::Match}
  #   for more details.
  #
  #   @param property [Symbol, Openlayer::Models::Governance::FrameworkUpdateParams::ProjectSelector::Match::Property] The project property to match against.
  #
  #   @param value [Object] The value to match against. Pass an array to match any of several values, or `nu
  #
  #   @param operator [String] How to compare the project property with `value`. One of `equals`, `notEquals`,

  # The project property to match against.
  #
  # @see Openlayer::Models::Governance::FrameworkUpdateParams::ProjectSelector::Match#property
  module Property
    extend Openlayer::Internal::Type::Enum

    TASK_TYPE = :taskType
    RISK_LEVEL = :riskLevel
    RISK_TOTAL_SCORE = :riskTotalScore
    NAME = :name
    OWNER_ID = :ownerId
    MODEL_TYPES = :modelTypes

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#operator ⇒ String?

How to compare the project property with value. One of equals, notEquals, contains, notContains, startsWith, endsWith, in, notIn, greaterThan, greaterThanOrEqual, lessThan, lessThanOrEqual, equalsIgnoreCase, containsIgnoreCase, matches, exists, or notExists.

Parameters:

  • (String)

Returns:

  • (String, nil)


166
# File 'lib/openlayer/models/governance/framework_update_params.rb', line 166

optional :operator, String

#property ⇒ Symbol, Openlayer::Models::Governance::FrameworkUpdateParams::ProjectSelector::Match::Property

The project property to match against.

Parameters:

  • value (Openlayer::Models::Governance::FrameworkUpdateParams::ProjectSelector::Match::property)

Returns:



148
149
# File 'lib/openlayer/models/governance/framework_update_params.rb', line 148

required :property,
enum: -> { Openlayer::Governance::FrameworkUpdateParams::ProjectSelector::Match::Property }

#value ⇒ Object

The value to match against. Pass an array to match any of several values, or null to match projects where the property is unset. Omit it for exists and notExists.

Parameters:

  • value (top)

Returns:

  • (Object)


157
# File 'lib/openlayer/models/governance/framework_update_params.rb', line 157

required :value, Openlayer::Internal::Type::Unknown

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


144
# File 'sig/openlayer/models/governance/framework_update_params.rbs', line 144

def to_hash: -> {