Class: Openlayer::Models::Governance::FrameworkUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::FrameworkUpdateResponse
- Defined in:
- lib/openlayer/models/governance/framework_update_response.rb,
sig/openlayer/models/governance/framework_update_response.rbs
Overview
Defined Under Namespace
Classes: Avatar, ProjectSelector, RuleStats
Instance Attribute Summary collapse
-
#avatar ⇒ Openlayer::Models::Governance::FrameworkUpdateResponse::Avatar?
The icon shown for the framework.
-
#built_in_slug ⇒ String?
Identifies a framework that ships with Openlayer, for example
eu_ai_act,iso_42001,nist_ai_rmf, ortraiga. -
#creator_id ⇒ String?
Returns the value of attribute creator_id.
-
#date_created ⇒ Time
Returns the value of attribute date_created.
-
#date_updated ⇒ Time
Returns the value of attribute date_updated.
-
#description ⇒ String?
A short description of the framework.
-
#enabled ⇒ Boolean
Whether the framework is active.
-
#extended_description ⇒ Hash{Symbol=>Object}?
A longer, rich-text description, as a TipTap JSON document.
-
#href ⇒ String?
A link to the external standard or regulation the framework is based on.
-
#id ⇒ String
Returns the value of attribute id.
-
#immutable ⇒ Boolean?
readonly
Returns the value of attribute immutable.
-
#name ⇒ String
The framework name.
-
#project_selector ⇒ Openlayer::Models::Governance::FrameworkUpdateResponse::ProjectSelector?
Determines which projects the framework applies to.
-
#rule_stats ⇒ Openlayer::Models::Governance::FrameworkUpdateResponse::RuleStats?
readonly
Returns the value of attribute rule_stats.
-
#tags ⇒ Array<String>
Free-form labels on the framework.
-
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
Class Method Summary collapse
Instance Method Summary collapse
- #immutable ⇒ Boolean readonly
-
#initialize(id:, date_created:, date_updated:, enabled:, name:, tags:, workspace_id:, avatar: nil, built_in_slug: nil, creator_id: nil, description: nil, extended_description: nil, href: nil, immutable: nil, project_selector: nil, rule_stats: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see FrameworkUpdateResponse for more details.
- #rule_stats ⇒ Object readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, date_created:, date_updated:, enabled:, name:, tags:, workspace_id:, avatar: nil, built_in_slug: nil, creator_id: nil, description: nil, extended_description: nil, href: nil, immutable: nil, project_selector: nil, rule_stats: nil) ⇒ Object
Some parameter documentations has been truncated, see Openlayer::Models::Governance::FrameworkUpdateResponse for more details.
`iso_
|
|
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 120
|
Instance Attribute Details
#avatar ⇒ Openlayer::Models::Governance::FrameworkUpdateResponse::Avatar?
The icon shown for the framework.
31 |
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 31 optional :avatar, -> { Openlayer::Models::Governance::FrameworkUpdateResponse::Avatar }, nil?: true |
#built_in_slug ⇒ String?
Identifies a framework that ships with Openlayer, for example eu_ai_act,
iso_42001, nist_ai_rmf, or traiga. null for frameworks you create
yourself.
39 |
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 39 optional :built_in_slug, String, api_name: :builtInSlug, nil?: true |
#creator_id ⇒ String?
Returns the value of attribute creator_id.
51 52 53 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 51 def creator_id @creator_id end |
#date_created ⇒ Time
Returns the value of attribute date_created.
45 46 47 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 45 def date_created @date_created end |
#date_updated ⇒ Time
Returns the value of attribute date_updated.
47 48 49 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 47 def date_updated @date_updated end |
#description ⇒ String?
A short description of the framework.
45 |
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 45 optional :description, String, nil?: true |
#enabled ⇒ Boolean
Whether the framework is active. Rules of a disabled framework are not evaluated and do not count towards compliance.
13 |
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 13 required :enabled, Openlayer::Internal::Type::Boolean |
#extended_description ⇒ Hash{Symbol=>Object}?
A longer, rich-text description, as a TipTap JSON document.
51 52 53 54 |
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 51 optional :extended_description, Openlayer::Internal::Type::HashOf[Openlayer::Internal::Type::Unknown], api_name: :extendedDescription, nil?: true |
#href ⇒ String?
A link to the external standard or regulation the framework is based on.
60 |
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 60 optional :href, String, nil?: true |
#id ⇒ String
Returns the value of attribute id.
43 44 45 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 43 def id @id end |
#immutable ⇒ Boolean? (readonly)
Returns the value of attribute immutable.
53 54 55 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 53 def immutable @immutable end |
#name ⇒ String
The framework name.
19 |
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 19 required :name, String |
#project_selector ⇒ Openlayer::Models::Governance::FrameworkUpdateResponse::ProjectSelector?
Determines which projects the framework applies to. An empty or null match
array applies the framework to every project in the workspace.
67 68 69 70 |
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 67 optional :project_selector, -> { Openlayer::Models::Governance::FrameworkUpdateResponse::ProjectSelector }, api_name: :projectSelector, nil?: true |
#rule_stats ⇒ Openlayer::Models::Governance::FrameworkUpdateResponse::RuleStats? (readonly)
Returns the value of attribute rule_stats.
57 58 59 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 57 def rule_stats @rule_stats end |
#tags ⇒ Array<String>
Free-form labels on the framework.
25 |
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 25 required :tags, Openlayer::Internal::Type::ArrayOf[String] |
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
49 50 51 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 49 def workspace_id @workspace_id end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/governance/framework_update_response.rb', line 183
|
Instance Method Details
#immutable= ⇒ Boolean (readonly)
55 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 55
def immutable=: (bool) -> bool
|
#rule_stats= ⇒ Object (readonly)
59 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 59
def rule_stats=: (
|
#to_hash ⇒ {
82 |
# File 'sig/openlayer/models/governance/framework_update_response.rbs', line 82
def to_hash: -> {
|