Class: Openlayer::Models::Governance::Frameworks::DocumentListResponse::Item::Section::Subsection

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openlayer/models/governance/frameworks/document_list_response.rb,
sig/openlayer/models/governance/frameworks/document_list_response.rbs

Defined Under Namespace

Classes: Rule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



287
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 287

def initialize: (

Instance Attribute Details

#id ⇒ String

Returns the value of attribute id.

Returns:

  • (String)


273
274
275
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 273

def id
  @id
end

#number ⇒ String

The subsection number as it appears in the source standard.

Parameters:

  • value (String)

Returns:

  • (String)


333
# File 'lib/openlayer/models/governance/frameworks/document_list_response.rb', line 333

required :number, String

#rule_count ⇒ Integer? (readonly)

Returns the value of attribute rule_count.

Returns:

  • (Integer, nil)


277
278
279
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 277

def rule_count
  @rule_count
end

#rules ⇒ ::Array[Openlayer::Models::Governance::Frameworks::DocumentListResponse::Item::Section::Subsection::Rule]? (readonly)

Returns the value of attribute rules.



281
282
283
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 281

def rules
  @rules
end

#section_id ⇒ String

Returns the value of attribute section_id.

Returns:

  • (String)


275
276
277
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 275

def section_id
  @section_id
end

#sort_order ⇒ Integer

The position of the subsection within its section.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


339
# File 'lib/openlayer/models/governance/frameworks/document_list_response.rb', line 339

required :sort_order, Integer, api_name: :sortOrder

#text ⇒ String?

The subsection text. This is the requirement your rules are mapped against.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


351
# File 'lib/openlayer/models/governance/frameworks/document_list_response.rb', line 351

optional :text, String, nil?: true

#title ⇒ String

The subsection title.

Parameters:

  • value (String)

Returns:

  • (String)


345
# File 'lib/openlayer/models/governance/frameworks/document_list_response.rb', line 345

required :title, String

Instance Method Details

#rule_count= ⇒ Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


279
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 279

def rule_count=: (Integer) -> Integer

#rules= ⇒ Object (readonly)



283
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 283

def rules=: (

#to_hash ⇒ {

Returns:

  • ({)


298
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 298

def to_hash: -> {