Class: Openlayer::Models::Governance::Frameworks::DocumentRetrieveResponse::Section::Subsection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/governance/frameworks/document_retrieve_response.rb,
sig/openlayer/models/governance/frameworks/document_retrieve_response.rbs

Defined Under Namespace

Classes: Rule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



271
# File 'sig/openlayer/models/governance/frameworks/document_retrieve_response.rbs', line 271

def initialize: (

Instance Attribute Details

#id ⇒ String

Returns the value of attribute id.

Returns:

  • (String)


257
258
259
# File 'sig/openlayer/models/governance/frameworks/document_retrieve_response.rbs', line 257

def id
  @id
end

#number ⇒ String

The subsection number as it appears in the source standard.

Parameters:

  • value (String)

Returns:

  • (String)


323
# File 'lib/openlayer/models/governance/frameworks/document_retrieve_response.rb', line 323

required :number, String

#rule_count ⇒ Integer? (readonly)

Returns the value of attribute rule_count.

Returns:

  • (Integer, nil)


261
262
263
# File 'sig/openlayer/models/governance/frameworks/document_retrieve_response.rbs', line 261

def rule_count
  @rule_count
end

#rules ⇒ ::Array[Openlayer::Models::Governance::Frameworks::DocumentRetrieveResponse::Section::Subsection::Rule]? (readonly)

Returns the value of attribute rules.



265
266
267
# File 'sig/openlayer/models/governance/frameworks/document_retrieve_response.rbs', line 265

def rules
  @rules
end

#section_id ⇒ String

Returns the value of attribute section_id.

Returns:

  • (String)


259
260
261
# File 'sig/openlayer/models/governance/frameworks/document_retrieve_response.rbs', line 259

def section_id
  @section_id
end

#sort_order ⇒ Integer

The position of the subsection within its section.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


329
# File 'lib/openlayer/models/governance/frameworks/document_retrieve_response.rb', line 329

required :sort_order, Integer, api_name: :sortOrder

#text ⇒ String?

The subsection text. This is the requirement your rules are mapped against.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


341
# File 'lib/openlayer/models/governance/frameworks/document_retrieve_response.rb', line 341

optional :text, String, nil?: true

#title ⇒ String

The subsection title.

Parameters:

  • value (String)

Returns:

  • (String)


335
# File 'lib/openlayer/models/governance/frameworks/document_retrieve_response.rb', line 335

required :title, String

Instance Method Details

#rule_count= ⇒ Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


263
# File 'sig/openlayer/models/governance/frameworks/document_retrieve_response.rbs', line 263

def rule_count=: (Integer) -> Integer

#rules= ⇒ Object (readonly)



267
# File 'sig/openlayer/models/governance/frameworks/document_retrieve_response.rbs', line 267

def rules=: (

#to_hash ⇒ {

Returns:

  • ({)


282
# File 'sig/openlayer/models/governance/frameworks/document_retrieve_response.rbs', line 282

def to_hash: -> {