Class: Openlayer::Models::Governance::Frameworks::SectionListRulesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::Frameworks::SectionListRulesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openlayer/models/governance/frameworks/section_list_rules_params.rb,
sig/openlayer/models/governance/frameworks/section_list_rules_params.rbs
Overview
Defined Under Namespace
Modules: Status
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Openlayer
Instance Attribute Summary collapse
- #framework_id ⇒ String
-
#include_results ⇒ Boolean?
Whether to include each rule's results inline, in a
resultsarray. -
#include_subsection_rules ⇒ Boolean?
Whether to also include the rules mapped to the section's subsections.
-
#page ⇒ Integer?
The page to return in a paginated query.
-
#per_page ⇒ Integer?
Maximum number of items to return per page.
-
#project_id ⇒ String?
Only include items that apply to this project.
- #section_id ⇒ String
-
#status ⇒ Symbol, ...
Only include items whose rule result has this compliance status.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(framework_id:, section_id:, include_results: nil, include_subsection_rules: nil, page: nil, per_page: nil, project_id: nil, status: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(framework_id:, section_id:, include_results: nil, include_subsection_rules: nil, page: nil, per_page: nil, project_id: nil, status: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/openlayer/models/governance/frameworks/section_list_rules_params.rb', line 58
|
Instance Attribute Details
#framework_id ⇒ String
15 |
# File 'lib/openlayer/models/governance/frameworks/section_list_rules_params.rb', line 15 required :framework_id, String |
#include_results ⇒ Boolean?
Whether to include each rule's results inline, in a results array.
26 |
# File 'lib/openlayer/models/governance/frameworks/section_list_rules_params.rb', line 26 optional :include_results, Openlayer::Internal::Type::Boolean |
#include_subsection_rules ⇒ Boolean?
Whether to also include the rules mapped to the section's subsections.
32 |
# File 'lib/openlayer/models/governance/frameworks/section_list_rules_params.rb', line 32 optional :include_subsection_rules, Openlayer::Internal::Type::Boolean |
#page ⇒ Integer?
The page to return in a paginated query.
38 |
# File 'lib/openlayer/models/governance/frameworks/section_list_rules_params.rb', line 38 optional :page, Integer |
#per_page ⇒ Integer?
Maximum number of items to return per page.
44 |
# File 'lib/openlayer/models/governance/frameworks/section_list_rules_params.rb', line 44 optional :per_page, Integer |
#project_id ⇒ String?
Only include items that apply to this project.
50 |
# File 'lib/openlayer/models/governance/frameworks/section_list_rules_params.rb', line 50 optional :project_id, String |
#section_id ⇒ String
20 |
# File 'lib/openlayer/models/governance/frameworks/section_list_rules_params.rb', line 20 required :section_id, String |
#status ⇒ Symbol, ...
Only include items whose rule result has this compliance status.
56 |
# File 'lib/openlayer/models/governance/frameworks/section_list_rules_params.rb', line 56 optional :status, enum: -> { Openlayer::Governance::Frameworks::SectionListRulesParams::Status } |
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/openlayer/models/governance/frameworks/section_list_rules_params.rbs', line 64
def to_hash: -> {
|