Class: Openlayer::Models::Governance::RuleCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleCreateResponse
- Defined in:
- lib/openlayer/models/governance/rule_create_response.rb,
sig/openlayer/models/governance/rule_create_response.rbs
Overview
Defined Under Namespace
Modules: EvidenceType, Scope, Type Classes: Framework, Result, ResultsSummary, Tag
Instance Attribute Summary collapse
-
#assignee_id ⇒ String?
The user responsible for satisfying the rule.
-
#automation_params ⇒ Hash{Symbol=>Object}?
Configuration for the platform check, when the automation takes parameters.
-
#automation_type ⇒ String?
Which workspace signal a platform rule checks, for example
monitoring_mode_enabled,test_setup, orproject_owner_set. -
#date_created ⇒ Time
Returns the value of attribute date_created.
-
#date_updated ⇒ Time
Returns the value of attribute date_updated.
-
#deactivated ⇒ Boolean?
Whether the rule is excluded from compliance calculations.
-
#description ⇒ String?
What the rule requires.
-
#evidence_type ⇒ Symbol, ...
The kind of evidence that satisfies the rule.
-
#frameworks ⇒ ::Array[Openlayer::Models::Governance::RuleCreateResponse::Framework]?
readonly
Returns the value of attribute frameworks.
-
#id ⇒ String
Returns the value of attribute id.
-
#immutable ⇒ Boolean?
readonly
Returns the value of attribute immutable.
-
#name ⇒ String
The rule name.
-
#renewal_cadence_days ⇒ Integer?
How often evidence must be renewed, in days.
-
#results ⇒ ::Array[Openlayer::Models::Governance::RuleCreateResponse::Result]?
readonly
Returns the value of attribute results.
-
#results_summary ⇒ Openlayer::Models::Governance::RuleCreateResponse::ResultsSummary?
Returns the value of attribute results_summary.
-
#scope ⇒ Symbol, Openlayer::Models::Governance::RuleCreateResponse::Scope
Whether the rule is evaluated once for the whole workspace, or once per project the rule's frameworks apply to.
-
#tags ⇒ ::Array[Openlayer::Models::Governance::RuleCreateResponse::Tag]?
Returns the value of attribute tags.
-
#type ⇒ Symbol, Openlayer::Models::Governance::RuleCreateResponse::Type
platformrules are evaluated automatically from the state of your Openlayer workspace. -
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
Class Method Summary collapse
Instance Method Summary collapse
- #frameworks ⇒ Object readonly
- #immutable ⇒ Boolean readonly
-
#initialize(passing: nil, total: nil) ⇒ Object
constructor
Pass-rate counts across all of the rule's entities, independent of any status filter applied to the request.
- #results ⇒ Object readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(passing: nil, total: nil) ⇒ Object
Pass-rate counts across all of the rule's entities, independent of any status filter applied to the request.
|
|
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 144
|
Instance Attribute Details
#assignee_id ⇒ String?
The user responsible for satisfying the rule.
32 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 32 optional :assignee_id, String, api_name: :assigneeId, nil?: true |
#automation_params ⇒ Hash{Symbol=>Object}?
Configuration for the platform check, when the automation takes parameters.
38 39 40 41 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 38 optional :automation_params, Openlayer::Internal::Type::HashOf[Openlayer::Internal::Type::Unknown], api_name: :automationParams, nil?: true |
#automation_type ⇒ String?
Which workspace signal a platform rule checks, for example
monitoring_mode_enabled, test_setup, or project_owner_set. null for
evidence rules.
49 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 49 optional :automation_type, String, api_name: :automationType, nil?: true |
#date_created ⇒ Time
Returns the value of attribute date_created.
53 54 55 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 53 def date_created @date_created end |
#date_updated ⇒ Time
Returns the value of attribute date_updated.
55 56 57 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 55 def date_updated @date_updated end |
#deactivated ⇒ Boolean?
Whether the rule is excluded from compliance calculations.
55 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 55 optional :deactivated, Openlayer::Internal::Type::Boolean |
#description ⇒ String?
What the rule requires.
61 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 61 optional :description, String, nil?: true |
#evidence_type ⇒ Symbol, ...
The kind of evidence that satisfies the rule. null for platform rules.
67 68 69 70 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 67 optional :evidence_type, enum: -> { Openlayer::Models::Governance::RuleCreateResponse::EvidenceType }, api_name: :evidenceType, nil?: true |
#frameworks ⇒ ::Array[Openlayer::Models::Governance::RuleCreateResponse::Framework]? (readonly)
Returns the value of attribute frameworks.
59 60 61 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 59 def frameworks @frameworks end |
#id ⇒ String
Returns the value of attribute id.
51 52 53 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 51 def id @id end |
#immutable ⇒ Boolean? (readonly)
Returns the value of attribute immutable.
65 66 67 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 65 def immutable @immutable end |
#name ⇒ String
The rule name.
12 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 12 required :name, String |
#renewal_cadence_days ⇒ Integer?
How often evidence must be renewed, in days. Once evidence is older than this,
the rule result becomes due_soon and then failing.
77 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 77 optional :renewal_cadence_days, Integer, api_name: :renewalCadenceDays, nil?: true |
#results ⇒ ::Array[Openlayer::Models::Governance::RuleCreateResponse::Result]? (readonly)
Returns the value of attribute results.
69 70 71 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 69 def results @results end |
#results_summary ⇒ Openlayer::Models::Governance::RuleCreateResponse::ResultsSummary?
Returns the value of attribute results_summary.
75 76 77 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 75 def results_summary @results_summary end |
#scope ⇒ Symbol, Openlayer::Models::Governance::RuleCreateResponse::Scope
Whether the rule is evaluated once for the whole workspace, or once per project the rule's frameworks apply to.
19 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 19 required :scope, enum: -> { Openlayer::Models::Governance::RuleCreateResponse::Scope } |
#tags ⇒ ::Array[Openlayer::Models::Governance::RuleCreateResponse::Tag]?
Returns the value of attribute tags.
77 78 79 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 77 def @tags end |
#type ⇒ Symbol, Openlayer::Models::Governance::RuleCreateResponse::Type
platform rules are evaluated automatically from the state of your Openlayer
workspace. evidence rules are satisfied by attaching evidence.
26 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 26 required :type, enum: -> { Openlayer::Models::Governance::RuleCreateResponse::Type } |
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
57 58 59 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 57 def workspace_id @workspace_id end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 196
|
Instance Method Details
#frameworks= ⇒ Object (readonly)
61 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 61
def frameworks=: (
|
#immutable= ⇒ Boolean (readonly)
67 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 67
def immutable=: (bool) -> bool
|
#results= ⇒ Object (readonly)
71 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 71
def results=: (
|
#to_hash ⇒ {
101 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 101
def to_hash: -> {
|