Class: Openlayer::Models::Governance::RuleCreateResponse::Result
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleCreateResponse::Result
- Defined in:
- lib/openlayer/models/governance/rule_create_response.rb,
sig/openlayer/models/governance/rule_create_response.rbs
Defined Under Namespace
Modules: Status Classes: BlockedBy, Blocking
Instance Attribute Summary collapse
-
#assignee_id ⇒ String?
The user responsible for this result.
-
#blocked_by ⇒ Array<Openlayer::Models::Governance::RuleCreateResponse::Result::BlockedBy>?
Rule results that must pass before this one can be satisfied.
-
#blocking ⇒ Array<Openlayer::Models::Governance::RuleCreateResponse::Result::Blocking>?
Rule results that this one blocks.
-
#date_created ⇒ Time
Returns the value of attribute date_created.
-
#date_last_evaluated ⇒ Time?
Returns the value of attribute date_last_evaluated.
-
#date_of_latest_evidence ⇒ Time?
Returns the value of attribute date_of_latest_evidence.
-
#date_of_next_evaluation ⇒ Time?
Returns the value of attribute date_of_next_evaluation.
-
#date_of_renewal ⇒ Time?
Returns the value of attribute date_of_renewal.
-
#date_updated ⇒ Time
Returns the value of attribute date_updated.
-
#deactivated ⇒ Boolean
Whether this result is excluded from compliance calculations.
-
#deactivated_reason ⇒ String?
Why the result was excluded.
-
#id ⇒ String
Returns the value of attribute id.
-
#project_id ⇒ String?
Returns the value of attribute project_id.
-
#rule_id ⇒ String
Returns the value of attribute rule_id.
-
#status ⇒ Symbol, Openlayer::Models::Governance::RuleCreateResponse::Result::Status
The compliance status of the rule for this entity.
-
#status_message ⇒ String?
A human-readable explanation of the status.
-
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, date_created:, date_updated:, deactivated:, rule_id:, status:, workspace_id:, assignee_id: nil, blocked_by: nil, blocking: nil, date_last_evaluated: nil, date_of_latest_evidence: nil, date_of_next_evaluation: nil, date_of_renewal: nil, deactivated_reason: nil, project_id: nil, status_message: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, date_created:, date_updated:, deactivated:, rule_id:, status:, workspace_id:, assignee_id: nil, blocked_by: nil, blocking: nil, date_last_evaluated: nil, date_of_latest_evidence: nil, date_of_next_evaluation: nil, date_of_renewal: nil, deactivated_reason: nil, project_id: nil, status_message: nil) ⇒ Object
|
|
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 420
|
Instance Attribute Details
#assignee_id ⇒ String?
The user responsible for this result.
329 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 329 optional :assignee_id, String, api_name: :assigneeId, nil?: true |
#blocked_by ⇒ Array<Openlayer::Models::Governance::RuleCreateResponse::Result::BlockedBy>?
Rule results that must pass before this one can be satisfied.
335 336 337 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 335 optional :blocked_by, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Governance::RuleCreateResponse::Result::BlockedBy] }, api_name: :blockedBy |
#blocking ⇒ Array<Openlayer::Models::Governance::RuleCreateResponse::Result::Blocking>?
Rule results that this one blocks.
343 344 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 343 optional :blocking, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Governance::RuleCreateResponse::Result::Blocking] } |
#date_created ⇒ Time
Returns the value of attribute date_created.
276 277 278 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 276 def date_created @date_created end |
#date_last_evaluated ⇒ Time?
Returns the value of attribute date_last_evaluated.
284 285 286 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 284 def date_last_evaluated @date_last_evaluated end |
#date_of_latest_evidence ⇒ Time?
Returns the value of attribute date_of_latest_evidence.
286 287 288 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 286 def date_of_latest_evidence @date_of_latest_evidence end |
#date_of_next_evaluation ⇒ Time?
Returns the value of attribute date_of_next_evaluation.
288 289 290 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 288 def date_of_next_evaluation @date_of_next_evaluation end |
#date_of_renewal ⇒ Time?
Returns the value of attribute date_of_renewal.
290 291 292 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 290 def date_of_renewal @date_of_renewal end |
#date_updated ⇒ Time
Returns the value of attribute date_updated.
278 279 280 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 278 def date_updated @date_updated end |
#deactivated ⇒ Boolean
Whether this result is excluded from compliance calculations.
317 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 317 required :deactivated, Openlayer::Internal::Type::Boolean |
#deactivated_reason ⇒ String?
Why the result was excluded.
350 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 350 optional :deactivated_reason, String, api_name: :deactivatedReason, nil?: true |
#id ⇒ String
Returns the value of attribute id.
274 275 276 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 274 def id @id end |
#project_id ⇒ String?
Returns the value of attribute project_id.
292 293 294 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 292 def project_id @project_id end |
#rule_id ⇒ String
Returns the value of attribute rule_id.
280 281 282 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 280 def rule_id @rule_id end |
#status ⇒ Symbol, Openlayer::Models::Governance::RuleCreateResponse::Result::Status
The compliance status of the rule for this entity.
323 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 323 required :status, enum: -> { Openlayer::Models::Governance::RuleCreateResponse::Result::Status } |
#status_message ⇒ String?
A human-readable explanation of the status.
356 |
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 356 optional :status_message, String, api_name: :statusMessage, nil?: true |
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
282 283 284 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 282 def workspace_id @workspace_id end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/governance/rule_create_response.rb', line 469
|
Instance Method Details
#to_hash ⇒ {
314 |
# File 'sig/openlayer/models/governance/rule_create_response.rbs', line 314
def to_hash: -> {
|