Class: Openlayer::Models::Governance::RuleListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openlayer/models/governance/rule_list_params.rb,
sig/openlayer/models/governance/rule_list_params.rbs

Overview

See Also:

  • Openlayer::Resources::Governance::Rules#list

Defined Under Namespace

Modules: Group, Scope, SortBy, Status, Type

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Openlayer

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, asc: nil, assignee_id: nil, deactivated: nil, enabled_framework_only: nil, framework_id: nil, group: nil, include_results: nil, include_unframed: nil, page: nil, per_page: nil, project_id: nil, scope: nil, search_query: nil, sort_by: nil, status: nil, tags: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::Governance::RuleListParams for more details.

Parameters:

  • workspace_id (String)
  • asc (Boolean) (defaults to: nil) —

    Whether to sort in ascending order.

  • assignee_id (String) (defaults to: nil) —

    Only include rules assigned to this user.

  • deactivated (Boolean) (defaults to: nil) —

    Only include rules that are deactivated (or active).

  • enabled_framework_only (Boolean) (defaults to: nil) —

    Only include items belonging to at least one enabled framework.

  • framework_id (String) (defaults to: nil) —

    Only include items belonging to this framework.

  • group (Symbol, Openlayer::Models::Governance::RuleListParams::Group) (defaults to: nil) —

    Only include rules in one bucket of the compliance workflow. open covers rules

  • include_results (Boolean) (defaults to: nil) —

    Whether to include each rule's results inline, in a results array.

  • include_unframed (Boolean) (defaults to: nil) —

    Whether to include rules that are not part of any framework.

  • page (Integer) (defaults to: nil) —

    The page to return in a paginated query.

  • per_page (Integer) (defaults to: nil) —

    Maximum number of items to return per page.

  • project_id (String) (defaults to: nil) —

    Only include items that apply to this project.

  • scope (Symbol, Openlayer::Models::Governance::RuleListParams::Scope) (defaults to: nil) —

    Only include rules with this scope.

  • search_query (String) (defaults to: nil) —

    Filter by a free-text search over names and descriptions.

  • sort_by (Symbol, Openlayer::Models::Governance::RuleListParams::SortBy) (defaults to: nil) —

    The field to sort on.

  • status (Symbol, Openlayer::Models::Governance::RuleListParams::Status) (defaults to: nil) —

    Only include items whose rule result has this compliance status.

  • tags (Array<String>) (defaults to: nil) —

    Only include rules carrying all of these rule tags. Pass tag ids, which you can

  • type (Symbol, Openlayer::Models::Governance::RuleListParams::Type) (defaults to: nil) —

    Only include rules of this type.

  • request_options (Openlayer::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openlayer/models/governance/rule_list_params.rb', line 121

Instance Attribute Details

#asc ⇒ Boolean?

Whether to sort in ascending order.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


20
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 20

optional :asc, Openlayer::Internal::Type::Boolean

#assignee_id ⇒ String?

Only include rules assigned to this user.

Parameters:

  • (String)

Returns:

  • (String, nil)


26
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 26

optional :assignee_id, String

#deactivated ⇒ Boolean?

Only include rules that are deactivated (or active).

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


32
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 32

optional :deactivated, Openlayer::Internal::Type::Boolean

#enabled_framework_only ⇒ Boolean?

Only include items belonging to at least one enabled framework.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


38
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 38

optional :enabled_framework_only, Openlayer::Internal::Type::Boolean

#framework_id ⇒ String?

Only include items belonging to this framework.

Parameters:

  • (String)

Returns:

  • (String, nil)


44
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 44

optional :framework_id, String

#group ⇒ Symbol, ...

Only include rules in one bucket of the compliance workflow. open covers rules that still need attention, done covers rules that are fully satisfied, and excluded covers rules that have been deactivated.



52
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 52

optional :group, enum: -> { Openlayer::Governance::RuleListParams::Group }

#include_results ⇒ Boolean?

Whether to include each rule's results inline, in a results array.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


58
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 58

optional :include_results, Openlayer::Internal::Type::Boolean

#include_unframed ⇒ Boolean?

Whether to include rules that are not part of any framework.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


64
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 64

optional :include_unframed, Openlayer::Internal::Type::Boolean

#page ⇒ Integer?

The page to return in a paginated query.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


70
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 70

optional :page, Integer

#per_page ⇒ Integer?

Maximum number of items to return per page.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


76
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 76

optional :per_page, Integer

#project_id ⇒ String?

Only include items that apply to this project.

Parameters:

  • (String)

Returns:

  • (String, nil)


82
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 82

optional :project_id, String

#scope ⇒ Symbol, ...

Only include rules with this scope.



88
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 88

optional :scope, enum: -> { Openlayer::Governance::RuleListParams::Scope }

#search_query ⇒ String?

Filter by a free-text search over names and descriptions.

Parameters:

  • (String)

Returns:

  • (String, nil)


94
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 94

optional :search_query, String

#sort_by ⇒ Symbol, ...

The field to sort on.



100
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 100

optional :sort_by, enum: -> { Openlayer::Governance::RuleListParams::SortBy }

#status ⇒ Symbol, ...

Only include items whose rule result has this compliance status.



106
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 106

optional :status, enum: -> { Openlayer::Governance::RuleListParams::Status }

#tags ⇒ Array<String>?

Only include rules carrying all of these rule tags. Pass tag ids, which you can look up with List rule tags.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


113
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 113

optional :tags, Openlayer::Internal::Type::ArrayOf[String]

#type ⇒ Symbol, ...

Only include rules of this type.



119
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 119

optional :type, enum: -> { Openlayer::Governance::RuleListParams::Type }

#workspace_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openlayer/models/governance/rule_list_params.rb', line 14

required :workspace_id, String

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/governance/rule_list_params.rb', line 173

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


133
# File 'sig/openlayer/models/governance/rule_list_params.rbs', line 133

def to_hash: -> {