Module: Openlayer::Models::Governance::RuleListParams::Group
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openlayer/models/governance/rule_list_params.rb,
sig/openlayer/models/governance/rule_list_params.rbs
Overview
Only include rules in one bucket of the compliance workflow. open covers rules
that still need attention, done covers rules that are fully satisfied, and
excluded covers rules that have been deactivated.
Constant Summary collapse
- OPEN =
:open- EXCLUDED =
:excluded- DONE =
:done
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Openlayer::Models::Governance::RuleListParams::group]
164 |
# File 'sig/openlayer/models/governance/rule_list_params.rbs', line 164 def self?.values: -> ::Array[Openlayer::Models::Governance::RuleListParams::group] |