Class: Openlayer::Models::Governance::RuleListResponse::Item::Framework
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleListResponse::Item::Framework
- Defined in:
- lib/openlayer/models/governance/rule_list_response.rb,
sig/openlayer/models/governance/rule_list_response.rbs
Defined Under Namespace
Classes: Avatar
Instance Attribute Summary collapse
-
#avatar ⇒ Openlayer::Models::Governance::RuleListResponse::Item::Framework::Avatar?
The icon shown for the framework.
-
#built_in_slug ⇒ String?
Identifies a framework that ships with Openlayer, for example
eu_ai_act,iso_42001,nist_ai_rmf, ortraiga. -
#enabled ⇒ Boolean
Whether the framework is active.
-
#id ⇒ String
Returns the value of attribute id.
-
#name ⇒ String
The framework name.
Instance Method Summary collapse
-
#initialize(id:, avatar:, built_in_slug:, enabled:, name:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Framework for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, avatar:, built_in_slug:, enabled:, name:) ⇒ Object
Some parameter documentations has been truncated, see Openlayer::Models::Governance::RuleListResponse::Item::Framework for more details.
`iso_
|
|
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 277
|
Instance Attribute Details
#avatar ⇒ Openlayer::Models::Governance::RuleListResponse::Item::Framework::Avatar?
The icon shown for the framework.
244 245 246 |
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 244 required :avatar, -> { Openlayer::Models::Governance::RuleListResponse::Item::Framework::Avatar }, nil?: true |
#built_in_slug ⇒ String?
Identifies a framework that ships with Openlayer, for example eu_ai_act,
iso_42001, nist_ai_rmf, or traiga. null for frameworks you create
yourself.
254 |
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 254 required :built_in_slug, String, api_name: :builtInSlug, nil?: true |
#enabled ⇒ Boolean
Whether the framework is active. Rules of a disabled framework are not evaluated and do not count towards compliance.
261 |
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 261 required :enabled, Openlayer::Internal::Type::Boolean |
#id ⇒ String
Returns the value of attribute id.
193 194 195 |
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 193 def id @id end |
#name ⇒ String
The framework name.
267 |
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 267 required :name, String |
Instance Method Details
#to_hash ⇒ {
203 |
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 203
def to_hash: -> {
|