Class: Openlayer::Models::Governance::RuleListResponse::Item::Result

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/governance/rule_list_response.rb,
sig/openlayer/models/governance/rule_list_response.rbs

Defined Under Namespace

Modules: Status Classes: BlockedBy, Blocking

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, date_created:, date_updated:, deactivated:, rule_id:, status:, workspace_id:, assignee_id: nil, blocked_by: nil, blocking: nil, date_last_evaluated: nil, date_of_latest_evidence: nil, date_of_next_evaluation: nil, date_of_renewal: nil, deactivated_reason: nil, project_id: nil, status_message: nil) ⇒ Object

Parameters:

  • id (String) —

    The rule result id.

  • date_created (Time) —

    The creation date.

  • date_updated (Time) —

    The last update date.

  • deactivated (Boolean) —

    Whether this result is excluded from compliance calculations.

  • rule_id (String) —

    The rule this result belongs to.

  • status (Symbol, Openlayer::Models::Governance::RuleListResponse::Item::Result::Status) —

    The compliance status of the rule for this entity.

  • workspace_id (String) —

    The id of the workspace the rule result belongs to.

  • assignee_id (String, nil) (defaults to: nil) —

    The user responsible for this result.

  • blocked_by (Array<Openlayer::Models::Governance::RuleListResponse::Item::Result::BlockedBy>) (defaults to: nil) —

    Rule results that must pass before this one can be satisfied.

  • blocking (Array<Openlayer::Models::Governance::RuleListResponse::Item::Result::Blocking>) (defaults to: nil) —

    Rule results that this one blocks.

  • date_last_evaluated (Time, nil) (defaults to: nil) —

    When the rule was last evaluated. Platform rules only.

  • date_of_latest_evidence (Time, nil) (defaults to: nil) —

    When the most recent piece of evidence was attached. Evidence rules only.

  • date_of_next_evaluation (Time, nil) (defaults to: nil) —

    When the rule will next be evaluated. Platform rules only.

  • date_of_renewal (Time, nil) (defaults to: nil) —

    When the evidence must be renewed. Evidence rules with a renewal cadence only.

  • deactivated_reason (String, nil) (defaults to: nil) —

    Why the result was excluded.

  • project_id (String, nil) (defaults to: nil) —

    The project this result was evaluated for. null for workspace-scoped rules.

  • status_message (String, nil) (defaults to: nil) —

    A human-readable explanation of the status.



# File 'lib/openlayer/models/governance/rule_list_response.rb', line 434

Instance Attribute Details

#assignee_id ⇒ String?

The user responsible for this result.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


343
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 343

optional :assignee_id, String, api_name: :assigneeId, nil?: true

#blocked_by ⇒ Array<Openlayer::Models::Governance::RuleListResponse::Item::Result::BlockedBy>?

Rule results that must pass before this one can be satisfied.



349
350
351
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 349

optional :blocked_by,
-> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Governance::RuleListResponse::Item::Result::BlockedBy] },
api_name: :blockedBy

#blocking ⇒ Array<Openlayer::Models::Governance::RuleListResponse::Item::Result::Blocking>?

Rule results that this one blocks.



357
358
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 357

optional :blocking,
-> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Governance::RuleListResponse::Item::Result::Blocking] }

#date_created ⇒ Time

Returns the value of attribute date_created.

Returns:

  • (Time)


292
293
294
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 292

def date_created
  @date_created
end

#date_last_evaluated ⇒ Time?

Returns the value of attribute date_last_evaluated.

Returns:

  • (Time, nil)


300
301
302
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 300

def date_last_evaluated
  @date_last_evaluated
end

#date_of_latest_evidence ⇒ Time?

Returns the value of attribute date_of_latest_evidence.

Returns:

  • (Time, nil)


302
303
304
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 302

def date_of_latest_evidence
  @date_of_latest_evidence
end

#date_of_next_evaluation ⇒ Time?

Returns the value of attribute date_of_next_evaluation.

Returns:

  • (Time, nil)


304
305
306
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 304

def date_of_next_evaluation
  @date_of_next_evaluation
end

#date_of_renewal ⇒ Time?

Returns the value of attribute date_of_renewal.

Returns:

  • (Time, nil)


306
307
308
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 306

def date_of_renewal
  @date_of_renewal
end

#date_updated ⇒ Time

Returns the value of attribute date_updated.

Returns:

  • (Time)


294
295
296
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 294

def date_updated
  @date_updated
end

#deactivated ⇒ Boolean

Whether this result is excluded from compliance calculations.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


331
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 331

required :deactivated, Openlayer::Internal::Type::Boolean

#deactivated_reason ⇒ String?

Why the result was excluded.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


364
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 364

optional :deactivated_reason, String, api_name: :deactivatedReason, nil?: true

#id ⇒ String

Returns the value of attribute id.

Returns:

  • (String)


290
291
292
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 290

def id
  @id
end

#project_id ⇒ String?

Returns the value of attribute project_id.

Returns:

  • (String, nil)


308
309
310
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 308

def project_id
  @project_id
end

#rule_id ⇒ String

Returns the value of attribute rule_id.

Returns:

  • (String)


296
297
298
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 296

def rule_id
  @rule_id
end

#status ⇒ Symbol, Openlayer::Models::Governance::RuleListResponse::Item::Result::Status

The compliance status of the rule for this entity.

Parameters:

  • value (Openlayer::Models::Governance::RuleListResponse::Item::Result::status)

Returns:



337
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 337

required :status, enum: -> { Openlayer::Models::Governance::RuleListResponse::Item::Result::Status }

#status_message ⇒ String?

A human-readable explanation of the status.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


370
# File 'lib/openlayer/models/governance/rule_list_response.rb', line 370

optional :status_message, String, api_name: :statusMessage, nil?: true

#workspace_id ⇒ String

Returns the value of attribute workspace_id.

Returns:

  • (String)


298
299
300
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 298

def workspace_id
  @workspace_id
end

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/governance/rule_list_response.rb', line 483

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


330
# File 'sig/openlayer/models/governance/rule_list_response.rbs', line 330

def to_hash: -> {