Class: Openlayer::Models::Governance::RuleResultRetrieveResponse::BlockedBy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleResultRetrieveResponse::BlockedBy
- Defined in:
- lib/openlayer/models/governance/rule_result_retrieve_response.rb,
sig/openlayer/models/governance/rule_result_retrieve_response.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
- #id ⇒ String?
-
#status ⇒ Symbol, ...
The compliance status of the rule for this entity.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, status: nil) ⇒ Object
|
|
# File 'lib/openlayer/models/governance/rule_result_retrieve_response.rb', line 181
|
Instance Attribute Details
#id ⇒ String?
172 |
# File 'lib/openlayer/models/governance/rule_result_retrieve_response.rb', line 172 optional :id, String |
#status ⇒ Symbol, ...
The compliance status of the rule for this entity.
178 179 |
# File 'lib/openlayer/models/governance/rule_result_retrieve_response.rb', line 178 optional :status, enum: -> { Openlayer::Models::Governance::RuleResultRetrieveResponse::BlockedBy::Status } |
Instance Method Details
#to_hash ⇒ {
153 |
# File 'sig/openlayer/models/governance/rule_result_retrieve_response.rbs', line 153
def to_hash: -> {
|