Class: Openlayer::Models::Governance::RuleResultUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleResultUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openlayer/models/governance/rule_result_update_params.rb,
sig/openlayer/models/governance/rule_result_update_params.rbs
Overview
Defined Under Namespace
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Openlayer
Instance Attribute Summary collapse
-
#assignee_id ⇒ String?
The user responsible for this result.
-
#blocked_by ⇒ Array<Openlayer::Models::Governance::RuleResultUpdateParams::BlockedBy>?
Rule results that must pass before this one can be satisfied.
-
#blocking ⇒ Array<Openlayer::Models::Governance::RuleResultUpdateParams::Blocking>?
Rule results that this one blocks.
-
#deactivated ⇒ Boolean?
Whether this result is excluded from compliance calculations.
-
#deactivated_reason ⇒ String?
Why the result was excluded.
- #rule_result_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
41 |
# File 'sig/openlayer/models/governance/rule_result_update_params.rbs', line 41
def initialize: (
|
Instance Attribute Details
#assignee_id ⇒ String?
The user responsible for this result.
20 |
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 20 optional :assignee_id, String, api_name: :assigneeId, nil?: true |
#blocked_by ⇒ Array<Openlayer::Models::Governance::RuleResultUpdateParams::BlockedBy>?
Rule results that must pass before this one can be satisfied.
26 27 28 29 30 |
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 26 optional :blocked_by, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Governance::RuleResultUpdateParams::BlockedBy] }, api_name: :blockedBy |
#blocking ⇒ Array<Openlayer::Models::Governance::RuleResultUpdateParams::Blocking>?
Rule results that this one blocks.
36 37 |
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 36 optional :blocking, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Governance::RuleResultUpdateParams::Blocking] } |
#deactivated ⇒ Boolean?
Whether this result is excluded from compliance calculations.
43 |
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 43 optional :deactivated, Openlayer::Internal::Type::Boolean |
#deactivated_reason ⇒ String?
Why the result was excluded.
49 |
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 49 optional :deactivated_reason, String, api_name: :deactivatedReason, nil?: true |
#rule_result_id ⇒ String
14 |
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 14 required :rule_result_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 97
|
Instance Method Details
#to_hash ⇒ {
51 |
# File 'sig/openlayer/models/governance/rule_result_update_params.rbs', line 51
def to_hash: -> {
|