Class: Openlayer::Models::Governance::RuleResultUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleResultUpdateResponse
- Defined in:
- lib/openlayer/models/governance/rule_result_update_response.rb,
sig/openlayer/models/governance/rule_result_update_response.rbs
Overview
Defined Under Namespace
Modules: Status Classes: BlockedBy, Blocking
Instance Attribute Summary collapse
-
#assignee_id ⇒ String?
The user responsible for this result.
-
#blocked_by ⇒ Array<Openlayer::Models::Governance::RuleResultUpdateResponse::BlockedBy>?
Rule results that must pass before this one can be satisfied.
-
#blocking ⇒ Array<Openlayer::Models::Governance::RuleResultUpdateResponse::Blocking>?
Rule results that this one blocks.
-
#date_created ⇒ Time
Returns the value of attribute date_created.
-
#date_last_evaluated ⇒ Time?
Returns the value of attribute date_last_evaluated.
-
#date_of_latest_evidence ⇒ Time?
Returns the value of attribute date_of_latest_evidence.
-
#date_of_next_evaluation ⇒ Time?
Returns the value of attribute date_of_next_evaluation.
-
#date_of_renewal ⇒ Time?
Returns the value of attribute date_of_renewal.
-
#date_updated ⇒ Time
Returns the value of attribute date_updated.
-
#deactivated ⇒ Boolean
Whether this result is excluded from compliance calculations.
-
#deactivated_reason ⇒ String?
Why the result was excluded.
-
#id ⇒ String
Returns the value of attribute id.
-
#project_id ⇒ String?
Returns the value of attribute project_id.
-
#rule_id ⇒ String
Returns the value of attribute rule_id.
-
#status ⇒ Symbol, Openlayer::Models::Governance::RuleResultUpdateResponse::Status
The compliance status of the rule for this entity.
-
#status_message ⇒ String?
A human-readable explanation of the status.
-
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, date_created:, date_updated:, deactivated:, rule_id:, status:, workspace_id:, assignee_id: nil, blocked_by: nil, blocking: nil, date_last_evaluated: nil, date_of_latest_evidence: nil, date_of_next_evaluation: nil, date_of_renewal: nil, deactivated_reason: nil, project_id: nil, status_message: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, date_created:, date_updated:, deactivated:, rule_id:, status:, workspace_id:, assignee_id: nil, blocked_by: nil, blocking: nil, date_last_evaluated: nil, date_of_latest_evidence: nil, date_of_next_evaluation: nil, date_of_renewal: nil, deactivated_reason: nil, project_id: nil, status_message: nil) ⇒ Object
|
|
# File 'lib/openlayer/models/governance/rule_result_update_response.rb', line 115
|
Instance Attribute Details
#assignee_id ⇒ String?
The user responsible for this result.
24 |
# File 'lib/openlayer/models/governance/rule_result_update_response.rb', line 24 optional :assignee_id, String, api_name: :assigneeId, nil?: true |
#blocked_by ⇒ Array<Openlayer::Models::Governance::RuleResultUpdateResponse::BlockedBy>?
Rule results that must pass before this one can be satisfied.
30 31 32 |
# File 'lib/openlayer/models/governance/rule_result_update_response.rb', line 30 optional :blocked_by, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Governance::RuleResultUpdateResponse::BlockedBy] }, api_name: :blockedBy |
#blocking ⇒ Array<Openlayer::Models::Governance::RuleResultUpdateResponse::Blocking>?
Rule results that this one blocks.
38 39 |
# File 'lib/openlayer/models/governance/rule_result_update_response.rb', line 38 optional :blocking, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Governance::RuleResultUpdateResponse::Blocking] } |
#date_created ⇒ Time
Returns the value of attribute date_created.
50 51 52 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 50 def date_created @date_created end |
#date_last_evaluated ⇒ Time?
Returns the value of attribute date_last_evaluated.
58 59 60 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 58 def date_last_evaluated @date_last_evaluated end |
#date_of_latest_evidence ⇒ Time?
Returns the value of attribute date_of_latest_evidence.
60 61 62 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 60 def date_of_latest_evidence @date_of_latest_evidence end |
#date_of_next_evaluation ⇒ Time?
Returns the value of attribute date_of_next_evaluation.
62 63 64 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 62 def date_of_next_evaluation @date_of_next_evaluation end |
#date_of_renewal ⇒ Time?
Returns the value of attribute date_of_renewal.
64 65 66 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 64 def date_of_renewal @date_of_renewal end |
#date_updated ⇒ Time
Returns the value of attribute date_updated.
52 53 54 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 52 def date_updated @date_updated end |
#deactivated ⇒ Boolean
Whether this result is excluded from compliance calculations.
12 |
# File 'lib/openlayer/models/governance/rule_result_update_response.rb', line 12 required :deactivated, Openlayer::Internal::Type::Boolean |
#deactivated_reason ⇒ String?
Why the result was excluded.
45 |
# File 'lib/openlayer/models/governance/rule_result_update_response.rb', line 45 optional :deactivated_reason, String, api_name: :deactivatedReason, nil?: true |
#id ⇒ String
Returns the value of attribute id.
48 49 50 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 48 def id @id end |
#project_id ⇒ String?
Returns the value of attribute project_id.
66 67 68 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 66 def project_id @project_id end |
#rule_id ⇒ String
Returns the value of attribute rule_id.
54 55 56 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 54 def rule_id @rule_id end |
#status ⇒ Symbol, Openlayer::Models::Governance::RuleResultUpdateResponse::Status
The compliance status of the rule for this entity.
18 |
# File 'lib/openlayer/models/governance/rule_result_update_response.rb', line 18 required :status, enum: -> { Openlayer::Models::Governance::RuleResultUpdateResponse::Status } |
#status_message ⇒ String?
A human-readable explanation of the status.
51 |
# File 'lib/openlayer/models/governance/rule_result_update_response.rb', line 51 optional :status_message, String, api_name: :statusMessage, nil?: true |
#workspace_id ⇒ String
Returns the value of attribute workspace_id.
56 57 58 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 56 def workspace_id @workspace_id end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/governance/rule_result_update_response.rb', line 164
|
Instance Method Details
#to_hash ⇒ {
88 |
# File 'sig/openlayer/models/governance/rule_result_update_response.rbs', line 88 def to_hash: -> { |