Class: Openlayer::Models::Governance::RuleStatRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/governance/rule_stat_retrieve_response.rb,
sig/openlayer/models/governance/rule_stat_retrieve_response.rbs

Overview

See Also:

  • Openlayer::Resources::Governance::RuleStats#retrieve

Defined Under Namespace

Classes: RuleResults, Rules

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(total:, total_due_soon:, total_error:, total_failing:, total_passing:, total_pending:, total_running:, total_skipped:) ⇒ Object

Parameters:

  • total (Integer) —

    The total number of rule results.

  • total_due_soon (Integer) —

    The number of rule results whose evidence is about to expire.

  • total_error (Integer) —

    The number of rule results that errored during evaluation.

  • total_failing (Integer) —

    The number of failing rule results.

  • total_passing (Integer) —

    The number of passing rule results.

  • total_pending (Integer) —

    The number of rule results that have not been satisfied yet.

  • total_running (Integer) —

    The number of rule results currently being evaluated.

  • total_skipped (Integer) —

    The number of skipped rule results.



# File 'lib/openlayer/models/governance/rule_stat_retrieve_response.rb', line 23

Instance Attribute Details

#rule_results ⇒ Openlayer::Models::Governance::RuleStatRetrieveResponse::RuleResults

Counts of rule results, after any filters in the request, with breakdowns by the type and scope of the rule each result belongs to.



13
14
15
# File 'lib/openlayer/models/governance/rule_stat_retrieve_response.rb', line 13

required :rule_results,
-> { Openlayer::Models::Governance::RuleStatRetrieveResponse::RuleResults },
api_name: :ruleResults

#rules ⇒ Openlayer::Models::Governance::RuleStatRetrieveResponse::Rules

Counts of the rules themselves, after any filters in the request.



21
# File 'lib/openlayer/models/governance/rule_stat_retrieve_response.rb', line 21

required :rules, -> { Openlayer::Models::Governance::RuleStatRetrieveResponse::Rules }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


20
# File 'sig/openlayer/models/governance/rule_stat_retrieve_response.rbs', line 20

def to_hash: -> {