Class: Openlayer::Models::Governance::RuleUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openlayer/models/governance/rule_update_params.rb,
sig/openlayer/models/governance/rule_update_params.rbs

Overview

See Also:

  • Openlayer::Resources::Governance::Rules#update

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Openlayer

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(rule_id:, assignee_id: nil, deactivated: nil, description: nil, name: nil, renewal_cadence_days: nil, tag_ids: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::Governance::RuleUpdateParams for more details.

Parameters:

  • rule_id (String)
  • assignee_id (String, nil) (defaults to: nil) —

    The user responsible for satisfying the rule.

  • deactivated (Boolean) (defaults to: nil) —

    Whether the rule is excluded from compliance calculations.

  • description (String, nil) (defaults to: nil) —

    What the rule requires.

  • name (String) (defaults to: nil) —

    The rule name.

  • renewal_cadence_days (Integer, nil) (defaults to: nil) —

    How often evidence must be renewed, in days. Once evidence is older than this, t

  • tag_ids (Array<String>, nil) (defaults to: nil) —

    The ids of the rule tags to associate with the rule. Replaces the rule's tags. R

  • request_options (Openlayer::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openlayer/models/governance/rule_update_params.rb', line 55

Instance Attribute Details

#assignee_id ⇒ String?

The user responsible for satisfying the rule.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


20
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 20

optional :assignee_id, String, api_name: :assigneeId, nil?: true

#deactivated ⇒ Boolean?

Whether the rule is excluded from compliance calculations.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


26
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 26

optional :deactivated, Openlayer::Internal::Type::Boolean

#description ⇒ String?

What the rule requires.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 32

optional :description, String, nil?: true

#name ⇒ String?

The rule name.

Parameters:

  • (String)

Returns:

  • (String, nil)


38
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 38

optional :name, String

#renewal_cadence_days ⇒ Integer?

How often evidence must be renewed, in days. Once evidence is older than this, the rule result becomes due_soon and then failing.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


45
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 45

optional :renewal_cadence_days, Integer, api_name: :renewalCadenceDays, nil?: true

#rule_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 14

required :rule_id, String

#tag_ids ⇒ Array<String>?

The ids of the rule tags to associate with the rule. Replaces the rule's tags. Read them back from tags, and list the tags available in the workspace with GET /workspaces/{workspaceId}/rule-tags.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


53
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 53

optional :tag_ids, Openlayer::Internal::Type::ArrayOf[String], api_name: :tagIds, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


49
# File 'sig/openlayer/models/governance/rule_update_params.rbs', line 49

def to_hash: -> {