Class: Openlayer::Models::Governance::RuleUpdateResponse::Tag

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/governance/rule_update_response.rb,
sig/openlayer/models/governance/rule_update_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, creator_id:, date_created:, date_updated:, immutable:, name:, workspace_id:, color: nil) ⇒ Object

Parameters:

  • The rule tag id.

  • The user who created the tag. null for tags that ship with Openlayer.

  • The creation date.

  • The last update date.

  • Whether the tag is managed by Openlayer and cannot be edited or deleted.

  • The tag name.

  • The id of the workspace the tag belongs to.

  • (defaults to: nil)

    The color the tag is displayed with.



# File 'lib/openlayer/models/governance/rule_update_response.rb', line 618

Instance Attribute Details

#color ⇒ String?

The color the tag is displayed with.

Parameters:

Returns:



578
# File 'lib/openlayer/models/governance/rule_update_response.rb', line 578

optional :color, String, nil?: true

#creator_id ⇒ String?

Returns the value of attribute creator_id.

Returns:



495
496
497
# File 'sig/openlayer/models/governance/rule_update_response.rbs', line 495

def creator_id
  @creator_id
end

#date_created ⇒ Time

Returns the value of attribute date_created.

Returns:



497
498
499
# File 'sig/openlayer/models/governance/rule_update_response.rbs', line 497

def date_created
  @date_created
end

#date_updated ⇒ Time

Returns the value of attribute date_updated.

Returns:



499
500
501
# File 'sig/openlayer/models/governance/rule_update_response.rbs', line 499

def date_updated
  @date_updated
end

#id ⇒ String

Returns the value of attribute id.

Returns:



493
494
495
# File 'sig/openlayer/models/governance/rule_update_response.rbs', line 493

def id
  @id
end

#immutable ⇒ Boolean

Returns the value of attribute immutable.

Returns:



501
502
503
# File 'sig/openlayer/models/governance/rule_update_response.rbs', line 501

def immutable
  @immutable
end

#name ⇒ String

The tag name.

Parameters:

Returns:



572
# File 'lib/openlayer/models/governance/rule_update_response.rb', line 572

required :name, String

#workspace_id ⇒ String

Returns the value of attribute workspace_id.

Returns:



503
504
505
# File 'sig/openlayer/models/governance/rule_update_response.rbs', line 503

def workspace_id
  @workspace_id
end

Instance Method Details

#to_hash ⇒ {

Returns:



516
# File 'sig/openlayer/models/governance/rule_update_response.rbs', line 516

def to_hash: -> {