Class: Openlayer::Models::InferencePipelineRetrieveResponse::Project

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/inference_pipeline_retrieve_response.rb,
sig/openlayer/models/inference_pipeline_retrieve_response.rbs

Overview

See Also:

  • Openlayer::Models::InferencePipelineRetrieveResponse#project

Defined Under Namespace

Modules: Source, TaskType Classes: GitRepo, Links

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(app:) ⇒ Object

Links to the project.

Parameters:

  • app (String)


# File 'lib/openlayer/models/inference_pipeline_retrieve_response.rb', line 816

Instance Attribute Details

#creator_idString?

Returns the value of attribute creator_id.

Returns:

  • (String, nil)


646
647
648
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 646

def creator_id
  @creator_id
end

#data_retention_daysInteger?

Number of days to retain monitoring data for this project. Null means data is retained indefinitely.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


706
# File 'lib/openlayer/models/inference_pipeline_retrieve_response.rb', line 706

optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true

#date_createdTime

Returns the value of attribute date_created.

Returns:

  • (Time)


648
649
650
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 648

def date_created
  @date_created
end

#date_updatedTime

Returns the value of attribute date_updated.

Returns:

  • (Time)


650
651
652
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 650

def date_updated
  @date_updated
end

#descriptionString?

The project description.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


712
# File 'lib/openlayer/models/inference_pipeline_retrieve_response.rb', line 712

optional :description, String, nil?: true

#development_goal_countInteger

Returns the value of attribute development_goal_count.

Returns:

  • (Integer)


652
653
654
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 652

def development_goal_count
  @development_goal_count
end

#git_repoOpenlayer::Models::InferencePipelineRetrieveResponse::Project::GitRepo?

Returns the value of attribute git_repo.



668
669
670
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 668

def git_repo
  @git_repo
end

#goal_countInteger

Returns the value of attribute goal_count.

Returns:

  • (Integer)


654
655
656
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 654

def goal_count
  @goal_count
end

#idString

Returns the value of attribute id.

Returns:

  • (String)


644
645
646
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 644

def id
  @id
end

#inference_pipeline_countInteger

Returns the value of attribute inference_pipeline_count.

Returns:

  • (Integer)


656
657
658
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 656

def inference_pipeline_count
  @inference_pipeline_count
end

Returns the value of attribute links.



658
659
660
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 658

def links
  @links
end

#model_developerString?

Who developed the model used in this project.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


718
# File 'lib/openlayer/models/inference_pipeline_retrieve_response.rb', line 718

optional :model_developer, String, api_name: :modelDeveloper, nil?: true

#model_typesArray<String>?

The kinds of model used in this project.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


724
# File 'lib/openlayer/models/inference_pipeline_retrieve_response.rb', line 724

optional :model_types, Openlayer::Internal::Type::ArrayOf[String], api_name: :modelTypes, nil?: true

#monitoring_goal_countInteger

Returns the value of attribute monitoring_goal_count.

Returns:

  • (Integer)


660
661
662
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 660

def monitoring_goal_count
  @monitoring_goal_count
end

#nameString

The project name.

Parameters:

  • value (String)

Returns:

  • (String)


691
# File 'lib/openlayer/models/inference_pipeline_retrieve_response.rb', line 691

required :name, String

#purposeString?

What the system in this project is intended to do.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


730
# File 'lib/openlayer/models/inference_pipeline_retrieve_response.rb', line 730

optional :purpose, String, nil?: true

#sourceOpenlayer::Models::InferencePipelineRetrieveResponse::Project::source?

Returns the value of attribute source.

Returns:

  • (Openlayer::Models::InferencePipelineRetrieveResponse::Project::source, nil)


662
663
664
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 662

def source
  @source
end

#task_typeSymbol, Openlayer::Models::InferencePipelineRetrieveResponse::Project::TaskType

The task type of the project.

Parameters:

  • value (Openlayer::Models::InferencePipelineRetrieveResponse::Project::task_type)

Returns:



697
698
699
# File 'lib/openlayer/models/inference_pipeline_retrieve_response.rb', line 697

required :task_type,
enum: -> { Openlayer::Models::InferencePipelineRetrieveResponse::Project::TaskType },
api_name: :taskType

#version_countInteger

Returns the value of attribute version_count.

Returns:

  • (Integer)


664
665
666
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 664

def version_count
  @version_count
end

#workspace_idString?

Returns the value of attribute workspace_id.

Returns:

  • (String, nil)


666
667
668
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 666

def workspace_id
  @workspace_id
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/inference_pipeline_retrieve_response.rb', line 884

Instance Method Details

#to_hash{

Returns:

  • ({)


693
# File 'sig/openlayer/models/inference_pipeline_retrieve_response.rbs', line 693

def to_hash: -> {