Class: Openlayer::Models::InferencePipelineRetrieveSessionsResponse::Item
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::InferencePipelineRetrieveSessionsResponse::Item
- Defined in:
- lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb
Instance Attribute Summary collapse
-
#cost ⇒ Float
Total cost for the session.
-
#date_created ⇒ Time
Latest/most recent timestamp in the session.
-
#date_of_first_record ⇒ Time
Timestamp of the first request in the session.
-
#date_of_last_record ⇒ Time
Timestamp of the last request in the session.
-
#duration ⇒ Float
Duration between first and last request (in milliseconds).
-
#first_record ⇒ Hash{Symbol=>Object}
The complete first record in the session.
-
#id ⇒ String
The unique session identifier.
-
#last_record ⇒ Hash{Symbol=>Object}
The complete last record in the session.
-
#latency ⇒ Float
Total latency for the session (in milliseconds).
-
#records ⇒ Integer
Total number of records/traces in the session.
-
#tokens ⇒ Float
Total token count for the session.
-
#user_ids ⇒ Array<String>
List of unique user IDs that participated in this session.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, cost:, date_created:, date_of_first_record:, date_of_last_record:, duration:, first_record:, last_record:, latency:, records:, tokens:, user_ids:) ⇒ Object
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 17 class Item < Openlayer::Internal::Type::BaseModel # @!attribute id # The unique session identifier # # @return [String] required :id, String # @!attribute cost # Total cost for the session # # @return [Float] required :cost, Float # @!attribute date_created # Latest/most recent timestamp in the session # # @return [Time] required :date_created, Time, api_name: :dateCreated # @!attribute date_of_first_record # Timestamp of the first request in the session # # @return [Time] required :date_of_first_record, Time, api_name: :dateOfFirstRecord # @!attribute date_of_last_record # Timestamp of the last request in the session # # @return [Time] required :date_of_last_record, Time, api_name: :dateOfLastRecord # @!attribute duration # Duration between first and last request (in milliseconds) # # @return [Float] required :duration, Float # @!attribute first_record # The complete first record in the session # # @return [Hash{Symbol=>Object}] required :first_record, Openlayer::Internal::Type::HashOf[Openlayer::Internal::Type::Unknown], api_name: :firstRecord # @!attribute last_record # The complete last record in the session # # @return [Hash{Symbol=>Object}] required :last_record, Openlayer::Internal::Type::HashOf[Openlayer::Internal::Type::Unknown], api_name: :lastRecord # @!attribute latency # Total latency for the session (in milliseconds) # # @return [Float] required :latency, Float # @!attribute records # Total number of records/traces in the session # # @return [Integer] required :records, Integer # @!attribute tokens # Total token count for the session # # @return [Float] required :tokens, Float # @!attribute user_ids # List of unique user IDs that participated in this session # # @return [Array<String>] required :user_ids, Openlayer::Internal::Type::ArrayOf[String], api_name: :userIds # @!method initialize(id:, cost:, date_created:, date_of_first_record:, date_of_last_record:, duration:, first_record:, last_record:, latency:, records:, tokens:, user_ids:) # @param id [String] The unique session identifier # # @param cost [Float] Total cost for the session # # @param date_created [Time] Latest/most recent timestamp in the session # # @param date_of_first_record [Time] Timestamp of the first request in the session # # @param date_of_last_record [Time] Timestamp of the last request in the session # # @param duration [Float] Duration between first and last request (in milliseconds) # # @param first_record [Hash{Symbol=>Object}] The complete first record in the session # # @param last_record [Hash{Symbol=>Object}] The complete last record in the session # # @param latency [Float] Total latency for the session (in milliseconds) # # @param records [Integer] Total number of records/traces in the session # # @param tokens [Float] Total token count for the session # # @param user_ids [Array<String>] List of unique user IDs that participated in this session end |
Instance Attribute Details
#cost ⇒ Float
Total cost for the session
28 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 28 required :cost, Float |
#date_created ⇒ Time
Latest/most recent timestamp in the session
34 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 34 required :date_created, Time, api_name: :dateCreated |
#date_of_first_record ⇒ Time
Timestamp of the first request in the session
40 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 40 required :date_of_first_record, Time, api_name: :dateOfFirstRecord |
#date_of_last_record ⇒ Time
Timestamp of the last request in the session
46 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 46 required :date_of_last_record, Time, api_name: :dateOfLastRecord |
#duration ⇒ Float
Duration between first and last request (in milliseconds)
52 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 52 required :duration, Float |
#first_record ⇒ Hash{Symbol=>Object}
The complete first record in the session
58 59 60 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 58 required :first_record, Openlayer::Internal::Type::HashOf[Openlayer::Internal::Type::Unknown], api_name: :firstRecord |
#id ⇒ String
The unique session identifier
22 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 22 required :id, String |
#last_record ⇒ Hash{Symbol=>Object}
The complete last record in the session
66 67 68 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 66 required :last_record, Openlayer::Internal::Type::HashOf[Openlayer::Internal::Type::Unknown], api_name: :lastRecord |
#latency ⇒ Float
Total latency for the session (in milliseconds)
74 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 74 required :latency, Float |
#records ⇒ Integer
Total number of records/traces in the session
80 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 80 required :records, Integer |
#tokens ⇒ Float
Total token count for the session
86 |
# File 'lib/openlayer/models/inference_pipeline_retrieve_sessions_response.rb', line 86 required :tokens, Float |