Class: Openlayer::Models::InferencePipelines::DataStreamParams::Config::LlmData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::InferencePipelines::DataStreamParams::Config::LlmData
- Defined in:
- lib/openlayer/models/inference_pipelines/data_stream_params.rb
Defined Under Namespace
Classes: Prompt
Instance Attribute Summary collapse
-
#context_column_name ⇒ String?
Name of the column with the context retrieved.
-
#cost_column_name ⇒ String?
Name of the column with the cost associated with each row.
-
#ground_truth_column_name ⇒ String?
Name of the column with the ground truths.
-
#inference_id_column_name ⇒ String?
Name of the column with the inference ids.
-
#input_variable_names ⇒ Array<String>?
Array of input variable names.
-
#latency_column_name ⇒ String?
Name of the column with the latencies.
-
#metadata ⇒ Object?
Object with metadata.
-
#num_of_token_column_name ⇒ String?
Name of the column with the total number of tokens.
-
#output_column_name ⇒ String
Name of the column with the model outputs.
-
#prompt ⇒ Array<Openlayer::Models::InferencePipelines::DataStreamParams::Config::LlmData::Prompt>?
Prompt for the LLM.
-
#question_column_name ⇒ String?
Name of the column with the questions.
-
#session_id_column_name ⇒ String?
Name of the column with the session id.
-
#timestamp_column_name ⇒ String?
Name of the column with the timestamps.
-
#user_id_column_name ⇒ String?
Name of the column with the user id.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Openlayer::Internal::Type::BaseModel
Instance Attribute Details
#context_column_name ⇒ String?
Name of the column with the context retrieved. Applies to RAG use cases. Providing the context enables RAG-specific metrics.
68 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 68 optional :context_column_name, String, api_name: :contextColumnName |
#cost_column_name ⇒ String?
Name of the column with the cost associated with each row.
74 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 74 optional :cost_column_name, String, api_name: :costColumnName |
#ground_truth_column_name ⇒ String?
Name of the column with the ground truths.
80 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 80 optional :ground_truth_column_name, String, api_name: :groundTruthColumnName |
#inference_id_column_name ⇒ String?
Name of the column with the inference ids. This is useful if you want to update rows at a later point in time. If not provided, a unique id is generated by Openlayer.
88 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 88 optional :inference_id_column_name, String, api_name: :inferenceIdColumnName |
#input_variable_names ⇒ Array<String>?
Array of input variable names. Each input variable should be a dataset column.
94 95 96 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 94 optional :input_variable_names, Openlayer::Internal::Type::ArrayOf[String], api_name: :inputVariableNames |
#latency_column_name ⇒ String?
Name of the column with the latencies.
102 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 102 optional :latency_column_name, String, api_name: :latencyColumnName |
#metadata ⇒ Object?
Object with metadata.
108 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 108 optional :metadata, Openlayer::Internal::Type::Unknown |
#num_of_token_column_name ⇒ String?
Name of the column with the total number of tokens.
114 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 114 optional :num_of_token_column_name, String, api_name: :numOfTokenColumnName, nil?: true |
#output_column_name ⇒ String
Name of the column with the model outputs.
61 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 61 required :output_column_name, String, api_name: :outputColumnName |
#prompt ⇒ Array<Openlayer::Models::InferencePipelines::DataStreamParams::Config::LlmData::Prompt>?
Prompt for the LLM.
120 121 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 120 optional :prompt, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::InferencePipelines::DataStreamParams::Config::LlmData::Prompt] } |
#question_column_name ⇒ String?
Name of the column with the questions. Applies to RAG use cases. Providing the question enables RAG-specific metrics.
128 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 128 optional :question_column_name, String, api_name: :questionColumnName |
#session_id_column_name ⇒ String?
Name of the column with the session id.
134 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 134 optional :session_id_column_name, String, api_name: :sessionIdColumnName, nil?: true |
#timestamp_column_name ⇒ String?
Name of the column with the timestamps. Timestamps must be in UNIX sec format. If not provided, the upload timestamp is used.
141 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 141 optional :timestamp_column_name, String, api_name: :timestampColumnName |
#user_id_column_name ⇒ String?
Name of the column with the user id.
147 |
# File 'lib/openlayer/models/inference_pipelines/data_stream_params.rb', line 147 optional :user_id_column_name, String, api_name: :userIdColumnName, nil?: true |