Class: Openlayer::Models::InferencePipelines::TestResultListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openlayer/models/inference_pipelines/test_result_list_params.rb,
sig/openlayer/models/inference_pipelines/test_result_list_params.rbs

Overview

See Also:

  • Openlayer::Resources::InferencePipelines::TestResults#list

Defined Under Namespace

Modules: Status, Type

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Openlayer

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(inference_pipeline_id:, page: nil, per_page: nil, status: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::InferencePipelines::TestResultListParams for more details.

Parameters:



# File 'lib/openlayer/models/inference_pipelines/test_result_list_params.rb', line 42

Instance Attribute Details

#inference_pipeline_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openlayer/models/inference_pipelines/test_result_list_params.rb', line 14

required :inference_pipeline_id, String

#pageInteger?

The page to return in a paginated query.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


20
# File 'lib/openlayer/models/inference_pipelines/test_result_list_params.rb', line 20

optional :page, Integer

#per_pageInteger?

Maximum number of items to return per page.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


26
# File 'lib/openlayer/models/inference_pipelines/test_result_list_params.rb', line 26

optional :per_page, Integer

#statusSymbol, ...

Filter list of test results by status. Available statuses are running, passing, failing, skipped, and error.



33
# File 'lib/openlayer/models/inference_pipelines/test_result_list_params.rb', line 33

optional :status, enum: -> { Openlayer::InferencePipelines::TestResultListParams::Status }

#typeSymbol, ...

Filter objects by test type. Available types are integrity, consistency, performance, fairness, and robustness.



40
# File 'lib/openlayer/models/inference_pipelines/test_result_list_params.rb', line 40

optional :type, enum: -> { Openlayer::InferencePipelines::TestResultListParams::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/inference_pipelines/test_result_list_params.rb', line 69

Instance Method Details

#to_hash{

Returns:

  • ({)


49
# File 'sig/openlayer/models/inference_pipelines/test_result_list_params.rbs', line 49

def to_hash: -> {