Class: Openlayer::Models::InferencePipelines::TestResultListResponse::Item
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::InferencePipelines::TestResultListResponse::Item
- Defined in:
- lib/openlayer/models/inference_pipelines/test_result_list_response.rb
Defined Under Namespace
Modules: Status Classes: ExpectedValue, Goal, RowsBody
Instance Attribute Summary collapse
- #expected_values ⇒ Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::ExpectedValue>?
- #goal ⇒ Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal?
-
#rows ⇒ String?
The URL to the rows of the test result.
-
#rows_body ⇒ Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody?
The body of the rows request.
-
#status ⇒ Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Status
The status of the test.
-
#status_message ⇒ String?
The status message.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(lower_threshold: nil, measurement: nil, upper_threshold: nil) ⇒ Object
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 |
# File 'lib/openlayer/models/inference_pipelines/test_result_list_response.rb', line 17 class Item < Openlayer::Internal::Type::BaseModel # @!attribute status # The status of the test. # # @return [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Status] required :status, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Status } # @!attribute status_message # The status message. # # @return [String, nil] required :status_message, String, api_name: :statusMessage, nil?: true # @!attribute expected_values # # @return [Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::ExpectedValue>, nil] optional :expected_values, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::InferencePipelines::TestResultListResponse::Item::ExpectedValue] }, api_name: :expectedValues # @!attribute goal # # @return [Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal, nil] optional :goal, -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal } # @!attribute rows # The URL to the rows of the test result. # # @return [String, nil] optional :rows, String # @!attribute rows_body # The body of the rows request. # # @return [Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody, nil] optional :rows_body, -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody }, api_name: :rowsBody, nil?: true response_only do # @!attribute id # Project version (commit) id. # # @return [String] required :id, String # @!attribute date_created # The creation date. # # @return [Time] required :date_created, Time, api_name: :dateCreated # @!attribute date_data_ends # The data end date. # # @return [Time, nil] required :date_data_ends, Time, api_name: :dateDataEnds, nil?: true # @!attribute date_data_starts # The data start date. # # @return [Time, nil] required :date_data_starts, Time, api_name: :dateDataStarts, nil?: true # @!attribute date_updated # The last updated date. # # @return [Time] required :date_updated, Time, api_name: :dateUpdated # @!attribute inference_pipeline_id # The inference pipeline id. # # @return [String, nil] required :inference_pipeline_id, String, api_name: :inferencePipelineId, nil?: true # @!attribute project_version_id # The project version (commit) id. # # @return [String, nil] required :project_version_id, String, api_name: :projectVersionId, nil?: true # @!attribute goal_id # The test id. # # @return [String, nil] optional :goal_id, String, api_name: :goalId, nil?: true end # @!method initialize(id:, date_created:, date_data_ends:, date_data_starts:, date_updated:, inference_pipeline_id:, project_version_id:, status:, status_message:, expected_values: nil, goal: nil, goal_id: nil, rows: nil, rows_body: nil) # @param id [String] Project version (commit) id. # # @param date_created [Time] The creation date. # # @param date_data_ends [Time, nil] The data end date. # # @param date_data_starts [Time, nil] The data start date. # # @param date_updated [Time] The last updated date. # # @param inference_pipeline_id [String, nil] The inference pipeline id. # # @param project_version_id [String, nil] The project version (commit) id. # # @param status [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Status] The status of the test. # # @param status_message [String, nil] The status message. # # @param expected_values [Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::ExpectedValue>] # # @param goal [Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal] # # @param goal_id [String, nil] The test id. # # @param rows [String] The URL to the rows of the test result. # # @param rows_body [Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody, nil] The body of the rows request. # The status of the test. # # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item#status module Status extend Openlayer::Internal::Type::Enum RUNNING = :running PASSING = :passing FAILING = :failing SKIPPED = :skipped ERROR = :error # @!method self.values # @return [Array<Symbol>] end class ExpectedValue < Openlayer::Internal::Type::BaseModel # @!attribute lower_threshold # the lower threshold for the expected value # # @return [Float, nil] optional :lower_threshold, Float, api_name: :lowerThreshold, nil?: true # @!attribute measurement # One of the `measurement` values in the test's thresholds # # @return [String, nil] optional :measurement, String # @!attribute upper_threshold # The upper threshold for the expected value # # @return [Float, nil] optional :upper_threshold, Float, api_name: :upperThreshold, nil?: true # @!method initialize(lower_threshold: nil, measurement: nil, upper_threshold: nil) # @param lower_threshold [Float, nil] the lower threshold for the expected value # # @param measurement [String] One of the `measurement` values in the test's thresholds # # @param upper_threshold [Float, nil] The upper threshold for the expected value end # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item#goal class Goal < Openlayer::Internal::Type::BaseModel # @!attribute description # The test description. # # @return [Object, nil] required :description, Openlayer::Internal::Type::Unknown, nil?: true # @!attribute name # The test name. # # @return [String] required :name, String # @!attribute subtype # The test subtype. # # @return [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Subtype] required :subtype, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Subtype } # @!attribute thresholds # # @return [Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold>] required :thresholds, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold] } # @!attribute type # The test type. # # @return [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Type] required :type, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Type } # @!attribute archived # Whether the test is archived. # # @return [Boolean, nil] optional :archived, Openlayer::Internal::Type::Boolean # @!attribute delay_window # The delay window in seconds. Only applies to tests that use production data. # # @return [Float, nil] optional :delay_window, Float, api_name: :delayWindow, nil?: true # @!attribute evaluation_window # The evaluation window in seconds. Only applies to tests that use production # data. # # @return [Float, nil] optional :evaluation_window, Float, api_name: :evaluationWindow, nil?: true # @!attribute uses_ml_model # Whether the test uses an ML model. # # @return [Boolean, nil] optional :uses_ml_model, Openlayer::Internal::Type::Boolean, api_name: :usesMlModel # @!attribute uses_production_data # Whether the test uses production data (monitoring mode only). # # @return [Boolean, nil] optional :uses_production_data, Openlayer::Internal::Type::Boolean, api_name: :usesProductionData # @!attribute uses_reference_dataset # Whether the test uses a reference dataset (monitoring mode only). # # @return [Boolean, nil] optional :uses_reference_dataset, Openlayer::Internal::Type::Boolean, api_name: :usesReferenceDataset # @!attribute uses_training_dataset # Whether the test uses a training dataset. # # @return [Boolean, nil] optional :uses_training_dataset, Openlayer::Internal::Type::Boolean, api_name: :usesTrainingDataset # @!attribute uses_validation_dataset # Whether the test uses a validation dataset. # # @return [Boolean, nil] optional :uses_validation_dataset, Openlayer::Internal::Type::Boolean, api_name: :usesValidationDataset response_only do # @!attribute id # The test id. # # @return [String] required :id, String # @!attribute comment_count # The number of comments on the test. # # @return [Integer] required :comment_count, Integer, api_name: :commentCount # @!attribute creator_id # The test creator id. # # @return [String, nil] required :creator_id, String, api_name: :creatorId, nil?: true # @!attribute date_archived # The date the test was archived. # # @return [Time, nil] required :date_archived, Time, api_name: :dateArchived, nil?: true # @!attribute date_created # The creation date. # # @return [Time] required :date_created, Time, api_name: :dateCreated # @!attribute date_updated # The last updated date. # # @return [Time] required :date_updated, Time, api_name: :dateUpdated # @!attribute number # The test number. # # @return [Integer] required :number, Integer # @!attribute origin_project_version_id # The project version (commit) id where the test was created. # # @return [String, nil] required :origin_project_version_id, String, api_name: :originProjectVersionId, nil?: true # @!attribute suggested # Whether the test is suggested or user-created. # # @return [Boolean] required :suggested, Openlayer::Internal::Type::Boolean end # @!method initialize(id:, comment_count:, creator_id:, date_archived:, date_created:, date_updated:, description:, name:, number:, origin_project_version_id:, subtype:, suggested:, thresholds:, type:, archived: nil, delay_window: nil, evaluation_window: nil, uses_ml_model: nil, uses_production_data: nil, uses_reference_dataset: nil, uses_training_dataset: nil, uses_validation_dataset: nil) # Some parameter documentations has been truncated, see # {Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal} for # more details. # # @param id [String] The test id. # # @param comment_count [Integer] The number of comments on the test. # # @param creator_id [String, nil] The test creator id. # # @param date_archived [Time, nil] The date the test was archived. # # @param date_created [Time] The creation date. # # @param date_updated [Time] The last updated date. # # @param description [Object, nil] The test description. # # @param name [String] The test name. # # @param number [Integer] The test number. # # @param origin_project_version_id [String, nil] The project version (commit) id where the test was created. # # @param subtype [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Subtype] The test subtype. # # @param suggested [Boolean] Whether the test is suggested or user-created. # # @param thresholds [Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold>] # # @param type [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Type] The test type. # # @param archived [Boolean] Whether the test is archived. # # @param delay_window [Float, nil] The delay window in seconds. Only applies to tests that use production data. # # @param evaluation_window [Float, nil] The evaluation window in seconds. Only applies to tests that use production data # # @param uses_ml_model [Boolean] Whether the test uses an ML model. # # @param uses_production_data [Boolean] Whether the test uses production data (monitoring mode only). # # @param uses_reference_dataset [Boolean] Whether the test uses a reference dataset (monitoring mode only). # # @param uses_training_dataset [Boolean] Whether the test uses a training dataset. # # @param uses_validation_dataset [Boolean] Whether the test uses a validation dataset. # The test subtype. # # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal#subtype module Subtype extend Openlayer::Internal::Type::Enum ANOMALOUS_COLUMN_COUNT = :anomalousColumnCount CHARACTER_LENGTH = :characterLength CLASS_IMBALANCE_RATIO = :classImbalanceRatio EXPECT_COLUMN_A_TO_BE_IN_COLUMN_B = :expectColumnAToBeInColumnB COLUMN_AVERAGE = :columnAverage COLUMN_DRIFT = :columnDrift COLUMN_STATISTIC = :columnStatistic COLUMN_VALUES_MATCH = :columnValuesMatch CONFLICTING_LABEL_ROW_COUNT = :conflictingLabelRowCount CONTAINS_PII = :containsPii CONTAINS_VALID_URL = :containsValidUrl CORRELATED_FEATURE_COUNT = :correlatedFeatureCount CUSTOM_METRIC_THRESHOLD = :customMetricThreshold DUPLICATE_ROW_COUNT = :duplicateRowCount EMPTY_FEATURE = :emptyFeature EMPTY_FEATURE_COUNT = :emptyFeatureCount DRIFTED_FEATURE_COUNT = :driftedFeatureCount FEATURE_MISSING_VALUES = :featureMissingValues FEATURE_VALUE_VALIDATION = :featureValueValidation GREAT_EXPECTATIONS = :greatExpectations GROUP_BY_COLUMN_STATS_CHECK = :groupByColumnStatsCheck ILL_FORMED_ROW_COUNT = :illFormedRowCount IS_CODE = :isCode IS_JSON = :isJson LLM_RUBRIC_THRESHOLD_V2 = :llmRubricThresholdV2 LABEL_DRIFT = :labelDrift METRIC_THRESHOLD = :metricThreshold NEW_CATEGORY_COUNT = :newCategoryCount NEW_LABEL_COUNT = :newLabelCount NULL_ROW_COUNT = :nullRowCount ROW_COUNT = :rowCount PP_SCORE_VALUE_VALIDATION = :ppScoreValueValidation QUASI_CONSTANT_FEATURE = :quasiConstantFeature QUASI_CONSTANT_FEATURE_COUNT = :quasiConstantFeatureCount SQL_QUERY = :sqlQuery DTYPE_VALIDATION = :dtypeValidation SENTENCE_LENGTH = :sentenceLength SIZE_RATIO = :sizeRatio SPECIAL_CHARACTERS_RATIO = :specialCharactersRatio STRING_VALIDATION = :stringValidation TRAIN_VAL_LEAKAGE_ROW_COUNT = :trainValLeakageRowCount # @!method self.values # @return [Array<Symbol>] end class Threshold < Openlayer::Internal::Type::BaseModel # @!attribute insight_name # The insight name to be evaluated. # # @return [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::InsightName, nil] optional :insight_name, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::InsightName }, api_name: :insightName # @!attribute insight_parameters # The insight parameters. Required only for some test subtypes. For example, for # tests that require a column name, the insight parameters will be [{'name': # 'column_name', 'value': 'Age'}] # # @return [Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::InsightParameter>, nil] optional :insight_parameters, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::InsightParameter] }, api_name: :insightParameters, nil?: true # @!attribute measurement # The measurement to be evaluated. # # @return [String, nil] optional :measurement, String # @!attribute operator # The operator to be used for the evaluation. # # @return [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::Operator, nil] optional :operator, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::Operator } # @!attribute threshold_mode # Whether to use automatic anomaly detection or manual thresholds # # @return [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::ThresholdMode, nil] optional :threshold_mode, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::ThresholdMode }, api_name: :thresholdMode # @!attribute value # The value to be compared. # # @return [Float, Boolean, String, Array<String>, nil] optional :value, union: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::Value } # @!method initialize(insight_name: nil, insight_parameters: nil, measurement: nil, operator: nil, threshold_mode: nil, value: nil) # Some parameter documentations has been truncated, see # {Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold} # for more details. # # @param insight_name [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::InsightName] The insight name to be evaluated. # # @param insight_parameters [Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::InsightParameter>, nil] The insight parameters. Required only for some test subtypes. For example, for t # # @param measurement [String] The measurement to be evaluated. # # @param operator [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::Operator] The operator to be used for the evaluation. # # @param threshold_mode [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::ThresholdMode] Whether to use automatic anomaly detection or manual thresholds # # @param value [Float, Boolean, String, Array<String>] The value to be compared. # The insight name to be evaluated. # # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold#insight_name module InsightName extend Openlayer::Internal::Type::Enum CHARACTER_LENGTH = :characterLength CLASS_IMBALANCE = :classImbalance EXPECT_COLUMN_A_TO_BE_IN_COLUMN_B = :expectColumnAToBeInColumnB COLUMN_AVERAGE = :columnAverage COLUMN_DRIFT = :columnDrift COLUMN_VALUES_MATCH = :columnValuesMatch CONFIDENCE_DISTRIBUTION = :confidenceDistribution CONFLICTING_LABEL_ROW_COUNT = :conflictingLabelRowCount CONTAINS_PII = :containsPii CONTAINS_VALID_URL = :containsValidUrl CORRELATED_FEATURES = :correlatedFeatures CUSTOM_METRIC = :customMetric DUPLICATE_ROW_COUNT = :duplicateRowCount EMPTY_FEATURES = :emptyFeatures FEATURE_DRIFT = :featureDrift FEATURE_PROFILE = :featureProfile GREAT_EXPECTATIONS = :greatExpectations GROUP_BY_COLUMN_STATS_CHECK = :groupByColumnStatsCheck ILL_FORMED_ROW_COUNT = :illFormedRowCount IS_CODE = :isCode IS_JSON = :isJson LLM_RUBRIC_V2 = :llmRubricV2 LABEL_DRIFT = :labelDrift METRICS = :metrics NEW_CATEGORIES = :newCategories NEW_LABELS = :newLabels NULL_ROW_COUNT = :nullRowCount PP_SCORE = :ppScore QUASI_CONSTANT_FEATURES = :quasiConstantFeatures SENTENCE_LENGTH = :sentenceLength SIZE_RATIO = :sizeRatio SPECIAL_CHARACTERS = :specialCharacters STRING_VALIDATION = :stringValidation TRAIN_VAL_LEAKAGE_ROW_COUNT = :trainValLeakageRowCount # @!method self.values # @return [Array<Symbol>] end class InsightParameter < Openlayer::Internal::Type::BaseModel # @!attribute name # The name of the insight filter. # # @return [String] required :name, String # @!attribute value # # @return [Object] required :value, Openlayer::Internal::Type::Unknown # @!method initialize(name:, value:) # @param name [String] The name of the insight filter. # # @param value [Object] end # The operator to be used for the evaluation. # # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold#operator module Operator extend Openlayer::Internal::Type::Enum IS = :is GREATER = :> GREATER_OR_EQUALS = :">=" LESS = :< LESS_OR_EQUALS = :"<=" NOT_EQUALS = :"!=" # @!method self.values # @return [Array<Symbol>] end # Whether to use automatic anomaly detection or manual thresholds # # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold#threshold_mode module ThresholdMode extend Openlayer::Internal::Type::Enum AUTOMATIC = :automatic MANUAL = :manual # @!method self.values # @return [Array<Symbol>] end # The value to be compared. # # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold#value module Value extend Openlayer::Internal::Type::Union variant Float variant Openlayer::Internal::Type::Boolean variant String variant -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal::Threshold::Value::StringArray } # @!method self.variants # @return [Array(Float, Boolean, String, Array<String>)] # @type [Openlayer::Internal::Type::Converter] StringArray = Openlayer::Internal::Type::ArrayOf[String] end end # The test type. # # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal#type module Type extend Openlayer::Internal::Type::Enum INTEGRITY = :integrity CONSISTENCY = :consistency PERFORMANCE = :performance # @!method self.values # @return [Array<Symbol>] end end # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item#rows_body class RowsBody < Openlayer::Internal::Type::BaseModel # @!attribute column_filters # # @return [Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::SetColumnFilter, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::NumericColumnFilter, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter>, nil] optional :column_filters, -> { Openlayer::Internal::Type::ArrayOf[union: Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter] }, api_name: :columnFilters, nil?: true # @!attribute exclude_row_id_list # # @return [Array<Integer>, nil] optional :exclude_row_id_list, Openlayer::Internal::Type::ArrayOf[Integer], api_name: :excludeRowIdList, nil?: true # @!attribute not_search_query_and # # @return [Array<String>, nil] optional :not_search_query_and, Openlayer::Internal::Type::ArrayOf[String], api_name: :notSearchQueryAnd, nil?: true # @!attribute not_search_query_or # # @return [Array<String>, nil] optional :not_search_query_or, Openlayer::Internal::Type::ArrayOf[String], api_name: :notSearchQueryOr, nil?: true # @!attribute row_id_list # # @return [Array<Integer>, nil] optional :row_id_list, Openlayer::Internal::Type::ArrayOf[Integer], api_name: :rowIdList, nil?: true # @!attribute search_query_and # # @return [Array<String>, nil] optional :search_query_and, Openlayer::Internal::Type::ArrayOf[String], api_name: :searchQueryAnd, nil?: true # @!attribute search_query_or # # @return [Array<String>, nil] optional :search_query_or, Openlayer::Internal::Type::ArrayOf[String], api_name: :searchQueryOr, nil?: true # @!method initialize(column_filters: nil, exclude_row_id_list: nil, not_search_query_and: nil, not_search_query_or: nil, row_id_list: nil, search_query_and: nil, search_query_or: nil) # The body of the rows request. # # @param column_filters [Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::SetColumnFilter, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::NumericColumnFilter, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter>, nil] # @param exclude_row_id_list [Array<Integer>, nil] # @param not_search_query_and [Array<String>, nil] # @param not_search_query_or [Array<String>, nil] # @param row_id_list [Array<Integer>, nil] # @param search_query_and [Array<String>, nil] # @param search_query_or [Array<String>, nil] module ColumnFilter extend Openlayer::Internal::Type::Union variant -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::SetColumnFilter } variant -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::NumericColumnFilter } variant -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter } class SetColumnFilter < Openlayer::Internal::Type::BaseModel # @!attribute measurement # The name of the column. # # @return [String] required :measurement, String # @!attribute operator # # @return [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::SetColumnFilter::Operator] required :operator, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::SetColumnFilter::Operator } # @!attribute value # # @return [Array<String, Float>] required :value, -> do Openlayer::Internal::Type::ArrayOf[ union: Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::SetColumnFilter::Value ] end # @!method initialize(measurement:, operator:, value:) # @param measurement [String] The name of the column. # # @param operator [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::SetColumnFilter::Operator] # # @param value [Array<String, Float>] # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::SetColumnFilter#operator module Operator extend Openlayer::Internal::Type::Enum CONTAINS_NONE = :contains_none CONTAINS_ANY = :contains_any CONTAINS_ALL = :contains_all ONE_OF = :one_of NONE_OF = :none_of # @!method self.values # @return [Array<Symbol>] end module Value extend Openlayer::Internal::Type::Union variant String variant Float # @!method self.variants # @return [Array(String, Float)] end end class NumericColumnFilter < Openlayer::Internal::Type::BaseModel # @!attribute measurement # The name of the column. # # @return [String] required :measurement, String # @!attribute operator # # @return [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::NumericColumnFilter::Operator] required :operator, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::NumericColumnFilter::Operator } # @!attribute value # # @return [Float, nil] required :value, Float, nil?: true # @!method initialize(measurement:, operator:, value:) # @param measurement [String] The name of the column. # # @param operator [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::NumericColumnFilter::Operator] # # @param value [Float, nil] # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::NumericColumnFilter#operator module Operator extend Openlayer::Internal::Type::Enum GREATER = :> GREATER_OR_EQUALS = :">=" IS = :is LESS = :< LESS_OR_EQUALS = :"<=" NOT_EQUALS = :"!=" # @!method self.values # @return [Array<Symbol>] end end class StringColumnFilter < Openlayer::Internal::Type::BaseModel # @!attribute measurement # The name of the column. # # @return [String] required :measurement, String # @!attribute operator # # @return [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter::Operator] required :operator, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter::Operator } # @!attribute value # # @return [String, Boolean] required :value, union: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter::Value } # @!method initialize(measurement:, operator:, value:) # @param measurement [String] The name of the column. # # @param operator [Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter::Operator] # # @param value [String, Boolean] # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter#operator module Operator extend Openlayer::Internal::Type::Enum IS = :is NOT_EQUALS = :"!=" # @!method self.values # @return [Array<Symbol>] end # @see Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter#value module Value extend Openlayer::Internal::Type::Union variant String variant Openlayer::Internal::Type::Boolean # @!method self.variants # @return [Array(String, Boolean)] end end # @!method self.variants # @return [Array(Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::SetColumnFilter, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::NumericColumnFilter, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody::ColumnFilter::StringColumnFilter)] end end end |
Instance Attribute Details
#expected_values ⇒ Array<Openlayer::Models::InferencePipelines::TestResultListResponse::Item::ExpectedValue>?
33 34 35 |
# File 'lib/openlayer/models/inference_pipelines/test_result_list_response.rb', line 33 optional :expected_values, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::InferencePipelines::TestResultListResponse::Item::ExpectedValue] }, api_name: :expectedValues |
#goal ⇒ Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal?
40 |
# File 'lib/openlayer/models/inference_pipelines/test_result_list_response.rb', line 40 optional :goal, -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Goal } |
#rows ⇒ String?
The URL to the rows of the test result.
46 |
# File 'lib/openlayer/models/inference_pipelines/test_result_list_response.rb', line 46 optional :rows, String |
#rows_body ⇒ Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody?
The body of the rows request.
52 53 54 55 |
# File 'lib/openlayer/models/inference_pipelines/test_result_list_response.rb', line 52 optional :rows_body, -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::RowsBody }, api_name: :rowsBody, nil?: true |
#status ⇒ Symbol, Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Status
The status of the test.
22 |
# File 'lib/openlayer/models/inference_pipelines/test_result_list_response.rb', line 22 required :status, enum: -> { Openlayer::Models::InferencePipelines::TestResultListResponse::Item::Status } |
#status_message ⇒ String?
The status message.
28 |
# File 'lib/openlayer/models/inference_pipelines/test_result_list_response.rb', line 28 required :status_message, String, api_name: :statusMessage, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/inference_pipelines/test_result_list_response.rb', line 148
|