Class: Openlayer::Models::ProjectListResponse::Item
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::ProjectListResponse::Item
- Defined in:
- lib/openlayer/models/project_list_response.rb,
sig/openlayer/models/project_list_response.rbs
Defined Under Namespace
Modules: Source, TaskType Classes: GitRepo, Links
Instance Attribute Summary collapse
-
#creator_id ⇒ String?
Returns the value of attribute creator_id.
-
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project.
-
#date_created ⇒ Time
Returns the value of attribute date_created.
-
#date_updated ⇒ Time
Returns the value of attribute date_updated.
-
#description ⇒ String?
The project description.
-
#development_goal_count ⇒ Integer
Returns the value of attribute development_goal_count.
-
#git_repo ⇒ Openlayer::Models::ProjectListResponse::Item::GitRepo?
Returns the value of attribute git_repo.
-
#goal_count ⇒ Integer
Returns the value of attribute goal_count.
-
#id ⇒ String
Returns the value of attribute id.
-
#inference_pipeline_count ⇒ Integer
Returns the value of attribute inference_pipeline_count.
-
#links ⇒ Openlayer::Models::ProjectListResponse::Item::Links
Returns the value of attribute links.
-
#model_developer ⇒ String?
Who developed the model used in this project.
-
#model_types ⇒ Array<String>?
The kinds of model used in this project.
-
#monitoring_goal_count ⇒ Integer
Returns the value of attribute monitoring_goal_count.
-
#name ⇒ String
The project name.
-
#purpose ⇒ String?
What the system in this project is intended to do.
-
#source ⇒ Openlayer::Models::ProjectListResponse::Item::source?
Returns the value of attribute source.
-
#task_type ⇒ Symbol, Openlayer::Models::ProjectListResponse::Item::TaskType
The task type of the project.
-
#version_count ⇒ Integer
Returns the value of attribute version_count.
-
#workspace_id ⇒ String?
Returns the value of attribute workspace_id.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(app:) ⇒ Object
constructor
Links to the project.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app:) ⇒ Object
Links to the project.
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/openlayer/models/project_list_response.rb', line 15 class Item < Openlayer::Internal::Type::BaseModel # @!attribute name # The project name. # # @return [String] required :name, String # @!attribute task_type # The task type of the project. # # @return [Symbol, Openlayer::Models::ProjectListResponse::Item::TaskType] required :task_type, enum: -> { Openlayer::Models::ProjectListResponse::Item::TaskType }, api_name: :taskType # @!attribute data_retention_days # Number of days to retain monitoring data for this project. Null means data is # retained indefinitely. # # @return [Integer, nil] optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true # @!attribute description # The project description. # # @return [String, nil] optional :description, String, nil?: true # @!attribute model_developer # Who developed the model used in this project. # # @return [String, nil] optional :model_developer, String, api_name: :modelDeveloper, nil?: true # @!attribute model_types # The kinds of model used in this project. # # @return [Array<String>, nil] optional :model_types, Openlayer::Internal::Type::ArrayOf[String], api_name: :modelTypes, nil?: true # @!attribute purpose # What the system in this project is intended to do. # # @return [String, nil] optional :purpose, String, nil?: true response_only do # @!attribute id # The project id. # # @return [String] required :id, String # @!attribute creator_id # The project creator id. # # @return [String, nil] required :creator_id, String, api_name: :creatorId, nil?: true # @!attribute date_created # The project creation date. # # @return [Time] required :date_created, Time, api_name: :dateCreated # @!attribute date_updated # The project last updated date. # # @return [Time] required :date_updated, Time, api_name: :dateUpdated # @!attribute development_goal_count # The number of tests in the development mode of the project. # # @return [Integer] required :development_goal_count, Integer, api_name: :developmentGoalCount # @!attribute goal_count # The total number of tests in the project. # # @return [Integer] required :goal_count, Integer, api_name: :goalCount # @!attribute inference_pipeline_count # The number of inference pipelines in the project. # # @return [Integer] required :inference_pipeline_count, Integer, api_name: :inferencePipelineCount # @!attribute links # Links to the project. # # @return [Openlayer::Models::ProjectListResponse::Item::Links] required :links, -> { Openlayer::Models::ProjectListResponse::Item::Links } # @!attribute monitoring_goal_count # The number of tests in the monitoring mode of the project. # # @return [Integer] required :monitoring_goal_count, Integer, api_name: :monitoringGoalCount # @!attribute source # The source of the project. # # @return [Symbol, Openlayer::Models::ProjectListResponse::Item::Source, nil] required :source, enum: -> { Openlayer::Models::ProjectListResponse::Item::Source }, nil?: true # @!attribute version_count # The number of versions (commits) in the project. # # @return [Integer] required :version_count, Integer, api_name: :versionCount # @!attribute workspace_id # The workspace id. # # @return [String, nil] required :workspace_id, String, api_name: :workspaceId, nil?: true # @!attribute git_repo # # @return [Openlayer::Models::ProjectListResponse::Item::GitRepo, nil] optional :git_repo, -> { Openlayer::Models::ProjectListResponse::Item::GitRepo }, api_name: :gitRepo, nil?: true end # @!method initialize(id:, creator_id:, date_created:, date_updated:, development_goal_count:, goal_count:, inference_pipeline_count:, links:, monitoring_goal_count:, name:, source:, task_type:, version_count:, workspace_id:, data_retention_days: nil, description: nil, git_repo: nil, model_developer: nil, model_types: nil, purpose: nil) # Some parameter documentations has been truncated, see # {Openlayer::Models::ProjectListResponse::Item} for more details. # # @param id [String] The project id. # # @param creator_id [String, nil] The project creator id. # # @param date_created [Time] The project creation date. # # @param date_updated [Time] The project last updated date. # # @param development_goal_count [Integer] The number of tests in the development mode of the project. # # @param goal_count [Integer] The total number of tests in the project. # # @param inference_pipeline_count [Integer] The number of inference pipelines in the project. # # @param links [Openlayer::Models::ProjectListResponse::Item::Links] Links to the project. # # @param monitoring_goal_count [Integer] The number of tests in the monitoring mode of the project. # # @param name [String] The project name. # # @param source [Symbol, Openlayer::Models::ProjectListResponse::Item::Source, nil] The source of the project. # # @param task_type [Symbol, Openlayer::Models::ProjectListResponse::Item::TaskType] The task type of the project. # # @param version_count [Integer] The number of versions (commits) in the project. # # @param workspace_id [String, nil] The workspace id. # # @param data_retention_days [Integer, nil] Number of days to retain monitoring data for this project. Null means data is re # # @param description [String, nil] The project description. # # @param git_repo [Openlayer::Models::ProjectListResponse::Item::GitRepo, nil] # # @param model_developer [String, nil] Who developed the model used in this project. # # @param model_types [Array<String>, nil] The kinds of model used in this project. # # @param purpose [String, nil] What the system in this project is intended to do. # @see Openlayer::Models::ProjectListResponse::Item#links class Links < Openlayer::Internal::Type::BaseModel # @!attribute app # # @return [String] required :app, String # @!method initialize(app:) # Links to the project. # # @param app [String] end # The source of the project. # # @see Openlayer::Models::ProjectListResponse::Item#source module Source extend Openlayer::Internal::Type::Enum WEB = :web API = :api NULL = :null # @!method self.values # @return [Array<Symbol>] end # The task type of the project. # # @see Openlayer::Models::ProjectListResponse::Item#task_type module TaskType extend Openlayer::Internal::Type::Enum LLM_BASE = :"llm-base" TABULAR_CLASSIFICATION = :"tabular-classification" TABULAR_REGRESSION = :"tabular-regression" TEXT_CLASSIFICATION = :"text-classification" # @!method self.values # @return [Array<Symbol>] end # @see Openlayer::Models::ProjectListResponse::Item#git_repo class GitRepo < Openlayer::Internal::Type::BaseModel # @!attribute git_account_id # # @return [String] required :git_account_id, String, api_name: :gitAccountId # @!attribute git_id # # @return [Integer] required :git_id, Integer, api_name: :gitId # @!attribute branch # # @return [String, nil] optional :branch, String # @!attribute root_dir # # @return [String, nil] optional :root_dir, String, api_name: :rootDir response_only do # @!attribute id # # @return [String] required :id, String # @!attribute date_connected # # @return [Time] required :date_connected, Time, api_name: :dateConnected # @!attribute date_updated # # @return [Time] required :date_updated, Time, api_name: :dateUpdated # @!attribute name # # @return [String] required :name, String # @!attribute private # # @return [Boolean] required :private, Openlayer::Internal::Type::Boolean # @!attribute project_id # # @return [String] required :project_id, String, api_name: :projectId # @!attribute slug # # @return [String] required :slug, String # @!attribute url # # @return [String] required :url, String end # @!method initialize(id:, date_connected:, date_updated:, git_account_id:, git_id:, name:, private:, project_id:, slug:, url:, branch: nil, root_dir: nil) # @param id [String] # @param date_connected [Time] # @param date_updated [Time] # @param git_account_id [String] # @param git_id [Integer] # @param name [String] # @param private [Boolean] # @param project_id [String] # @param slug [String] # @param url [String] # @param branch [String] # @param root_dir [String] end end |
Instance Attribute Details
#creator_id ⇒ String?
Returns the value of attribute creator_id.
58 59 60 |
# File 'sig/openlayer/models/project_list_response.rbs', line 58 def creator_id @creator_id end |
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project. Null means data is retained indefinitely.
35 |
# File 'lib/openlayer/models/project_list_response.rb', line 35 optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true |
#date_created ⇒ Time
Returns the value of attribute date_created.
60 61 62 |
# File 'sig/openlayer/models/project_list_response.rbs', line 60 def date_created @date_created end |
#date_updated ⇒ Time
Returns the value of attribute date_updated.
62 63 64 |
# File 'sig/openlayer/models/project_list_response.rbs', line 62 def date_updated @date_updated end |
#description ⇒ String?
The project description.
41 |
# File 'lib/openlayer/models/project_list_response.rb', line 41 optional :description, String, nil?: true |
#development_goal_count ⇒ Integer
Returns the value of attribute development_goal_count.
64 65 66 |
# File 'sig/openlayer/models/project_list_response.rbs', line 64 def development_goal_count @development_goal_count end |
#git_repo ⇒ Openlayer::Models::ProjectListResponse::Item::GitRepo?
Returns the value of attribute git_repo.
80 81 82 |
# File 'sig/openlayer/models/project_list_response.rbs', line 80 def git_repo @git_repo end |
#goal_count ⇒ Integer
Returns the value of attribute goal_count.
66 67 68 |
# File 'sig/openlayer/models/project_list_response.rbs', line 66 def goal_count @goal_count end |
#id ⇒ String
Returns the value of attribute id.
56 57 58 |
# File 'sig/openlayer/models/project_list_response.rbs', line 56 def id @id end |
#inference_pipeline_count ⇒ Integer
Returns the value of attribute inference_pipeline_count.
68 69 70 |
# File 'sig/openlayer/models/project_list_response.rbs', line 68 def inference_pipeline_count @inference_pipeline_count end |
#links ⇒ Openlayer::Models::ProjectListResponse::Item::Links
Returns the value of attribute links.
70 71 72 |
# File 'sig/openlayer/models/project_list_response.rbs', line 70 def links @links end |
#model_developer ⇒ String?
Who developed the model used in this project.
47 |
# File 'lib/openlayer/models/project_list_response.rb', line 47 optional :model_developer, String, api_name: :modelDeveloper, nil?: true |
#model_types ⇒ Array<String>?
The kinds of model used in this project.
53 |
# File 'lib/openlayer/models/project_list_response.rb', line 53 optional :model_types, Openlayer::Internal::Type::ArrayOf[String], api_name: :modelTypes, nil?: true |
#monitoring_goal_count ⇒ Integer
Returns the value of attribute monitoring_goal_count.
72 73 74 |
# File 'sig/openlayer/models/project_list_response.rbs', line 72 def monitoring_goal_count @monitoring_goal_count end |
#name ⇒ String
The project name.
20 |
# File 'lib/openlayer/models/project_list_response.rb', line 20 required :name, String |
#purpose ⇒ String?
What the system in this project is intended to do.
59 |
# File 'lib/openlayer/models/project_list_response.rb', line 59 optional :purpose, String, nil?: true |
#source ⇒ Openlayer::Models::ProjectListResponse::Item::source?
Returns the value of attribute source.
74 75 76 |
# File 'sig/openlayer/models/project_list_response.rbs', line 74 def source @source end |
#task_type ⇒ Symbol, Openlayer::Models::ProjectListResponse::Item::TaskType
The task type of the project.
26 27 28 |
# File 'lib/openlayer/models/project_list_response.rb', line 26 required :task_type, enum: -> { Openlayer::Models::ProjectListResponse::Item::TaskType }, api_name: :taskType |
#version_count ⇒ Integer
Returns the value of attribute version_count.
76 77 78 |
# File 'sig/openlayer/models/project_list_response.rbs', line 76 def version_count @version_count end |
#workspace_id ⇒ String?
Returns the value of attribute workspace_id.
78 79 80 |
# File 'sig/openlayer/models/project_list_response.rbs', line 78 def workspace_id @workspace_id end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/project_list_response.rb', line 210
|
Instance Method Details
#to_hash ⇒ {
105 |
# File 'sig/openlayer/models/project_list_response.rbs', line 105
def to_hash: -> {
|