Class: Openlayer::Models::ProjectUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openlayer/models/project_update_params.rb,
sig/openlayer/models/project_update_params.rbs

Overview

See Also:

  • Openlayer::Resources::Projects#update

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Openlayer

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(project_id:, data_retention_days: nil, description: nil, model_developer: nil, model_types: nil, name: nil, purpose: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::ProjectUpdateParams for more details.

Parameters:

  • project_id (String)
  • data_retention_days (Integer, nil) (defaults to: nil)

    Number of days to retain monitoring data for this project. Null means data is re

  • description (String, nil) (defaults to: nil)

    The project description.

  • model_developer (String, nil) (defaults to: nil)

    Who developed the model used in this project.

  • model_types (Array<String>, nil) (defaults to: nil)

    The kinds of model used in this project.

  • name (String) (defaults to: nil)

    The project name.

  • purpose (String, nil) (defaults to: nil)

    What the system in this project is intended to do.

  • request_options (Openlayer::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openlayer/models/project_update_params.rb', line 52

Instance Attribute Details

#data_retention_daysInteger?

Number of days to retain monitoring data for this project. Null means data is retained indefinitely.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


20
# File 'lib/openlayer/models/project_update_params.rb', line 20

optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true

#descriptionString?

The project description.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


26
# File 'lib/openlayer/models/project_update_params.rb', line 26

optional :description, String, nil?: true

#model_developerString?

Who developed the model used in this project.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/openlayer/models/project_update_params.rb', line 32

optional :model_developer, String, api_name: :modelDeveloper, nil?: true

#model_typesArray<String>?

The kinds of model used in this project.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


38
# File 'lib/openlayer/models/project_update_params.rb', line 38

optional :model_types, Openlayer::Internal::Type::ArrayOf[String], api_name: :modelTypes, nil?: true

#nameString?

The project name.

Parameters:

  • (String)

Returns:

  • (String, nil)


44
# File 'lib/openlayer/models/project_update_params.rb', line 44

optional :name, String

#project_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/openlayer/models/project_update_params.rb', line 13

required :project_id, String

#purposeString?

What the system in this project is intended to do.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


50
# File 'lib/openlayer/models/project_update_params.rb', line 50

optional :purpose, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


46
# File 'sig/openlayer/models/project_update_params.rbs', line 46

def to_hash: -> {