Class: Openlayer::Models::ProjectUpdateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::ProjectUpdateResponse
- Defined in:
- lib/openlayer/models/project_update_response.rb,
sig/openlayer/models/project_update_response.rbs
Overview
Defined Under Namespace
Modules: Source, TaskType Classes: GitRepo, Links
Instance Attribute Summary collapse
-
#creator_id ⇒ String?
Returns the value of attribute creator_id.
-
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project.
-
#date_created ⇒ Time
Returns the value of attribute date_created.
-
#date_updated ⇒ Time
Returns the value of attribute date_updated.
-
#description ⇒ String?
The project description.
-
#development_goal_count ⇒ Integer
Returns the value of attribute development_goal_count.
-
#git_repo ⇒ Openlayer::Models::ProjectUpdateResponse::GitRepo?
Returns the value of attribute git_repo.
-
#goal_count ⇒ Integer
Returns the value of attribute goal_count.
-
#id ⇒ String
Returns the value of attribute id.
-
#inference_pipeline_count ⇒ Integer
Returns the value of attribute inference_pipeline_count.
-
#links ⇒ Openlayer::Models::ProjectUpdateResponse::Links
Returns the value of attribute links.
-
#model_developer ⇒ String?
Who developed the model used in this project.
-
#model_types ⇒ Array<String>?
The kinds of model used in this project.
-
#monitoring_goal_count ⇒ Integer
Returns the value of attribute monitoring_goal_count.
-
#name ⇒ String
The project name.
-
#purpose ⇒ String?
What the system in this project is intended to do.
-
#source ⇒ Openlayer::Models::ProjectUpdateResponse::source?
Returns the value of attribute source.
-
#task_type ⇒ Symbol, Openlayer::Models::ProjectUpdateResponse::TaskType
The task type of the project.
-
#version_count ⇒ Integer
Returns the value of attribute version_count.
-
#workspace_id ⇒ String?
Returns the value of attribute workspace_id.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(app:) ⇒ Object
constructor
Links to the project.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app:) ⇒ Object
Links to the project.
|
|
# File 'lib/openlayer/models/project_update_response.rb', line 132
|
Instance Attribute Details
#creator_id ⇒ String?
Returns the value of attribute creator_id.
44 45 46 |
# File 'sig/openlayer/models/project_update_response.rbs', line 44 def creator_id @creator_id end |
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project. Null means data is retained indefinitely.
24 |
# File 'lib/openlayer/models/project_update_response.rb', line 24 optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true |
#date_created ⇒ Time
Returns the value of attribute date_created.
46 47 48 |
# File 'sig/openlayer/models/project_update_response.rbs', line 46 def date_created @date_created end |
#date_updated ⇒ Time
Returns the value of attribute date_updated.
48 49 50 |
# File 'sig/openlayer/models/project_update_response.rbs', line 48 def date_updated @date_updated end |
#description ⇒ String?
The project description.
30 |
# File 'lib/openlayer/models/project_update_response.rb', line 30 optional :description, String, nil?: true |
#development_goal_count ⇒ Integer
Returns the value of attribute development_goal_count.
50 51 52 |
# File 'sig/openlayer/models/project_update_response.rbs', line 50 def development_goal_count @development_goal_count end |
#git_repo ⇒ Openlayer::Models::ProjectUpdateResponse::GitRepo?
Returns the value of attribute git_repo.
66 67 68 |
# File 'sig/openlayer/models/project_update_response.rbs', line 66 def git_repo @git_repo end |
#goal_count ⇒ Integer
Returns the value of attribute goal_count.
52 53 54 |
# File 'sig/openlayer/models/project_update_response.rbs', line 52 def goal_count @goal_count end |
#id ⇒ String
Returns the value of attribute id.
42 43 44 |
# File 'sig/openlayer/models/project_update_response.rbs', line 42 def id @id end |
#inference_pipeline_count ⇒ Integer
Returns the value of attribute inference_pipeline_count.
54 55 56 |
# File 'sig/openlayer/models/project_update_response.rbs', line 54 def inference_pipeline_count @inference_pipeline_count end |
#links ⇒ Openlayer::Models::ProjectUpdateResponse::Links
Returns the value of attribute links.
56 57 58 |
# File 'sig/openlayer/models/project_update_response.rbs', line 56 def links @links end |
#model_developer ⇒ String?
Who developed the model used in this project.
36 |
# File 'lib/openlayer/models/project_update_response.rb', line 36 optional :model_developer, String, api_name: :modelDeveloper, nil?: true |
#model_types ⇒ Array<String>?
The kinds of model used in this project.
42 |
# File 'lib/openlayer/models/project_update_response.rb', line 42 optional :model_types, Openlayer::Internal::Type::ArrayOf[String], api_name: :modelTypes, nil?: true |
#monitoring_goal_count ⇒ Integer
Returns the value of attribute monitoring_goal_count.
58 59 60 |
# File 'sig/openlayer/models/project_update_response.rbs', line 58 def monitoring_goal_count @monitoring_goal_count end |
#name ⇒ String
The project name.
11 |
# File 'lib/openlayer/models/project_update_response.rb', line 11 required :name, String |
#purpose ⇒ String?
What the system in this project is intended to do.
48 |
# File 'lib/openlayer/models/project_update_response.rb', line 48 optional :purpose, String, nil?: true |
#source ⇒ Openlayer::Models::ProjectUpdateResponse::source?
Returns the value of attribute source.
60 61 62 |
# File 'sig/openlayer/models/project_update_response.rbs', line 60 def source @source end |
#task_type ⇒ Symbol, Openlayer::Models::ProjectUpdateResponse::TaskType
The task type of the project.
17 |
# File 'lib/openlayer/models/project_update_response.rb', line 17 required :task_type, enum: -> { Openlayer::Models::ProjectUpdateResponse::TaskType }, api_name: :taskType |
#version_count ⇒ Integer
Returns the value of attribute version_count.
62 63 64 |
# File 'sig/openlayer/models/project_update_response.rbs', line 62 def version_count @version_count end |
#workspace_id ⇒ String?
Returns the value of attribute workspace_id.
64 65 66 |
# File 'sig/openlayer/models/project_update_response.rbs', line 64 def workspace_id @workspace_id end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/project_update_response.rb', line 199
|
Instance Method Details
#to_hash ⇒ {
91 |
# File 'sig/openlayer/models/project_update_response.rbs', line 91
def to_hash: -> {
|