Module: Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend

Extended by:
Internal::Type::Union
Defined in:
lib/openlayer/models/projects/inference_pipeline_create_params.rb

Defined Under Namespace

Classes: BigQueryDataBackend, DatabricksDtlDataBackend, DefaultDataBackend, PostgresDataBackend, RedshiftDataBackend, SnowflakeDataBackend

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/projects/inference_pipeline_create_params.rb', line 204

Instance Method Details

#initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, inference_id_column_name: nil, latency_column_name: nil, timestamp_column_name: nil) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend::Config for more details.

Parameters:

  • ground_truth_column_name (String, nil) (defaults to: nil)

    Name of the column with the ground truths.

  • human_feedback_column_name (String, nil) (defaults to: nil)

    Name of the column with human feedback.

  • inference_id_column_name (String, nil) (defaults to: nil)

    Name of the column with the inference ids. This is useful if you want to update

  • latency_column_name (String, nil) (defaults to: nil)

    Name of the column with the latencies.

  • timestamp_column_name (String, nil) (defaults to: nil)

    Name of the column with the timestamps. Timestamps must be in UNIX sec format. I



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
# File 'lib/openlayer/models/projects/inference_pipeline_create_params.rb', line 61

module DataBackend
  extend Openlayer::Internal::Type::Union

  variant -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend }

  variant -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::DefaultDataBackend }

  variant -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend }

  variant -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend }

  variant -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend }

  variant -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend }

  class BigQueryDataBackend < Openlayer::Internal::Type::BaseModel
    # @!attribute backend_type
    #
    #   @return [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::BackendType]
    required :backend_type,
             enum: -> {
               Openlayer::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::BackendType
             },
             api_name: :backendType

    # @!attribute bigquery_connection_id
    #
    #   @return [String, nil]
    required :bigquery_connection_id, String, api_name: :bigqueryConnectionId, nil?: true

    # @!attribute dataset_id
    #
    #   @return [String]
    required :dataset_id, String, api_name: :datasetId

    # @!attribute project_id
    #
    #   @return [String]
    required :project_id, String, api_name: :projectId

    # @!attribute table_id
    #
    #   @return [String, nil]
    required :table_id, String, api_name: :tableId, nil?: true

    # @!attribute partition_type
    #
    #   @return [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::PartitionType, nil]
    optional :partition_type,
             enum: -> {
               Openlayer::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::PartitionType
             },
             api_name: :partitionType,
             nil?: true

    request_only do
      # @!attribute config
      #
      #   @return [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::Config]
      required :config,
               -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::Config }
    end

    # @!method initialize(backend_type:, bigquery_connection_id:, config:, dataset_id:, project_id:, table_id:, partition_type: nil)
    #   @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::BackendType]
    #   @param bigquery_connection_id [String, nil]
    #   @param config [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::Config]
    #   @param dataset_id [String]
    #   @param project_id [String]
    #   @param table_id [String, nil]
    #   @param partition_type [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::PartitionType, nil]

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend#backend_type
    module BackendType
      extend Openlayer::Internal::Type::Enum

      BIGQUERY = :bigquery

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend#config
    class Config < Openlayer::Internal::Type::BaseModel
      # @!attribute ground_truth_column_name
      #   Name of the column with the ground truths.
      #
      #   @return [String, nil]
      optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true

      # @!attribute human_feedback_column_name
      #   Name of the column with human feedback.
      #
      #   @return [String, nil]
      optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true

      # @!attribute latency_column_name
      #   Name of the column with the latencies.
      #
      #   @return [String, nil]
      optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true

      # @!attribute timestamp_column_name
      #   Name of the column with the timestamps. Timestamps must be in UNIX sec format.
      #   If not provided, the upload timestamp is used.
      #
      #   @return [String, nil]
      optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true

      request_only do
        # @!attribute inference_id_column_name
        #   Name of the column with the inference ids. This is useful if you want to update
        #   rows at a later point in time. If not provided, a unique id is generated by
        #   Openlayer.
        #
        #   @return [String, nil]
        optional :inference_id_column_name, String, api_name: :inferenceIdColumnName, nil?: true
      end

      # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, inference_id_column_name: nil, latency_column_name: nil, timestamp_column_name: nil)
      #   Some parameter documentations has been truncated, see
      #   {Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend::Config}
      #   for more details.
      #
      #   @param ground_truth_column_name [String, nil] Name of the column with the ground truths.
      #
      #   @param human_feedback_column_name [String, nil] Name of the column with human feedback.
      #
      #   @param inference_id_column_name [String, nil] Name of the column with the inference ids. This is useful if you want to update
      #
      #   @param latency_column_name [String, nil] Name of the column with the latencies.
      #
      #   @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I
    end

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend#partition_type
    module PartitionType
      extend Openlayer::Internal::Type::Enum

      DAY = :DAY
      MONTH = :MONTH
      YEAR = :YEAR

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  class DefaultDataBackend < Openlayer::Internal::Type::BaseModel
    # @!attribute backend_type
    #
    #   @return [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DefaultDataBackend::BackendType]
    required :backend_type,
             enum: -> {
               Openlayer::Projects::InferencePipelineCreateParams::DataBackend::DefaultDataBackend::BackendType
             },
             api_name: :backendType

    # @!method initialize(backend_type:)
    #   @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DefaultDataBackend::BackendType]

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DefaultDataBackend#backend_type
    module BackendType
      extend Openlayer::Internal::Type::Enum

      DEFAULT = :default

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  class SnowflakeDataBackend < Openlayer::Internal::Type::BaseModel
    # @!attribute backend_type
    #
    #   @return [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend::BackendType]
    required :backend_type,
             enum: -> {
               Openlayer::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend::BackendType
             },
             api_name: :backendType

    # @!attribute database
    #
    #   @return [String]
    required :database, String

    # @!attribute schema
    #
    #   @return [String]
    required :schema, String

    # @!attribute snowflake_connection_id
    #
    #   @return [String, nil]
    required :snowflake_connection_id, String, api_name: :snowflakeConnectionId, nil?: true

    # @!attribute table
    #
    #   @return [String, nil]
    required :table, String, nil?: true

    request_only do
      # @!attribute config
      #
      #   @return [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend::Config]
      required :config,
               -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend::Config }
    end

    # @!method initialize(backend_type:, config:, database:, schema:, snowflake_connection_id:, table:)
    #   @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend::BackendType]
    #   @param config [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend::Config]
    #   @param database [String]
    #   @param schema [String]
    #   @param snowflake_connection_id [String, nil]
    #   @param table [String, nil]

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend#backend_type
    module BackendType
      extend Openlayer::Internal::Type::Enum

      SNOWFLAKE = :snowflake

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend#config
    class Config < Openlayer::Internal::Type::BaseModel
      # @!attribute ground_truth_column_name
      #   Name of the column with the ground truths.
      #
      #   @return [String, nil]
      optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true

      # @!attribute human_feedback_column_name
      #   Name of the column with human feedback.
      #
      #   @return [String, nil]
      optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true

      # @!attribute latency_column_name
      #   Name of the column with the latencies.
      #
      #   @return [String, nil]
      optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true

      # @!attribute timestamp_column_name
      #   Name of the column with the timestamps. Timestamps must be in UNIX sec format.
      #   If not provided, the upload timestamp is used.
      #
      #   @return [String, nil]
      optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true

      request_only do
        # @!attribute inference_id_column_name
        #   Name of the column with the inference ids. This is useful if you want to update
        #   rows at a later point in time. If not provided, a unique id is generated by
        #   Openlayer.
        #
        #   @return [String, nil]
        optional :inference_id_column_name, String, api_name: :inferenceIdColumnName, nil?: true
      end

      # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, inference_id_column_name: nil, latency_column_name: nil, timestamp_column_name: nil)
      #   Some parameter documentations has been truncated, see
      #   {Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend::Config}
      #   for more details.
      #
      #   @param ground_truth_column_name [String, nil] Name of the column with the ground truths.
      #
      #   @param human_feedback_column_name [String, nil] Name of the column with human feedback.
      #
      #   @param inference_id_column_name [String, nil] Name of the column with the inference ids. This is useful if you want to update
      #
      #   @param latency_column_name [String, nil] Name of the column with the latencies.
      #
      #   @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I
    end
  end

  class DatabricksDtlDataBackend < Openlayer::Internal::Type::BaseModel
    # @!attribute backend_type
    #
    #   @return [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend::BackendType]
    required :backend_type,
             enum: -> {
               Openlayer::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend::BackendType
             },
             api_name: :backendType

    # @!attribute databricks_dtl_connection_id
    #
    #   @return [String, nil]
    required :databricks_dtl_connection_id, String, api_name: :databricksDtlConnectionId, nil?: true

    # @!attribute table_id
    #
    #   @return [String, nil]
    required :table_id, String, api_name: :tableId, nil?: true

    request_only do
      # @!attribute config
      #
      #   @return [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend::Config]
      required :config,
               -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend::Config }
    end

    # @!method initialize(backend_type:, config:, databricks_dtl_connection_id:, table_id:)
    #   @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend::BackendType]
    #   @param config [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend::Config]
    #   @param databricks_dtl_connection_id [String, nil]
    #   @param table_id [String, nil]

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend#backend_type
    module BackendType
      extend Openlayer::Internal::Type::Enum

      DATABRICKS_DTL = :databricks_dtl

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend#config
    class Config < Openlayer::Internal::Type::BaseModel
      # @!attribute ground_truth_column_name
      #   Name of the column with the ground truths.
      #
      #   @return [String, nil]
      optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true

      # @!attribute human_feedback_column_name
      #   Name of the column with human feedback.
      #
      #   @return [String, nil]
      optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true

      # @!attribute latency_column_name
      #   Name of the column with the latencies.
      #
      #   @return [String, nil]
      optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true

      # @!attribute timestamp_column_name
      #   Name of the column with the timestamps. Timestamps must be in UNIX sec format.
      #   If not provided, the upload timestamp is used.
      #
      #   @return [String, nil]
      optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true

      request_only do
        # @!attribute inference_id_column_name
        #   Name of the column with the inference ids. This is useful if you want to update
        #   rows at a later point in time. If not provided, a unique id is generated by
        #   Openlayer.
        #
        #   @return [String, nil]
        optional :inference_id_column_name, String, api_name: :inferenceIdColumnName, nil?: true
      end

      # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, inference_id_column_name: nil, latency_column_name: nil, timestamp_column_name: nil)
      #   Some parameter documentations has been truncated, see
      #   {Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend::Config}
      #   for more details.
      #
      #   @param ground_truth_column_name [String, nil] Name of the column with the ground truths.
      #
      #   @param human_feedback_column_name [String, nil] Name of the column with human feedback.
      #
      #   @param inference_id_column_name [String, nil] Name of the column with the inference ids. This is useful if you want to update
      #
      #   @param latency_column_name [String, nil] Name of the column with the latencies.
      #
      #   @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I
    end
  end

  class RedshiftDataBackend < Openlayer::Internal::Type::BaseModel
    # @!attribute backend_type
    #
    #   @return [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend::BackendType]
    required :backend_type,
             enum: -> {
               Openlayer::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend::BackendType
             },
             api_name: :backendType

    # @!attribute redshift_connection_id
    #
    #   @return [String, nil]
    required :redshift_connection_id, String, api_name: :redshiftConnectionId, nil?: true

    # @!attribute schema_name
    #
    #   @return [String]
    required :schema_name, String, api_name: :schemaName

    # @!attribute table_name
    #
    #   @return [String]
    required :table_name, String, api_name: :tableName

    request_only do
      # @!attribute config
      #
      #   @return [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend::Config]
      required :config,
               -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend::Config }
    end

    # @!method initialize(backend_type:, config:, redshift_connection_id:, schema_name:, table_name:)
    #   @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend::BackendType]
    #   @param config [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend::Config]
    #   @param redshift_connection_id [String, nil]
    #   @param schema_name [String]
    #   @param table_name [String]

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend#backend_type
    module BackendType
      extend Openlayer::Internal::Type::Enum

      REDSHIFT = :redshift

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend#config
    class Config < Openlayer::Internal::Type::BaseModel
      # @!attribute ground_truth_column_name
      #   Name of the column with the ground truths.
      #
      #   @return [String, nil]
      optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true

      # @!attribute human_feedback_column_name
      #   Name of the column with human feedback.
      #
      #   @return [String, nil]
      optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true

      # @!attribute latency_column_name
      #   Name of the column with the latencies.
      #
      #   @return [String, nil]
      optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true

      # @!attribute timestamp_column_name
      #   Name of the column with the timestamps. Timestamps must be in UNIX sec format.
      #   If not provided, the upload timestamp is used.
      #
      #   @return [String, nil]
      optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true

      request_only do
        # @!attribute inference_id_column_name
        #   Name of the column with the inference ids. This is useful if you want to update
        #   rows at a later point in time. If not provided, a unique id is generated by
        #   Openlayer.
        #
        #   @return [String, nil]
        optional :inference_id_column_name, String, api_name: :inferenceIdColumnName, nil?: true
      end

      # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, inference_id_column_name: nil, latency_column_name: nil, timestamp_column_name: nil)
      #   Some parameter documentations has been truncated, see
      #   {Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend::Config}
      #   for more details.
      #
      #   @param ground_truth_column_name [String, nil] Name of the column with the ground truths.
      #
      #   @param human_feedback_column_name [String, nil] Name of the column with human feedback.
      #
      #   @param inference_id_column_name [String, nil] Name of the column with the inference ids. This is useful if you want to update
      #
      #   @param latency_column_name [String, nil] Name of the column with the latencies.
      #
      #   @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I
    end
  end

  class PostgresDataBackend < Openlayer::Internal::Type::BaseModel
    # @!attribute backend_type
    #
    #   @return [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend::BackendType]
    required :backend_type,
             enum: -> {
               Openlayer::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend::BackendType
             },
             api_name: :backendType

    # @!attribute database
    #
    #   @return [String]
    required :database, String

    # @!attribute postgres_connection_id
    #
    #   @return [String, nil]
    required :postgres_connection_id, String, api_name: :postgresConnectionId, nil?: true

    # @!attribute schema
    #
    #   @return [String]
    required :schema, String

    # @!attribute table
    #
    #   @return [String, nil]
    required :table, String, nil?: true

    request_only do
      # @!attribute config
      #
      #   @return [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend::Config]
      required :config,
               -> { Openlayer::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend::Config }
    end

    # @!method initialize(backend_type:, config:, database:, postgres_connection_id:, schema:, table:)
    #   @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend::BackendType]
    #   @param config [Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend::Config]
    #   @param database [String]
    #   @param postgres_connection_id [String, nil]
    #   @param schema [String]
    #   @param table [String, nil]

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend#backend_type
    module BackendType
      extend Openlayer::Internal::Type::Enum

      POSTGRES = :postgres

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # @see Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend#config
    class Config < Openlayer::Internal::Type::BaseModel
      # @!attribute ground_truth_column_name
      #   Name of the column with the ground truths.
      #
      #   @return [String, nil]
      optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true

      # @!attribute human_feedback_column_name
      #   Name of the column with human feedback.
      #
      #   @return [String, nil]
      optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true

      # @!attribute latency_column_name
      #   Name of the column with the latencies.
      #
      #   @return [String, nil]
      optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true

      # @!attribute timestamp_column_name
      #   Name of the column with the timestamps. Timestamps must be in UNIX sec format.
      #   If not provided, the upload timestamp is used.
      #
      #   @return [String, nil]
      optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true

      request_only do
        # @!attribute inference_id_column_name
        #   Name of the column with the inference ids. This is useful if you want to update
        #   rows at a later point in time. If not provided, a unique id is generated by
        #   Openlayer.
        #
        #   @return [String, nil]
        optional :inference_id_column_name, String, api_name: :inferenceIdColumnName, nil?: true
      end

      # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, inference_id_column_name: nil, latency_column_name: nil, timestamp_column_name: nil)
      #   Some parameter documentations has been truncated, see
      #   {Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend::Config}
      #   for more details.
      #
      #   @param ground_truth_column_name [String, nil] Name of the column with the ground truths.
      #
      #   @param human_feedback_column_name [String, nil] Name of the column with human feedback.
      #
      #   @param inference_id_column_name [String, nil] Name of the column with the inference ids. This is useful if you want to update
      #
      #   @param latency_column_name [String, nil] Name of the column with the latencies.
      #
      #   @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I
    end
  end

  # @!method self.variants
  #   @return [Array(Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::BigQueryDataBackend, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DefaultDataBackend, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::SnowflakeDataBackend, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::DatabricksDtlDataBackend, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::RedshiftDataBackend, Openlayer::Models::Projects::InferencePipelineCreateParams::DataBackend::PostgresDataBackend)]
end