Class: Openlayer::Models::Projects::InferencePipelineCreateResponse::Project

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/projects/inference_pipeline_create_response.rb,
sig/openlayer/models/projects/inference_pipeline_create_response.rbs

Overview

See Also:

  • Openlayer::Models::Projects::InferencePipelineCreateResponse#project

Defined Under Namespace

Modules: Source, TaskType Classes: GitRepo, Links

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(app:) ⇒ Object

Links to the project.

Parameters:

  • app (String)


# File 'lib/openlayer/models/projects/inference_pipeline_create_response.rb', line 821

Instance Attribute Details

#creator_idString?

Returns the value of attribute creator_id.

Returns:

  • (String, nil)


647
648
649
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 647

def creator_id
  @creator_id
end

#data_retention_daysInteger?

Number of days to retain monitoring data for this project. Null means data is retained indefinitely.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


711
# File 'lib/openlayer/models/projects/inference_pipeline_create_response.rb', line 711

optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true

#date_createdTime

Returns the value of attribute date_created.

Returns:

  • (Time)


649
650
651
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 649

def date_created
  @date_created
end

#date_updatedTime

Returns the value of attribute date_updated.

Returns:

  • (Time)


651
652
653
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 651

def date_updated
  @date_updated
end

#descriptionString?

The project description.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


717
# File 'lib/openlayer/models/projects/inference_pipeline_create_response.rb', line 717

optional :description, String, nil?: true

#development_goal_countInteger

Returns the value of attribute development_goal_count.

Returns:

  • (Integer)


653
654
655
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 653

def development_goal_count
  @development_goal_count
end

#git_repoOpenlayer::Models::Projects::InferencePipelineCreateResponse::Project::GitRepo?

Returns the value of attribute git_repo.



669
670
671
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 669

def git_repo
  @git_repo
end

#goal_countInteger

Returns the value of attribute goal_count.

Returns:

  • (Integer)


655
656
657
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 655

def goal_count
  @goal_count
end

#idString

Returns the value of attribute id.

Returns:

  • (String)


645
646
647
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 645

def id
  @id
end

#inference_pipeline_countInteger

Returns the value of attribute inference_pipeline_count.

Returns:

  • (Integer)


657
658
659
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 657

def inference_pipeline_count
  @inference_pipeline_count
end

Returns the value of attribute links.



659
660
661
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 659

def links
  @links
end

#model_developerString?

Who developed the model used in this project.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


723
# File 'lib/openlayer/models/projects/inference_pipeline_create_response.rb', line 723

optional :model_developer, String, api_name: :modelDeveloper, nil?: true

#model_typesArray<String>?

The kinds of model used in this project.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


729
# File 'lib/openlayer/models/projects/inference_pipeline_create_response.rb', line 729

optional :model_types, Openlayer::Internal::Type::ArrayOf[String], api_name: :modelTypes, nil?: true

#monitoring_goal_countInteger

Returns the value of attribute monitoring_goal_count.

Returns:

  • (Integer)


661
662
663
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 661

def monitoring_goal_count
  @monitoring_goal_count
end

#nameString

The project name.

Parameters:

  • value (String)

Returns:

  • (String)


696
# File 'lib/openlayer/models/projects/inference_pipeline_create_response.rb', line 696

required :name, String

#purposeString?

What the system in this project is intended to do.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


735
# File 'lib/openlayer/models/projects/inference_pipeline_create_response.rb', line 735

optional :purpose, String, nil?: true

#sourceOpenlayer::Models::Projects::InferencePipelineCreateResponse::Project::source?

Returns the value of attribute source.

Returns:

  • (Openlayer::Models::Projects::InferencePipelineCreateResponse::Project::source, nil)


663
664
665
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 663

def source
  @source
end

#task_typeSymbol, Openlayer::Models::Projects::InferencePipelineCreateResponse::Project::TaskType

The task type of the project.

Parameters:

  • value (Openlayer::Models::Projects::InferencePipelineCreateResponse::Project::task_type)

Returns:



702
703
704
# File 'lib/openlayer/models/projects/inference_pipeline_create_response.rb', line 702

required :task_type,
enum: -> { Openlayer::Models::Projects::InferencePipelineCreateResponse::Project::TaskType },
api_name: :taskType

#version_countInteger

Returns the value of attribute version_count.

Returns:

  • (Integer)


665
666
667
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 665

def version_count
  @version_count
end

#workspace_idString?

Returns the value of attribute workspace_id.

Returns:

  • (String, nil)


667
668
669
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 667

def workspace_id
  @workspace_id
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/projects/inference_pipeline_create_response.rb', line 889

Instance Method Details

#to_hash{

Returns:

  • ({)


694
# File 'sig/openlayer/models/projects/inference_pipeline_create_response.rbs', line 694

def to_hash: -> {