Class: Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend
- Defined in:
- lib/openlayer/models/projects/inference_pipeline_list_response.rb
Defined Under Namespace
Modules: BackendType, PartitionType Classes: Config
Instance Attribute Summary collapse
- #backend_type ⇒ Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::BackendType
- #bigquery_connection_id ⇒ String?
- #dataset_id ⇒ String
- #partition_type ⇒ Symbol, ...
- #project_id ⇒ String
- #table_id ⇒ String?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, latency_column_name: nil, timestamp_column_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Config for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, latency_column_name: nil, timestamp_column_name: nil) ⇒ Object
Some parameter documentations has been truncated, see Config for more details.
|
|
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 272
|
Instance Attribute Details
#backend_type ⇒ Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::BackendType
240 241 242 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 240 required :backend_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::BackendType }, api_name: :backendType |
#bigquery_connection_id ⇒ String?
247 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 247 required :bigquery_connection_id, String, api_name: :bigqueryConnectionId, nil?: true |
#dataset_id ⇒ String
252 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 252 required :dataset_id, String, api_name: :datasetId |
#partition_type ⇒ Symbol, ...
267 268 269 270 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 267 optional :partition_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::PartitionType }, api_name: :partitionType, nil?: true |
#project_id ⇒ String
257 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 257 required :project_id, String, api_name: :projectId |
#table_id ⇒ String?
262 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 262 required :table_id, String, api_name: :tableId, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 286
|