Class: Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/projects/inference_pipeline_list_response.rb,
sig/openlayer/models/projects/inference_pipeline_list_response.rbs

Overview

See Also:

  • Openlayer::Models::Projects::InferencePipelineListResponse::Item#project

Defined Under Namespace

Modules: Source, TaskType Classes: GitRepo, Links

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(app:) ⇒ Object

Links to the project.

Parameters:

  • app (String)


# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 834

Instance Attribute Details

#creator_idString?

Returns the value of attribute creator_id.

Returns:

  • (String, nil)


663
664
665
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 663

def creator_id
  @creator_id
end

#data_retention_daysInteger?

Number of days to retain monitoring data for this project. Null means data is retained indefinitely.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


721
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 721

optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true

#date_createdTime

Returns the value of attribute date_created.

Returns:

  • (Time)


665
666
667
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 665

def date_created
  @date_created
end

#date_updatedTime

Returns the value of attribute date_updated.

Returns:

  • (Time)


667
668
669
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 667

def date_updated
  @date_updated
end

#descriptionString?

The project description.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


727
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 727

optional :description, String, nil?: true

#development_goal_countInteger

Returns the value of attribute development_goal_count.

Returns:

  • (Integer)


669
670
671
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 669

def development_goal_count
  @development_goal_count
end

#git_repoOpenlayer::Models::Projects::InferencePipelineListResponse::Item::Project::GitRepo?

Returns the value of attribute git_repo.



685
686
687
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 685

def git_repo
  @git_repo
end

#goal_countInteger

Returns the value of attribute goal_count.

Returns:

  • (Integer)


671
672
673
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 671

def goal_count
  @goal_count
end

#idString

Returns the value of attribute id.

Returns:

  • (String)


661
662
663
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 661

def id
  @id
end

#inference_pipeline_countInteger

Returns the value of attribute inference_pipeline_count.

Returns:

  • (Integer)


673
674
675
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 673

def inference_pipeline_count
  @inference_pipeline_count
end

Returns the value of attribute links.



675
676
677
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 675

def links
  @links
end

#model_developerString?

Who developed the model used in this project.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


733
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 733

optional :model_developer, String, api_name: :modelDeveloper, nil?: true

#model_typesArray<String>?

The kinds of model used in this project.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


739
740
741
742
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 739

optional :model_types,
Openlayer::Internal::Type::ArrayOf[String],
api_name: :modelTypes,
nil?: true

#monitoring_goal_countInteger

Returns the value of attribute monitoring_goal_count.

Returns:

  • (Integer)


677
678
679
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 677

def monitoring_goal_count
  @monitoring_goal_count
end

#nameString

The project name.

Parameters:

  • value (String)

Returns:

  • (String)


706
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 706

required :name, String

#purposeString?

What the system in this project is intended to do.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


748
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 748

optional :purpose, String, nil?: true

#sourceOpenlayer::Models::Projects::InferencePipelineListResponse::Item::Project::source?

Returns the value of attribute source.

Returns:

  • (Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::source, nil)


679
680
681
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 679

def source
  @source
end

#task_typeSymbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::TaskType

The task type of the project.

Parameters:

  • value (Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::task_type)

Returns:



712
713
714
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 712

required :task_type,
enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::TaskType },
api_name: :taskType

#version_countInteger

Returns the value of attribute version_count.

Returns:

  • (Integer)


681
682
683
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 681

def version_count
  @version_count
end

#workspace_idString?

Returns the value of attribute workspace_id.

Returns:

  • (String, nil)


683
684
685
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 683

def workspace_id
  @workspace_id
end

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 902

Instance Method Details

#to_hash{

Returns:

  • ({)


710
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 710

def to_hash: -> {