Class: Openlayer::Models::Projects::TestCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openlayer/models/projects/test_create_params.rb

Overview

Defined Under Namespace

Modules: Subtype, Type Classes: Threshold

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(project_id:, description:, name:, subtype:, thresholds:, type:, archived: nil, default_to_all_pipelines: nil, delay_window: nil, evaluation_window: nil, exclude_pipelines: nil, include_historical_data: nil, include_pipelines: nil, uses_ml_model: nil, uses_production_data: nil, uses_reference_dataset: nil, uses_training_dataset: nil, uses_validation_dataset: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::Projects::TestCreateParams for more details.

Parameters:

  • project_id (String)
  • description (Object, nil)

    The test description.

  • name (String)

    The test name.

  • subtype (Symbol, Openlayer::Models::Projects::TestCreateParams::Subtype)

    The test subtype.

  • thresholds (Array<Openlayer::Models::Projects::TestCreateParams::Threshold>)
  • type (Symbol, Openlayer::Models::Projects::TestCreateParams::Type)

    The test type.

  • archived (Boolean) (defaults to: nil)

    Whether the test is archived.

  • default_to_all_pipelines (Boolean, nil) (defaults to: nil)

    Whether to apply the test to all pipelines (data sources) or to a specific set o

  • delay_window (Float, nil) (defaults to: nil)

    The delay window in seconds. Only applies to tests that use production data.

  • evaluation_window (Float, nil) (defaults to: nil)

    The evaluation window in seconds. Only applies to tests that use production data

  • exclude_pipelines (Array<String>, nil) (defaults to: nil)

    Array of pipelines (data sources) to which the test should not be applied. Only

  • include_historical_data (Boolean, nil) (defaults to: nil)

    Whether to include historical data in the test result. Only applies to tests tha

  • include_pipelines (Array<String>, nil) (defaults to: nil)

    Array of pipelines (data sources) to which the test should be applied. Only appl

  • uses_ml_model (Boolean) (defaults to: nil)

    Whether the test uses an ML model.

  • uses_production_data (Boolean) (defaults to: nil)

    Whether the test uses production data (monitoring mode only).

  • uses_reference_dataset (Boolean) (defaults to: nil)

    Whether the test uses a reference dataset (monitoring mode only).

  • uses_training_dataset (Boolean) (defaults to: nil)

    Whether the test uses a training dataset.

  • uses_validation_dataset (Boolean) (defaults to: nil)

    Whether the test uses a validation dataset.

  • request_options (Openlayer::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openlayer/models/projects/test_create_params.rb', line 137

Instance Attribute Details

#archivedBoolean?

Whether the test is archived.

Returns:

  • (Boolean, nil)


50
# File 'lib/openlayer/models/projects/test_create_params.rb', line 50

optional :archived, Openlayer::Internal::Type::Boolean

#default_to_all_pipelinesBoolean?

Whether to apply the test to all pipelines (data sources) or to a specific set of pipelines. Only applies to tests that use production data.

Returns:

  • (Boolean, nil)


57
58
59
60
# File 'lib/openlayer/models/projects/test_create_params.rb', line 57

optional :default_to_all_pipelines,
Openlayer::Internal::Type::Boolean,
api_name: :defaultToAllPipelines,
nil?: true

#delay_windowFloat?

The delay window in seconds. Only applies to tests that use production data.

Returns:

  • (Float, nil)


66
# File 'lib/openlayer/models/projects/test_create_params.rb', line 66

optional :delay_window, Float, api_name: :delayWindow, nil?: true

#descriptionObject?

The test description.

Returns:

  • (Object, nil)


20
# File 'lib/openlayer/models/projects/test_create_params.rb', line 20

required :description, Openlayer::Internal::Type::Unknown, nil?: true

#evaluation_windowFloat?

The evaluation window in seconds. Only applies to tests that use production data.

Returns:

  • (Float, nil)


73
# File 'lib/openlayer/models/projects/test_create_params.rb', line 73

optional :evaluation_window, Float, api_name: :evaluationWindow, nil?: true

#exclude_pipelinesArray<String>?

Array of pipelines (data sources) to which the test should not be applied. Only applies to tests that use production data.

Returns:

  • (Array<String>, nil)


80
81
82
83
# File 'lib/openlayer/models/projects/test_create_params.rb', line 80

optional :exclude_pipelines,
Openlayer::Internal::Type::ArrayOf[String],
api_name: :excludePipelines,
nil?: true

#include_historical_dataBoolean?

Whether to include historical data in the test result. Only applies to tests that use production data.

Returns:

  • (Boolean, nil)


90
91
92
93
# File 'lib/openlayer/models/projects/test_create_params.rb', line 90

optional :include_historical_data,
Openlayer::Internal::Type::Boolean,
api_name: :includeHistoricalData,
nil?: true

#include_pipelinesArray<String>?

Array of pipelines (data sources) to which the test should be applied. Only applies to tests that use production data.

Returns:

  • (Array<String>, nil)


100
101
102
103
# File 'lib/openlayer/models/projects/test_create_params.rb', line 100

optional :include_pipelines,
Openlayer::Internal::Type::ArrayOf[String],
api_name: :includePipelines,
nil?: true

#nameString

The test name.

Returns:

  • (String)


26
# File 'lib/openlayer/models/projects/test_create_params.rb', line 26

required :name, String

#project_idString

Returns:

  • (String)


14
# File 'lib/openlayer/models/projects/test_create_params.rb', line 14

required :project_id, String

#subtypeSymbol, Openlayer::Models::Projects::TestCreateParams::Subtype

The test subtype.



32
# File 'lib/openlayer/models/projects/test_create_params.rb', line 32

required :subtype, enum: -> { Openlayer::Projects::TestCreateParams::Subtype }

#thresholdsArray<Openlayer::Models::Projects::TestCreateParams::Threshold>



37
38
# File 'lib/openlayer/models/projects/test_create_params.rb', line 37

required :thresholds,
-> { Openlayer::Internal::Type::ArrayOf[Openlayer::Projects::TestCreateParams::Threshold] }

#typeSymbol, Openlayer::Models::Projects::TestCreateParams::Type

The test type.



44
# File 'lib/openlayer/models/projects/test_create_params.rb', line 44

required :type, enum: -> { Openlayer::Projects::TestCreateParams::Type }

#uses_ml_modelBoolean?

Whether the test uses an ML model.

Returns:

  • (Boolean, nil)


109
# File 'lib/openlayer/models/projects/test_create_params.rb', line 109

optional :uses_ml_model, Openlayer::Internal::Type::Boolean, api_name: :usesMlModel

#uses_production_dataBoolean?

Whether the test uses production data (monitoring mode only).

Returns:

  • (Boolean, nil)


115
# File 'lib/openlayer/models/projects/test_create_params.rb', line 115

optional :uses_production_data, Openlayer::Internal::Type::Boolean, api_name: :usesProductionData

#uses_reference_datasetBoolean?

Whether the test uses a reference dataset (monitoring mode only).

Returns:

  • (Boolean, nil)


121
# File 'lib/openlayer/models/projects/test_create_params.rb', line 121

optional :uses_reference_dataset, Openlayer::Internal::Type::Boolean, api_name: :usesReferenceDataset

#uses_training_datasetBoolean?

Whether the test uses a training dataset.

Returns:

  • (Boolean, nil)


127
# File 'lib/openlayer/models/projects/test_create_params.rb', line 127

optional :uses_training_dataset, Openlayer::Internal::Type::Boolean, api_name: :usesTrainingDataset

#uses_validation_datasetBoolean?

Whether the test uses a validation dataset.

Returns:

  • (Boolean, nil)


133
134
135
# File 'lib/openlayer/models/projects/test_create_params.rb', line 133

optional :uses_validation_dataset,
Openlayer::Internal::Type::Boolean,
api_name: :usesValidationDataset

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/projects/test_create_params.rb', line 225