Class: Openlayer::Models::Storage::PresignedURLCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/storage/presigned_url_create_response.rb,
sig/openlayer/models/storage/presigned_url_create_response.rbs

Overview

See Also:

  • Openlayer::Resources::Storage::PresignedURL#create

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(storage_uri:, url:, fields: nil) ⇒ PresignedURLCreateResponse

Returns a new instance of PresignedURLCreateResponse.

Parameters:

  • storage_uri (String)

    The storage URI to send back to the backend after the upload was completed.

  • url (String)

    The presigned url.

  • fields (Object) (defaults to: nil)

    Fields to include in the body of the upload. Only needed by s3

  • storage_uri: (String)
  • url: (String)
  • fields: (top) (defaults to: nil)


# File 'lib/openlayer/models/storage/presigned_url_create_response.rb', line 26

Instance Attribute Details

#fieldsObject?

Fields to include in the body of the upload. Only needed by s3

Parameters:

  • (top)

Returns:

  • (Object, nil)


24
# File 'lib/openlayer/models/storage/presigned_url_create_response.rb', line 24

optional :fields, Openlayer::Internal::Type::Unknown

#storage_uriString

The storage URI to send back to the backend after the upload was completed.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/openlayer/models/storage/presigned_url_create_response.rb', line 12

required :storage_uri, String, api_name: :storageUri

#urlString

The presigned url.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/openlayer/models/storage/presigned_url_create_response.rb', line 18

required :url, String

Instance Method Details

#to_hash{ storage_uri: String, url: String, fields: top }

Returns:

  • ({ storage_uri: String, url: String, fields: top })


18
# File 'sig/openlayer/models/storage/presigned_url_create_response.rbs', line 18

def to_hash: -> { storage_uri: String, url: String, fields: top }