Class: Openlayer::Models::TestListResultsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openlayer/models/test_list_results_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(test_id:, end_timestamp: nil, include_insights: nil, inference_pipeline_id: nil, page: nil, per_page: nil, project_version_id: nil, start_timestamp: nil, status: nil, request_options: {}) ⇒ Object

Parameters:

  • test_id (String)
  • end_timestamp (Float) (defaults to: nil)

    Filter for results that use data starting before the end timestamp.

  • include_insights (Boolean) (defaults to: nil)

    Include the insights linked to each test result

  • inference_pipeline_id (String, nil) (defaults to: nil)

    Retrive test results for a specific inference pipeline.

  • page (Integer) (defaults to: nil)

    The page to return in a paginated query.

  • per_page (Integer) (defaults to: nil)

    Maximum number of items to return per page.

  • project_version_id (String, nil) (defaults to: nil)

    Retrive test results for a specific project version.

  • start_timestamp (Float) (defaults to: nil)

    Filter for results that use data ending after the start timestamp.

  • status (Array<String>) (defaults to: nil)

    Filter by status(es).

  • request_options (Openlayer::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openlayer/models/test_list_results_params.rb', line 63

Instance Attribute Details

#end_timestampFloat?

Filter for results that use data starting before the end timestamp.

Returns:

  • (Float, nil)


19
# File 'lib/openlayer/models/test_list_results_params.rb', line 19

optional :end_timestamp, Float

#include_insightsBoolean?

Include the insights linked to each test result

Returns:

  • (Boolean, nil)


25
# File 'lib/openlayer/models/test_list_results_params.rb', line 25

optional :include_insights, Openlayer::Internal::Type::Boolean

#inference_pipeline_idString?

Retrive test results for a specific inference pipeline.

Returns:

  • (String, nil)


31
# File 'lib/openlayer/models/test_list_results_params.rb', line 31

optional :inference_pipeline_id, String, nil?: true

#pageInteger?

The page to return in a paginated query.

Returns:

  • (Integer, nil)


37
# File 'lib/openlayer/models/test_list_results_params.rb', line 37

optional :page, Integer

#per_pageInteger?

Maximum number of items to return per page.

Returns:

  • (Integer, nil)


43
# File 'lib/openlayer/models/test_list_results_params.rb', line 43

optional :per_page, Integer

#project_version_idString?

Retrive test results for a specific project version.

Returns:

  • (String, nil)


49
# File 'lib/openlayer/models/test_list_results_params.rb', line 49

optional :project_version_id, String, nil?: true

#start_timestampFloat?

Filter for results that use data ending after the start timestamp.

Returns:

  • (Float, nil)


55
# File 'lib/openlayer/models/test_list_results_params.rb', line 55

optional :start_timestamp, Float

#statusArray<String>?

Filter by status(es).

Returns:

  • (Array<String>, nil)


61
# File 'lib/openlayer/models/test_list_results_params.rb', line 61

optional :status, Openlayer::Internal::Type::ArrayOf[String]

#test_idString

Returns:

  • (String)


13
# File 'lib/openlayer/models/test_list_results_params.rb', line 13

required :test_id, String