Class: Openlayer::Resources::Governance::RuleTags
- Inherits:
-
Object
- Object
- Openlayer::Resources::Governance::RuleTags
- Defined in:
- lib/openlayer/resources/governance/rule_tags.rb,
sig/openlayer/resources/governance/rule_tags.rbs
Instance Method Summary collapse
-
#initialize(client:) ⇒ RuleTags
constructor
private
A new instance of RuleTags.
-
#list(workspace_id, page: nil, per_page: nil, request_options: {}) ⇒ Openlayer::Models::Governance::RuleTagListResponse
List the rule tags in a workspace.
Constructor Details
#initialize(client:) ⇒ RuleTags
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of RuleTags.
41 42 43 |
# File 'lib/openlayer/resources/governance/rule_tags.rb', line 41 def initialize(client:) @client = client end |
Instance Method Details
#list(workspace_id, page: nil, per_page: nil, request_options: {}) ⇒ Openlayer::Models::Governance::RuleTagListResponse
List the rule tags in a workspace.
Tags group rules across frameworks, for example by team or by control family.
Use the ids returned here with the tags filter on
List rules.
26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/openlayer/resources/governance/rule_tags.rb', line 26 def list(workspace_id, params = {}) parsed, = Openlayer::Governance::RuleTagListParams.dump_request(params) query = Openlayer::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["workspaces/%1$s/rule-tags", workspace_id], query: query.transform_keys(per_page: "perPage"), model: Openlayer::Models::Governance::RuleTagListResponse, options: ) end |