Class: Openlayer::Models::Governance::Frameworks::DocumentListResponse::Item::Section::Subsection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::Frameworks::DocumentListResponse::Item::Section::Subsection
- Defined in:
- lib/openlayer/models/governance/frameworks/document_list_response.rb,
sig/openlayer/models/governance/frameworks/document_list_response.rbs
Defined Under Namespace
Classes: Rule
Instance Attribute Summary collapse
-
#id ⇒ String
Returns the value of attribute id.
-
#number ⇒ String
The subsection number as it appears in the source standard.
-
#rule_count ⇒ Integer?
readonly
Returns the value of attribute rule_count.
-
#rules ⇒ ::Array[Openlayer::Models::Governance::Frameworks::DocumentListResponse::Item::Section::Subsection::Rule]?
readonly
Returns the value of attribute rules.
-
#section_id ⇒ String
Returns the value of attribute section_id.
-
#sort_order ⇒ Integer
The position of the subsection within its section.
-
#text ⇒ String?
The subsection text.
-
#title ⇒ String
The subsection title.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #rule_count ⇒ Integer readonly
- #rules ⇒ Object readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
287 |
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 287
def initialize: (
|
Instance Attribute Details
#id ⇒ String
Returns the value of attribute id.
273 274 275 |
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 273 def id @id end |
#number ⇒ String
The subsection number as it appears in the source standard.
333 |
# File 'lib/openlayer/models/governance/frameworks/document_list_response.rb', line 333 required :number, String |
#rule_count ⇒ Integer? (readonly)
Returns the value of attribute rule_count.
277 278 279 |
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 277 def rule_count @rule_count end |
#rules ⇒ ::Array[Openlayer::Models::Governance::Frameworks::DocumentListResponse::Item::Section::Subsection::Rule]? (readonly)
Returns the value of attribute rules.
281 282 283 |
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 281 def rules @rules end |
#section_id ⇒ String
Returns the value of attribute section_id.
275 276 277 |
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 275 def section_id @section_id end |
#sort_order ⇒ Integer
The position of the subsection within its section.
339 |
# File 'lib/openlayer/models/governance/frameworks/document_list_response.rb', line 339 required :sort_order, Integer, api_name: :sortOrder |
#text ⇒ String?
The subsection text. This is the requirement your rules are mapped against.
351 |
# File 'lib/openlayer/models/governance/frameworks/document_list_response.rb', line 351 optional :text, String, nil?: true |
#title ⇒ String
The subsection title.
345 |
# File 'lib/openlayer/models/governance/frameworks/document_list_response.rb', line 345 required :title, String |
Instance Method Details
#rule_count= ⇒ Integer (readonly)
279 |
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 279
def rule_count=: (Integer) -> Integer
|
#rules= ⇒ Object (readonly)
283 |
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 283
def rules=: (
|
#to_hash ⇒ {
298 |
# File 'sig/openlayer/models/governance/frameworks/document_list_response.rbs', line 298
def to_hash: -> {
|