Class: Openlayer::Models::Governance::RuleResultListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleResultListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openlayer/models/governance/rule_result_list_params.rb,
sig/openlayer/models/governance/rule_result_list_params.rbs
Overview
Defined Under Namespace
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Openlayer
Instance Attribute Summary collapse
-
#enabled_framework_only ⇒ Boolean?
Only include items belonging to at least one enabled framework.
-
#framework_id ⇒ String?
Only include items belonging to this framework.
-
#include_unframed ⇒ Boolean?
Whether to include rules that are not part of any framework.
-
#page ⇒ Integer?
The page to return in a paginated query.
-
#per_page ⇒ Integer?
Maximum number of items to return per page.
-
#project_id ⇒ String?
Only include items that apply to this project.
-
#rule_id ⇒ String?
Only include results of this rule.
-
#scope ⇒ Symbol, ...
Only include rules with this scope.
-
#search_query ⇒ String?
Filter by a free-text search over names and descriptions.
-
#status ⇒ Symbol, ...
Only include items whose rule result has this compliance status.
-
#type ⇒ Symbol, ...
Only include rules of this type.
- #workspace_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(workspace_id:, enabled_framework_only: nil, framework_id: nil, include_unframed: nil, page: nil, per_page: nil, project_id: nil, rule_id: nil, scope: nil, search_query: nil, status: nil, type: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workspace_id:, enabled_framework_only: nil, framework_id: nil, include_unframed: nil, page: nil, per_page: nil, project_id: nil, rule_id: nil, scope: nil, search_query: nil, status: nil, type: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 82
|
Instance Attribute Details
#enabled_framework_only ⇒ Boolean?
Only include items belonging to at least one enabled framework.
20 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 20 optional :enabled_framework_only, Openlayer::Internal::Type::Boolean |
#framework_id ⇒ String?
Only include items belonging to this framework.
26 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 26 optional :framework_id, String |
#include_unframed ⇒ Boolean?
Whether to include rules that are not part of any framework.
32 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 32 optional :include_unframed, Openlayer::Internal::Type::Boolean |
#page ⇒ Integer?
The page to return in a paginated query.
38 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 38 optional :page, Integer |
#per_page ⇒ Integer?
Maximum number of items to return per page.
44 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 44 optional :per_page, Integer |
#project_id ⇒ String?
Only include items that apply to this project.
50 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 50 optional :project_id, String |
#rule_id ⇒ String?
Only include results of this rule.
56 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 56 optional :rule_id, String |
#scope ⇒ Symbol, ...
Only include rules with this scope.
62 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 62 optional :scope, enum: -> { Openlayer::Governance::RuleResultListParams::Scope } |
#search_query ⇒ String?
Filter by a free-text search over names and descriptions.
68 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 68 optional :search_query, String |
#status ⇒ Symbol, ...
Only include items whose rule result has this compliance status.
74 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 74 optional :status, enum: -> { Openlayer::Governance::RuleResultListParams::Status } |
#type ⇒ Symbol, ...
Only include rules of this type.
80 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 80 optional :type, enum: -> { Openlayer::Governance::RuleResultListParams::Type } |
#workspace_id ⇒ String
14 |
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 14 required :workspace_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/governance/rule_result_list_params.rb', line 116
|
Instance Method Details
#to_hash ⇒ {
93 |
# File 'sig/openlayer/models/governance/rule_result_list_params.rbs', line 93
def to_hash: -> {
|