Class: Openlayer::Models::Governance::RuleResultUpdateParams::BlockedBy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleResultUpdateParams::BlockedBy
- Defined in:
- lib/openlayer/models/governance/rule_result_update_params.rb,
sig/openlayer/models/governance/rule_result_update_params.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
- #id ⇒ String?
-
#status ⇒ Symbol, ...
The compliance status of the rule for this entity.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, status: nil) ⇒ Object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 66 class BlockedBy < Openlayer::Internal::Type::BaseModel # @!attribute id # # @return [String, nil] optional :id, String # @!attribute status # The compliance status of the rule for this entity. # # @return [Symbol, Openlayer::Models::Governance::RuleResultUpdateParams::BlockedBy::Status, nil] optional :status, enum: -> { Openlayer::Governance::RuleResultUpdateParams::BlockedBy::Status } # @!method initialize(id: nil, status: nil) # @param id [String] # # @param status [Symbol, Openlayer::Models::Governance::RuleResultUpdateParams::BlockedBy::Status] The compliance status of the rule for this entity. # The compliance status of the rule for this entity. # # @see Openlayer::Models::Governance::RuleResultUpdateParams::BlockedBy#status module Status extend Openlayer::Internal::Type::Enum RUNNING = :running PASSING = :passing FAILING = :failing SKIPPED = :skipped ERROR = :error PENDING = :pending DUE_SOON = :due_soon # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#id ⇒ String?
70 |
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 70 optional :id, String |
#status ⇒ Symbol, ...
The compliance status of the rule for this entity.
76 |
# File 'lib/openlayer/models/governance/rule_result_update_params.rb', line 76 optional :status, enum: -> { Openlayer::Governance::RuleResultUpdateParams::BlockedBy::Status } |
Instance Method Details
#to_hash ⇒ {
83 |
# File 'sig/openlayer/models/governance/rule_result_update_params.rbs', line 83
def to_hash: -> {
|