Class: Openlayer::Models::Governance::RuleStatRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleStatRetrieveResponse
- Defined in:
- lib/openlayer/models/governance/rule_stat_retrieve_response.rb,
sig/openlayer/models/governance/rule_stat_retrieve_response.rbs
Overview
Defined Under Namespace
Classes: RuleResults, Rules
Instance Attribute Summary collapse
-
#rule_results ⇒ Openlayer::Models::Governance::RuleStatRetrieveResponse::RuleResults
Counts of rule results, after any filters in the request, with breakdowns by the type and scope of the rule each result belongs to.
-
#rules ⇒ Openlayer::Models::Governance::RuleStatRetrieveResponse::Rules
Counts of the rules themselves, after any filters in the request.
Instance Method Summary collapse
- #initialize(total:, total_due_soon:, total_error:, total_failing:, total_passing:, total_pending:, total_running:, total_skipped:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(total:, total_due_soon:, total_error:, total_failing:, total_passing:, total_pending:, total_running:, total_skipped:) ⇒ Object
|
|
# File 'lib/openlayer/models/governance/rule_stat_retrieve_response.rb', line 23
|
Instance Attribute Details
#rule_results ⇒ Openlayer::Models::Governance::RuleStatRetrieveResponse::RuleResults
Counts of rule results, after any filters in the request, with breakdowns by the type and scope of the rule each result belongs to.
13 14 15 |
# File 'lib/openlayer/models/governance/rule_stat_retrieve_response.rb', line 13 required :rule_results, -> { Openlayer::Models::Governance::RuleStatRetrieveResponse::RuleResults }, api_name: :ruleResults |
#rules ⇒ Openlayer::Models::Governance::RuleStatRetrieveResponse::Rules
Counts of the rules themselves, after any filters in the request.
21 |
# File 'lib/openlayer/models/governance/rule_stat_retrieve_response.rb', line 21 required :rules, -> { Openlayer::Models::Governance::RuleStatRetrieveResponse::Rules } |
Instance Method Details
#to_hash ⇒ {
20 |
# File 'sig/openlayer/models/governance/rule_stat_retrieve_response.rbs', line 20
def to_hash: -> {
|