Class: Openlayer::Models::Governance::RuleUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Governance::RuleUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openlayer/models/governance/rule_update_params.rb,
sig/openlayer/models/governance/rule_update_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Openlayer
Instance Attribute Summary collapse
-
#assignee_id ⇒ String?
The user responsible for satisfying the rule.
-
#deactivated ⇒ Boolean?
Whether the rule is excluded from compliance calculations.
-
#description ⇒ String?
What the rule requires.
-
#name ⇒ String?
The rule name.
-
#renewal_cadence_days ⇒ Integer?
How often evidence must be renewed, in days.
- #rule_id ⇒ String
-
#tag_ids ⇒ Array<String>?
The ids of the rule tags to associate with the rule.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(rule_id:, assignee_id: nil, deactivated: nil, description: nil, name: nil, renewal_cadence_days: nil, tag_ids: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see RuleUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(rule_id:, assignee_id: nil, deactivated: nil, description: nil, name: nil, renewal_cadence_days: nil, tag_ids: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Openlayer::Models::Governance::RuleUpdateParams for more details.
|
|
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 55
|
Instance Attribute Details
#assignee_id ⇒ String?
The user responsible for satisfying the rule.
20 |
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 20 optional :assignee_id, String, api_name: :assigneeId, nil?: true |
#deactivated ⇒ Boolean?
Whether the rule is excluded from compliance calculations.
26 |
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 26 optional :deactivated, Openlayer::Internal::Type::Boolean |
#description ⇒ String?
What the rule requires.
32 |
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 32 optional :description, String, nil?: true |
#name ⇒ String?
The rule name.
38 |
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 38 optional :name, String |
#renewal_cadence_days ⇒ Integer?
How often evidence must be renewed, in days. Once evidence is older than this,
the rule result becomes due_soon and then failing.
45 |
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 45 optional :renewal_cadence_days, Integer, api_name: :renewalCadenceDays, nil?: true |
#rule_id ⇒ String
14 |
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 14 required :rule_id, String |
#tag_ids ⇒ Array<String>?
The ids of the rule tags to associate with the rule. Replaces the rule's tags.
Read them back from tags, and list the tags available in the workspace with
GET /workspaces/{workspaceId}/rule-tags.
53 |
# File 'lib/openlayer/models/governance/rule_update_params.rb', line 53 optional :tag_ids, Openlayer::Internal::Type::ArrayOf[String], api_name: :tagIds, nil?: true |
Instance Method Details
#to_hash ⇒ {
49 |
# File 'sig/openlayer/models/governance/rule_update_params.rbs', line 49
def to_hash: -> {
|