Class: Openlayer::Models::ProjectCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::ProjectCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openlayer/models/project_create_params.rb,
sig/openlayer/models/project_create_params.rbs
Overview
Defined Under Namespace
Modules: TaskType
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Openlayer
Instance Attribute Summary collapse
-
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project.
-
#description ⇒ String?
The project description.
-
#model_developer ⇒ String?
Who developed the model used in this project.
-
#model_types ⇒ Array<String>?
The kinds of model used in this project.
-
#name ⇒ String
The project name.
-
#purpose ⇒ String?
What the system in this project is intended to do.
-
#task_type ⇒ Symbol, Openlayer::Models::ProjectCreateParams::TaskType
The task type of the project.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(name:, task_type:, data_retention_days: nil, description: nil, model_developer: nil, model_types: nil, purpose: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProjectCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, task_type:, data_retention_days: nil, description: nil, model_developer: nil, model_types: nil, purpose: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Openlayer::Models::ProjectCreateParams for more details.
|
|
# File 'lib/openlayer/models/project_create_params.rb', line 53
|
Instance Attribute Details
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project. Null means data is retained indefinitely.
27 |
# File 'lib/openlayer/models/project_create_params.rb', line 27 optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true |
#description ⇒ String?
The project description.
33 |
# File 'lib/openlayer/models/project_create_params.rb', line 33 optional :description, String, nil?: true |
#model_developer ⇒ String?
Who developed the model used in this project.
39 |
# File 'lib/openlayer/models/project_create_params.rb', line 39 optional :model_developer, String, api_name: :modelDeveloper, nil?: true |
#model_types ⇒ Array<String>?
The kinds of model used in this project.
45 |
# File 'lib/openlayer/models/project_create_params.rb', line 45 optional :model_types, Openlayer::Internal::Type::ArrayOf[String], api_name: :modelTypes, nil?: true |
#name ⇒ String
The project name.
14 |
# File 'lib/openlayer/models/project_create_params.rb', line 14 required :name, String |
#purpose ⇒ String?
What the system in this project is intended to do.
51 |
# File 'lib/openlayer/models/project_create_params.rb', line 51 optional :purpose, String, nil?: true |
#task_type ⇒ Symbol, Openlayer::Models::ProjectCreateParams::TaskType
The task type of the project.
20 |
# File 'lib/openlayer/models/project_create_params.rb', line 20 required :task_type, enum: -> { Openlayer::ProjectCreateParams::TaskType }, api_name: :taskType |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/openlayer/models/project_create_params.rbs', line 44
def to_hash: -> {
|