Class: Openlayer::Models::ProjectUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::ProjectUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openlayer/models/project_update_params.rb,
sig/openlayer/models/project_update_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Openlayer
Instance Attribute Summary collapse
-
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project.
-
#description ⇒ String?
The project description.
-
#model_developer ⇒ String?
Who developed the model used in this project.
-
#model_types ⇒ Array<String>?
The kinds of model used in this project.
-
#name ⇒ String?
The project name.
- #project_id ⇒ String
-
#purpose ⇒ String?
What the system in this project is intended to do.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(project_id:, data_retention_days: nil, description: nil, model_developer: nil, model_types: nil, name: nil, purpose: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProjectUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(project_id:, data_retention_days: nil, description: nil, model_developer: nil, model_types: nil, name: nil, purpose: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Openlayer::Models::ProjectUpdateParams for more details.
|
|
# File 'lib/openlayer/models/project_update_params.rb', line 52
|
Instance Attribute Details
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project. Null means data is retained indefinitely.
20 |
# File 'lib/openlayer/models/project_update_params.rb', line 20 optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true |
#description ⇒ String?
The project description.
26 |
# File 'lib/openlayer/models/project_update_params.rb', line 26 optional :description, String, nil?: true |
#model_developer ⇒ String?
Who developed the model used in this project.
32 |
# File 'lib/openlayer/models/project_update_params.rb', line 32 optional :model_developer, String, api_name: :modelDeveloper, nil?: true |
#model_types ⇒ Array<String>?
The kinds of model used in this project.
38 |
# File 'lib/openlayer/models/project_update_params.rb', line 38 optional :model_types, Openlayer::Internal::Type::ArrayOf[String], api_name: :modelTypes, nil?: true |
#name ⇒ String?
The project name.
44 |
# File 'lib/openlayer/models/project_update_params.rb', line 44 optional :name, String |
#project_id ⇒ String
13 |
# File 'lib/openlayer/models/project_update_params.rb', line 13 required :project_id, String |
#purpose ⇒ String?
What the system in this project is intended to do.
50 |
# File 'lib/openlayer/models/project_update_params.rb', line 50 optional :purpose, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
46 |
# File 'sig/openlayer/models/project_update_params.rbs', line 46
def to_hash: -> {
|