Class: Openlayer::Models::Projects::InferencePipelineListResponse::Item
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Projects::InferencePipelineListResponse::Item
- Defined in:
- lib/openlayer/models/projects/inference_pipeline_list_response.rb
Defined Under Namespace
Modules: DataBackend, Status Classes: Links, Project, Workspace
Instance Attribute Summary collapse
- #data_backend ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend, ...
-
#description ⇒ String?
The inference pipeline description.
-
#name ⇒ String
The inference pipeline name.
- #project ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project?
- #workspace ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace?
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend)
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, date_connected:, date_updated:, git_account_id:, git_id:, name:, private:, project_id:, slug:, url:, branch: nil, root_dir: nil) ⇒ Object
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 17 class Item < Openlayer::Internal::Type::BaseModel # @!attribute description # The inference pipeline description. # # @return [String, nil] required :description, String, nil?: true # @!attribute name # The inference pipeline name. # # @return [String] required :name, String # @!attribute data_backend # # @return [Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend, nil] optional :data_backend, union: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend }, api_name: :dataBackend, nil?: true # @!attribute project # # @return [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project, nil] optional :project, -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project }, nil?: true # @!attribute workspace # # @return [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace, nil] optional :workspace, -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace }, nil?: true response_only do # @!attribute id # The inference pipeline id. # # @return [String] required :id, String # @!attribute date_created # The creation date. # # @return [Time] required :date_created, Time, api_name: :dateCreated # @!attribute date_last_evaluated # The last test evaluation date. # # @return [Time, nil] required :date_last_evaluated, Time, api_name: :dateLastEvaluated, nil?: true # @!attribute date_last_sample_received # The last data sample received date. # # @return [Time, nil] required :date_last_sample_received, Time, api_name: :dateLastSampleReceived, nil?: true # @!attribute date_of_next_evaluation # The next test evaluation date. # # @return [Time, nil] required :date_of_next_evaluation, Time, api_name: :dateOfNextEvaluation, nil?: true # @!attribute date_updated # The last updated date. # # @return [Time] required :date_updated, Time, api_name: :dateUpdated # @!attribute failing_goal_count # The number of tests failing. # # @return [Integer] required :failing_goal_count, Integer, api_name: :failingGoalCount # @!attribute links # # @return [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Links] required :links, -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Links } # @!attribute passing_goal_count # The number of tests passing. # # @return [Integer] required :passing_goal_count, Integer, api_name: :passingGoalCount # @!attribute project_id # The project id. # # @return [String] required :project_id, String, api_name: :projectId # @!attribute status # The status of test evaluation for the inference pipeline. # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Status] required :status, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Status } # @!attribute status_message # The status message of test evaluation for the inference pipeline. # # @return [String, nil] required :status_message, String, api_name: :statusMessage, nil?: true # @!attribute total_goal_count # The total number of tests. # # @return [Integer] required :total_goal_count, Integer, api_name: :totalGoalCount # @!attribute date_last_polled # The last time the data was polled. # # @return [Time, nil] optional :date_last_polled, Time, api_name: :dateLastPolled, nil?: true # @!attribute total_records_count # The total number of records in the data backend. # # @return [Integer, nil] optional :total_records_count, Integer, api_name: :totalRecordsCount, nil?: true # @!attribute workspace_id # The workspace id. # # @return [String, nil] optional :workspace_id, String, api_name: :workspaceId end # @!method initialize(id:, date_created:, date_last_evaluated:, date_last_sample_received:, date_of_next_evaluation:, date_updated:, description:, failing_goal_count:, links:, name:, passing_goal_count:, project_id:, status:, status_message:, total_goal_count:, data_backend: nil, date_last_polled: nil, project: nil, total_records_count: nil, workspace: nil, workspace_id: nil) # @param id [String] The inference pipeline id. # # @param date_created [Time] The creation date. # # @param date_last_evaluated [Time, nil] The last test evaluation date. # # @param date_last_sample_received [Time, nil] The last data sample received date. # # @param date_of_next_evaluation [Time, nil] The next test evaluation date. # # @param date_updated [Time] The last updated date. # # @param description [String, nil] The inference pipeline description. # # @param failing_goal_count [Integer] The number of tests failing. # # @param links [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Links] # # @param name [String] The inference pipeline name. # # @param passing_goal_count [Integer] The number of tests passing. # # @param project_id [String] The project id. # # @param status [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Status] The status of test evaluation for the inference pipeline. # # @param status_message [String, nil] The status message of test evaluation for the inference pipeline. # # @param total_goal_count [Integer] The total number of tests. # # @param data_backend [Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend, nil] # # @param date_last_polled [Time, nil] The last time the data was polled. # # @param project [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project, nil] # # @param total_records_count [Integer, nil] The total number of records in the data backend. # # @param workspace [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace, nil] # # @param workspace_id [String] The workspace id. # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item#links class Links < Openlayer::Internal::Type::BaseModel # @!attribute app # # @return [String] required :app, String # @!method initialize(app:) # @param app [String] end # The status of test evaluation for the inference pipeline. # # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item#status module Status extend Openlayer::Internal::Type::Enum QUEUED = :queued RUNNING = :running PAUSED = :paused FAILED = :failed COMPLETED = :completed UNKNOWN = :unknown # @!method self.values # @return [Array<Symbol>] end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item#data_backend module DataBackend extend Openlayer::Internal::Type::Union variant -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend } variant -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend } variant -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend } variant -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend } variant -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend } variant -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend } class BigQueryDataBackend < Openlayer::Internal::Type::BaseModel # @!attribute backend_type # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::BackendType] required :backend_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::BackendType }, api_name: :backendType # @!attribute bigquery_connection_id # # @return [String, nil] required :bigquery_connection_id, String, api_name: :bigqueryConnectionId, nil?: true # @!attribute dataset_id # # @return [String] required :dataset_id, String, api_name: :datasetId # @!attribute project_id # # @return [String] required :project_id, String, api_name: :projectId # @!attribute table_id # # @return [String, nil] required :table_id, String, api_name: :tableId, nil?: true # @!attribute partition_type # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::PartitionType, nil] optional :partition_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::PartitionType }, api_name: :partitionType, nil?: true # @!method initialize(backend_type:, bigquery_connection_id:, dataset_id:, project_id:, table_id:, partition_type: nil) # @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::BackendType] # @param bigquery_connection_id [String, nil] # @param dataset_id [String] # @param project_id [String] # @param table_id [String, nil] # @param partition_type [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::PartitionType, nil] # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend#backend_type module BackendType extend Openlayer::Internal::Type::Enum BIGQUERY = :bigquery # @!method self.values # @return [Array<Symbol>] end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend#config class Config < Openlayer::Internal::Type::BaseModel # @!attribute ground_truth_column_name # Name of the column with the ground truths. # # @return [String, nil] optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true # @!attribute human_feedback_column_name # Name of the column with human feedback. # # @return [String, nil] optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true # @!attribute latency_column_name # Name of the column with the latencies. # # @return [String, nil] optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true # @!attribute timestamp_column_name # Name of the column with the timestamps. Timestamps must be in UNIX sec format. # If not provided, the upload timestamp is used. # # @return [String, nil] optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, latency_column_name: nil, timestamp_column_name: nil) # Some parameter documentations has been truncated, see # {Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend::Config} # for more details. # # @param ground_truth_column_name [String, nil] Name of the column with the ground truths. # # @param human_feedback_column_name [String, nil] Name of the column with human feedback. # # @param latency_column_name [String, nil] Name of the column with the latencies. # # @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend#partition_type module PartitionType extend Openlayer::Internal::Type::Enum DAY = :DAY MONTH = :MONTH YEAR = :YEAR # @!method self.values # @return [Array<Symbol>] end end class DefaultDataBackend < Openlayer::Internal::Type::BaseModel # @!attribute backend_type # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend::BackendType] required :backend_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend::BackendType }, api_name: :backendType # @!method initialize(backend_type:) # @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend::BackendType] # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend#backend_type module BackendType extend Openlayer::Internal::Type::Enum DEFAULT = :default # @!method self.values # @return [Array<Symbol>] end end class SnowflakeDataBackend < Openlayer::Internal::Type::BaseModel # @!attribute backend_type # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend::BackendType] required :backend_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend::BackendType }, api_name: :backendType # @!attribute database # # @return [String] required :database, String # @!attribute schema # # @return [String] required :schema, String # @!attribute snowflake_connection_id # # @return [String, nil] required :snowflake_connection_id, String, api_name: :snowflakeConnectionId, nil?: true # @!attribute table # # @return [String, nil] required :table, String, nil?: true # @!method initialize(backend_type:, database:, schema:, snowflake_connection_id:, table:) # @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend::BackendType] # @param database [String] # @param schema [String] # @param snowflake_connection_id [String, nil] # @param table [String, nil] # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend#backend_type module BackendType extend Openlayer::Internal::Type::Enum SNOWFLAKE = :snowflake # @!method self.values # @return [Array<Symbol>] end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend#config class Config < Openlayer::Internal::Type::BaseModel # @!attribute ground_truth_column_name # Name of the column with the ground truths. # # @return [String, nil] optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true # @!attribute human_feedback_column_name # Name of the column with human feedback. # # @return [String, nil] optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true # @!attribute latency_column_name # Name of the column with the latencies. # # @return [String, nil] optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true # @!attribute timestamp_column_name # Name of the column with the timestamps. Timestamps must be in UNIX sec format. # If not provided, the upload timestamp is used. # # @return [String, nil] optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, latency_column_name: nil, timestamp_column_name: nil) # Some parameter documentations has been truncated, see # {Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend::Config} # for more details. # # @param ground_truth_column_name [String, nil] Name of the column with the ground truths. # # @param human_feedback_column_name [String, nil] Name of the column with human feedback. # # @param latency_column_name [String, nil] Name of the column with the latencies. # # @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I end end class DatabricksDtlDataBackend < Openlayer::Internal::Type::BaseModel # @!attribute backend_type # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend::BackendType] required :backend_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend::BackendType }, api_name: :backendType # @!attribute databricks_dtl_connection_id # # @return [String, nil] required :databricks_dtl_connection_id, String, api_name: :databricksDtlConnectionId, nil?: true # @!attribute table_id # # @return [String, nil] required :table_id, String, api_name: :tableId, nil?: true # @!method initialize(backend_type:, databricks_dtl_connection_id:, table_id:) # @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend::BackendType] # @param databricks_dtl_connection_id [String, nil] # @param table_id [String, nil] # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend#backend_type module BackendType extend Openlayer::Internal::Type::Enum DATABRICKS_DTL = :databricks_dtl # @!method self.values # @return [Array<Symbol>] end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend#config class Config < Openlayer::Internal::Type::BaseModel # @!attribute ground_truth_column_name # Name of the column with the ground truths. # # @return [String, nil] optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true # @!attribute human_feedback_column_name # Name of the column with human feedback. # # @return [String, nil] optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true # @!attribute latency_column_name # Name of the column with the latencies. # # @return [String, nil] optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true # @!attribute timestamp_column_name # Name of the column with the timestamps. Timestamps must be in UNIX sec format. # If not provided, the upload timestamp is used. # # @return [String, nil] optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, latency_column_name: nil, timestamp_column_name: nil) # Some parameter documentations has been truncated, see # {Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend::Config} # for more details. # # @param ground_truth_column_name [String, nil] Name of the column with the ground truths. # # @param human_feedback_column_name [String, nil] Name of the column with human feedback. # # @param latency_column_name [String, nil] Name of the column with the latencies. # # @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I end end class RedshiftDataBackend < Openlayer::Internal::Type::BaseModel # @!attribute backend_type # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend::BackendType] required :backend_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend::BackendType }, api_name: :backendType # @!attribute redshift_connection_id # # @return [String, nil] required :redshift_connection_id, String, api_name: :redshiftConnectionId, nil?: true # @!attribute schema_name # # @return [String] required :schema_name, String, api_name: :schemaName # @!attribute table_name # # @return [String] required :table_name, String, api_name: :tableName # @!method initialize(backend_type:, redshift_connection_id:, schema_name:, table_name:) # @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend::BackendType] # @param redshift_connection_id [String, nil] # @param schema_name [String] # @param table_name [String] # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend#backend_type module BackendType extend Openlayer::Internal::Type::Enum REDSHIFT = :redshift # @!method self.values # @return [Array<Symbol>] end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend#config class Config < Openlayer::Internal::Type::BaseModel # @!attribute ground_truth_column_name # Name of the column with the ground truths. # # @return [String, nil] optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true # @!attribute human_feedback_column_name # Name of the column with human feedback. # # @return [String, nil] optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true # @!attribute latency_column_name # Name of the column with the latencies. # # @return [String, nil] optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true # @!attribute timestamp_column_name # Name of the column with the timestamps. Timestamps must be in UNIX sec format. # If not provided, the upload timestamp is used. # # @return [String, nil] optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, latency_column_name: nil, timestamp_column_name: nil) # Some parameter documentations has been truncated, see # {Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend::Config} # for more details. # # @param ground_truth_column_name [String, nil] Name of the column with the ground truths. # # @param human_feedback_column_name [String, nil] Name of the column with human feedback. # # @param latency_column_name [String, nil] Name of the column with the latencies. # # @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I end end class PostgresDataBackend < Openlayer::Internal::Type::BaseModel # @!attribute backend_type # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend::BackendType] required :backend_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend::BackendType }, api_name: :backendType # @!attribute database # # @return [String] required :database, String # @!attribute postgres_connection_id # # @return [String, nil] required :postgres_connection_id, String, api_name: :postgresConnectionId, nil?: true # @!attribute schema # # @return [String] required :schema, String # @!attribute table # # @return [String, nil] required :table, String, nil?: true # @!method initialize(backend_type:, database:, postgres_connection_id:, schema:, table:) # @param backend_type [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend::BackendType] # @param database [String] # @param postgres_connection_id [String, nil] # @param schema [String] # @param table [String, nil] # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend#backend_type module BackendType extend Openlayer::Internal::Type::Enum POSTGRES = :postgres # @!method self.values # @return [Array<Symbol>] end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend#config class Config < Openlayer::Internal::Type::BaseModel # @!attribute ground_truth_column_name # Name of the column with the ground truths. # # @return [String, nil] optional :ground_truth_column_name, String, api_name: :groundTruthColumnName, nil?: true # @!attribute human_feedback_column_name # Name of the column with human feedback. # # @return [String, nil] optional :human_feedback_column_name, String, api_name: :humanFeedbackColumnName, nil?: true # @!attribute latency_column_name # Name of the column with the latencies. # # @return [String, nil] optional :latency_column_name, String, api_name: :latencyColumnName, nil?: true # @!attribute timestamp_column_name # Name of the column with the timestamps. Timestamps must be in UNIX sec format. # If not provided, the upload timestamp is used. # # @return [String, nil] optional :timestamp_column_name, String, api_name: :timestampColumnName, nil?: true # @!method initialize(ground_truth_column_name: nil, human_feedback_column_name: nil, latency_column_name: nil, timestamp_column_name: nil) # Some parameter documentations has been truncated, see # {Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend::Config} # for more details. # # @param ground_truth_column_name [String, nil] Name of the column with the ground truths. # # @param human_feedback_column_name [String, nil] Name of the column with human feedback. # # @param latency_column_name [String, nil] Name of the column with the latencies. # # @param timestamp_column_name [String, nil] Name of the column with the timestamps. Timestamps must be in UNIX sec format. I end end # @!method self.variants # @return [Array(Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend)] end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item#project class Project < Openlayer::Internal::Type::BaseModel # @!attribute name # The project name. # # @return [String] required :name, String # @!attribute task_type # The task type of the project. # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::TaskType] required :task_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::TaskType }, api_name: :taskType # @!attribute description # The project description. # # @return [String, nil] optional :description, String, nil?: true response_only do # @!attribute id # The project id. # # @return [String] required :id, String # @!attribute creator_id # The project creator id. # # @return [String, nil] required :creator_id, String, api_name: :creatorId, nil?: true # @!attribute date_created # The project creation date. # # @return [Time] required :date_created, Time, api_name: :dateCreated # @!attribute date_updated # The project last updated date. # # @return [Time] required :date_updated, Time, api_name: :dateUpdated # @!attribute development_goal_count # The number of tests in the development mode of the project. # # @return [Integer] required :development_goal_count, Integer, api_name: :developmentGoalCount # @!attribute goal_count # The total number of tests in the project. # # @return [Integer] required :goal_count, Integer, api_name: :goalCount # @!attribute inference_pipeline_count # The number of inference pipelines in the project. # # @return [Integer] required :inference_pipeline_count, Integer, api_name: :inferencePipelineCount # @!attribute links # Links to the project. # # @return [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::Links] required :links, -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::Links } # @!attribute monitoring_goal_count # The number of tests in the monitoring mode of the project. # # @return [Integer] required :monitoring_goal_count, Integer, api_name: :monitoringGoalCount # @!attribute source # The source of the project. # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::Source, nil] required :source, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::Source }, nil?: true # @!attribute version_count # The number of versions (commits) in the project. # # @return [Integer] required :version_count, Integer, api_name: :versionCount # @!attribute workspace_id # The workspace id. # # @return [String, nil] required :workspace_id, String, api_name: :workspaceId, nil?: true # @!attribute git_repo # # @return [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::GitRepo, nil] optional :git_repo, -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::GitRepo }, api_name: :gitRepo, nil?: true end # @!method initialize(id:, creator_id:, date_created:, date_updated:, development_goal_count:, goal_count:, inference_pipeline_count:, links:, monitoring_goal_count:, name:, source:, task_type:, version_count:, workspace_id:, description: nil, git_repo: nil) # @param id [String] The project id. # # @param creator_id [String, nil] The project creator id. # # @param date_created [Time] The project creation date. # # @param date_updated [Time] The project last updated date. # # @param development_goal_count [Integer] The number of tests in the development mode of the project. # # @param goal_count [Integer] The total number of tests in the project. # # @param inference_pipeline_count [Integer] The number of inference pipelines in the project. # # @param links [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::Links] Links to the project. # # @param monitoring_goal_count [Integer] The number of tests in the monitoring mode of the project. # # @param name [String] The project name. # # @param source [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::Source, nil] The source of the project. # # @param task_type [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::TaskType] The task type of the project. # # @param version_count [Integer] The number of versions (commits) in the project. # # @param workspace_id [String, nil] The workspace id. # # @param description [String, nil] The project description. # # @param git_repo [Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::GitRepo, nil] # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project#links class Links < Openlayer::Internal::Type::BaseModel # @!attribute app # # @return [String] required :app, String # @!method initialize(app:) # Links to the project. # # @param app [String] end # The source of the project. # # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project#source module Source extend Openlayer::Internal::Type::Enum WEB = :web API = :api NULL = :null # @!method self.values # @return [Array<Symbol>] end # The task type of the project. # # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project#task_type module TaskType extend Openlayer::Internal::Type::Enum LLM_BASE = :"llm-base" TABULAR_CLASSIFICATION = :"tabular-classification" TABULAR_REGRESSION = :"tabular-regression" TEXT_CLASSIFICATION = :"text-classification" # @!method self.values # @return [Array<Symbol>] end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project#git_repo class GitRepo < Openlayer::Internal::Type::BaseModel # @!attribute git_account_id # # @return [String] required :git_account_id, String, api_name: :gitAccountId # @!attribute git_id # # @return [Integer] required :git_id, Integer, api_name: :gitId # @!attribute branch # # @return [String, nil] optional :branch, String # @!attribute root_dir # # @return [String, nil] optional :root_dir, String, api_name: :rootDir response_only do # @!attribute id # # @return [String] required :id, String # @!attribute date_connected # # @return [Time] required :date_connected, Time, api_name: :dateConnected # @!attribute date_updated # # @return [Time] required :date_updated, Time, api_name: :dateUpdated # @!attribute name # # @return [String] required :name, String # @!attribute private # # @return [Boolean] required :private, Openlayer::Internal::Type::Boolean # @!attribute project_id # # @return [String] required :project_id, String, api_name: :projectId # @!attribute slug # # @return [String] required :slug, String # @!attribute url # # @return [String] required :url, String end # @!method initialize(id:, date_connected:, date_updated:, git_account_id:, git_id:, name:, private:, project_id:, slug:, url:, branch: nil, root_dir: nil) # @param id [String] # @param date_connected [Time] # @param date_updated [Time] # @param git_account_id [String] # @param git_id [Integer] # @param name [String] # @param private [Boolean] # @param project_id [String] # @param slug [String] # @param url [String] # @param branch [String] # @param root_dir [String] end end # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item#workspace class Workspace < Openlayer::Internal::Type::BaseModel # @!attribute name # The workspace name. # # @return [String] required :name, String # @!attribute slug # The workspace slug. # # @return [String] required :slug, String # @!attribute saml_only_access # Whether the workspace only allows SAML authentication. # # @return [Boolean, nil] optional :saml_only_access, Openlayer::Internal::Type::Boolean, api_name: :samlOnlyAccess # @!attribute wildcard_domains # # @return [Array<String>, nil] optional :wildcard_domains, Openlayer::Internal::Type::ArrayOf[String], api_name: :wildcardDomains response_only do # @!attribute id # The workspace id. # # @return [String] required :id, String # @!attribute creator_id # The workspace creator id. # # @return [String, nil] required :creator_id, String, api_name: :creatorId, nil?: true # @!attribute date_created # The workspace creation date. # # @return [Time] required :date_created, Time, api_name: :dateCreated # @!attribute date_updated # The workspace last updated date. # # @return [Time] required :date_updated, Time, api_name: :dateUpdated # @!attribute invite_count # The number of invites in the workspace. # # @return [Integer] required :invite_count, Integer, api_name: :inviteCount # @!attribute member_count # The number of members in the workspace. # # @return [Integer] required :member_count, Integer, api_name: :memberCount # @!attribute period_end_date # The end date of the current billing period. # # @return [Time, nil] required :period_end_date, Time, api_name: :periodEndDate, nil?: true # @!attribute period_start_date # The start date of the current billing period. # # @return [Time, nil] required :period_start_date, Time, api_name: :periodStartDate, nil?: true # @!attribute project_count # The number of projects in the workspace. # # @return [Integer] required :project_count, Integer, api_name: :projectCount # @!attribute status # # @return [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace::Status] required :status, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace::Status } # @!attribute monthly_usage # # @return [Array<Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace::MonthlyUsage>, nil] optional :monthly_usage, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace::MonthlyUsage] }, api_name: :monthlyUsage end # @!method initialize(id:, creator_id:, date_created:, date_updated:, invite_count:, member_count:, name:, period_end_date:, period_start_date:, project_count:, slug:, status:, monthly_usage: nil, saml_only_access: nil, wildcard_domains: nil) # @param id [String] The workspace id. # # @param creator_id [String, nil] The workspace creator id. # # @param date_created [Time] The workspace creation date. # # @param date_updated [Time] The workspace last updated date. # # @param invite_count [Integer] The number of invites in the workspace. # # @param member_count [Integer] The number of members in the workspace. # # @param name [String] The workspace name. # # @param period_end_date [Time, nil] The end date of the current billing period. # # @param period_start_date [Time, nil] The start date of the current billing period. # # @param project_count [Integer] The number of projects in the workspace. # # @param slug [String] The workspace slug. # # @param status [Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace::Status] # # @param monthly_usage [Array<Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace::MonthlyUsage>] # # @param saml_only_access [Boolean] Whether the workspace only allows SAML authentication. # # @param wildcard_domains [Array<String>] # @see Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace#status module Status extend Openlayer::Internal::Type::Enum ACTIVE = :active PAST_DUE = :past_due UNPAID = :unpaid CANCELED = :canceled INCOMPLETE = :incomplete INCOMPLETE_EXPIRED = :incomplete_expired TRIALING = :trialing PAUSED = :paused # @!method self.values # @return [Array<Symbol>] end class MonthlyUsage < Openlayer::Internal::Type::BaseModel # @!attribute execution_time_ms # # @return [Integer, nil] optional :execution_time_ms, Integer, api_name: :executionTimeMs, nil?: true # @!attribute month_year # # @return [Date, nil] optional :month_year, Date, api_name: :monthYear # @!attribute prediction_count # # @return [Integer, nil] optional :prediction_count, Integer, api_name: :predictionCount # @!method initialize(execution_time_ms: nil, month_year: nil, prediction_count: nil) # @param execution_time_ms [Integer, nil] # @param month_year [Date] # @param prediction_count [Integer] end end end |
Instance Attribute Details
#data_backend ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend, ...
33 34 35 36 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 33 optional :data_backend, union: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend }, api_name: :dataBackend, nil?: true |
#description ⇒ String?
The inference pipeline description.
22 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 22 required :description, String, nil?: true |
#name ⇒ String
The inference pipeline name.
28 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 28 required :name, String |
#project ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project?
41 42 43 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 41 optional :project, -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project }, nil?: true |
#workspace ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace?
48 49 50 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 48 optional :workspace, -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Workspace }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 216
|
.variants ⇒ Array(Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::BigQueryDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DefaultDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::SnowflakeDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::DatabricksDtlDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::RedshiftDataBackend, Openlayer::Models::Projects::InferencePipelineListResponse::Item::DataBackend::PostgresDataBackend)
|
|
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 696
|