Class: Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project
- Defined in:
- lib/openlayer/models/projects/inference_pipeline_list_response.rb,
sig/openlayer/models/projects/inference_pipeline_list_response.rbs
Overview
Defined Under Namespace
Modules: Source, TaskType Classes: GitRepo, Links
Instance Attribute Summary collapse
-
#creator_id ⇒ String?
Returns the value of attribute creator_id.
-
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project.
-
#date_created ⇒ Time
Returns the value of attribute date_created.
-
#date_updated ⇒ Time
Returns the value of attribute date_updated.
-
#description ⇒ String?
The project description.
-
#development_goal_count ⇒ Integer
Returns the value of attribute development_goal_count.
-
#git_repo ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::GitRepo?
Returns the value of attribute git_repo.
-
#goal_count ⇒ Integer
Returns the value of attribute goal_count.
-
#id ⇒ String
Returns the value of attribute id.
-
#inference_pipeline_count ⇒ Integer
Returns the value of attribute inference_pipeline_count.
-
#links ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::Links
Returns the value of attribute links.
-
#model_developer ⇒ String?
Who developed the model used in this project.
-
#model_types ⇒ Array<String>?
The kinds of model used in this project.
-
#monitoring_goal_count ⇒ Integer
Returns the value of attribute monitoring_goal_count.
-
#name ⇒ String
The project name.
-
#purpose ⇒ String?
What the system in this project is intended to do.
-
#source ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::source?
Returns the value of attribute source.
-
#task_type ⇒ Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::TaskType
The task type of the project.
-
#version_count ⇒ Integer
Returns the value of attribute version_count.
-
#workspace_id ⇒ String?
Returns the value of attribute workspace_id.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(app:) ⇒ Object
constructor
Links to the project.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app:) ⇒ Object
Links to the project.
|
|
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 834
|
Instance Attribute Details
#creator_id ⇒ String?
Returns the value of attribute creator_id.
663 664 665 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 663 def creator_id @creator_id end |
#data_retention_days ⇒ Integer?
Number of days to retain monitoring data for this project. Null means data is retained indefinitely.
721 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 721 optional :data_retention_days, Integer, api_name: :dataRetentionDays, nil?: true |
#date_created ⇒ Time
Returns the value of attribute date_created.
665 666 667 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 665 def date_created @date_created end |
#date_updated ⇒ Time
Returns the value of attribute date_updated.
667 668 669 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 667 def date_updated @date_updated end |
#description ⇒ String?
The project description.
727 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 727 optional :description, String, nil?: true |
#development_goal_count ⇒ Integer
Returns the value of attribute development_goal_count.
669 670 671 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 669 def development_goal_count @development_goal_count end |
#git_repo ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::GitRepo?
Returns the value of attribute git_repo.
685 686 687 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 685 def git_repo @git_repo end |
#goal_count ⇒ Integer
Returns the value of attribute goal_count.
671 672 673 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 671 def goal_count @goal_count end |
#id ⇒ String
Returns the value of attribute id.
661 662 663 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 661 def id @id end |
#inference_pipeline_count ⇒ Integer
Returns the value of attribute inference_pipeline_count.
673 674 675 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 673 def inference_pipeline_count @inference_pipeline_count end |
#links ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::Links
Returns the value of attribute links.
675 676 677 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 675 def links @links end |
#model_developer ⇒ String?
Who developed the model used in this project.
733 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 733 optional :model_developer, String, api_name: :modelDeveloper, nil?: true |
#model_types ⇒ Array<String>?
The kinds of model used in this project.
739 740 741 742 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 739 optional :model_types, Openlayer::Internal::Type::ArrayOf[String], api_name: :modelTypes, nil?: true |
#monitoring_goal_count ⇒ Integer
Returns the value of attribute monitoring_goal_count.
677 678 679 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 677 def monitoring_goal_count @monitoring_goal_count end |
#name ⇒ String
The project name.
706 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 706 required :name, String |
#purpose ⇒ String?
What the system in this project is intended to do.
748 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 748 optional :purpose, String, nil?: true |
#source ⇒ Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::source?
Returns the value of attribute source.
679 680 681 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 679 def source @source end |
#task_type ⇒ Symbol, Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::TaskType
The task type of the project.
712 713 714 |
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 712 required :task_type, enum: -> { Openlayer::Models::Projects::InferencePipelineListResponse::Item::Project::TaskType }, api_name: :taskType |
#version_count ⇒ Integer
Returns the value of attribute version_count.
681 682 683 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 681 def version_count @version_count end |
#workspace_id ⇒ String?
Returns the value of attribute workspace_id.
683 684 685 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 683 def workspace_id @workspace_id end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/projects/inference_pipeline_list_response.rb', line 902
|
Instance Method Details
#to_hash ⇒ {
710 |
# File 'sig/openlayer/models/projects/inference_pipeline_list_response.rbs', line 710
def to_hash: -> {
|