Class: Openlayer::Models::Projects::TestCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Projects::TestCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openlayer/models/projects/test_create_params.rb
Overview
Defined Under Namespace
Modules: Subtype, Type Classes: Threshold
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether the test is archived.
-
#default_to_all_pipelines ⇒ Boolean?
Whether to apply the test to all pipelines (data sources) or to a specific set of pipelines.
-
#delay_window ⇒ Float?
The delay window in seconds.
-
#description ⇒ Object?
The test description.
-
#evaluation_window ⇒ Float?
The evaluation window in seconds.
-
#exclude_pipelines ⇒ Array<String>?
Array of pipelines (data sources) to which the test should not be applied.
-
#include_historical_data ⇒ Boolean?
Whether to include historical data in the test result.
-
#include_pipelines ⇒ Array<String>?
Array of pipelines (data sources) to which the test should be applied.
-
#name ⇒ String
The test name.
- #project_id ⇒ String
-
#subtype ⇒ Symbol, Openlayer::Models::Projects::TestCreateParams::Subtype
The test subtype.
- #thresholds ⇒ Array<Openlayer::Models::Projects::TestCreateParams::Threshold>
-
#type ⇒ Symbol, Openlayer::Models::Projects::TestCreateParams::Type
The test type.
-
#uses_ml_model ⇒ Boolean?
Whether the test uses an ML model.
-
#uses_production_data ⇒ Boolean?
Whether the test uses production data (monitoring mode only).
-
#uses_reference_dataset ⇒ Boolean?
Whether the test uses a reference dataset (monitoring mode only).
-
#uses_training_dataset ⇒ Boolean?
Whether the test uses a training dataset.
-
#uses_validation_dataset ⇒ Boolean?
Whether the test uses a validation dataset.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(project_id:, description:, name:, subtype:, thresholds:, type:, archived: nil, default_to_all_pipelines: nil, delay_window: nil, evaluation_window: nil, exclude_pipelines: nil, include_historical_data: nil, include_pipelines: nil, uses_ml_model: nil, uses_production_data: nil, uses_reference_dataset: nil, uses_training_dataset: nil, uses_validation_dataset: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TestCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(project_id:, description:, name:, subtype:, thresholds:, type:, archived: nil, default_to_all_pipelines: nil, delay_window: nil, evaluation_window: nil, exclude_pipelines: nil, include_historical_data: nil, include_pipelines: nil, uses_ml_model: nil, uses_production_data: nil, uses_reference_dataset: nil, uses_training_dataset: nil, uses_validation_dataset: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Openlayer::Models::Projects::TestCreateParams for more details.
|
|
# File 'lib/openlayer/models/projects/test_create_params.rb', line 137
|
Instance Attribute Details
#archived ⇒ Boolean?
Whether the test is archived.
50 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 50 optional :archived, Openlayer::Internal::Type::Boolean |
#default_to_all_pipelines ⇒ Boolean?
Whether to apply the test to all pipelines (data sources) or to a specific set of pipelines. Only applies to tests that use production data.
57 58 59 60 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 57 optional :default_to_all_pipelines, Openlayer::Internal::Type::Boolean, api_name: :defaultToAllPipelines, nil?: true |
#delay_window ⇒ Float?
The delay window in seconds. Only applies to tests that use production data.
66 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 66 optional :delay_window, Float, api_name: :delayWindow, nil?: true |
#description ⇒ Object?
The test description.
20 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 20 required :description, Openlayer::Internal::Type::Unknown, nil?: true |
#evaluation_window ⇒ Float?
The evaluation window in seconds. Only applies to tests that use production data.
73 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 73 optional :evaluation_window, Float, api_name: :evaluationWindow, nil?: true |
#exclude_pipelines ⇒ Array<String>?
Array of pipelines (data sources) to which the test should not be applied. Only applies to tests that use production data.
80 81 82 83 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 80 optional :exclude_pipelines, Openlayer::Internal::Type::ArrayOf[String], api_name: :excludePipelines, nil?: true |
#include_historical_data ⇒ Boolean?
Whether to include historical data in the test result. Only applies to tests that use production data.
90 91 92 93 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 90 optional :include_historical_data, Openlayer::Internal::Type::Boolean, api_name: :includeHistoricalData, nil?: true |
#include_pipelines ⇒ Array<String>?
Array of pipelines (data sources) to which the test should be applied. Only applies to tests that use production data.
100 101 102 103 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 100 optional :include_pipelines, Openlayer::Internal::Type::ArrayOf[String], api_name: :includePipelines, nil?: true |
#name ⇒ String
The test name.
26 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 26 required :name, String |
#project_id ⇒ String
14 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 14 required :project_id, String |
#subtype ⇒ Symbol, Openlayer::Models::Projects::TestCreateParams::Subtype
The test subtype.
32 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 32 required :subtype, enum: -> { Openlayer::Projects::TestCreateParams::Subtype } |
#thresholds ⇒ Array<Openlayer::Models::Projects::TestCreateParams::Threshold>
37 38 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 37 required :thresholds, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Projects::TestCreateParams::Threshold] } |
#type ⇒ Symbol, Openlayer::Models::Projects::TestCreateParams::Type
The test type.
44 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 44 required :type, enum: -> { Openlayer::Projects::TestCreateParams::Type } |
#uses_ml_model ⇒ Boolean?
Whether the test uses an ML model.
109 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 109 optional :uses_ml_model, Openlayer::Internal::Type::Boolean, api_name: :usesMlModel |
#uses_production_data ⇒ Boolean?
Whether the test uses production data (monitoring mode only).
115 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 115 optional :uses_production_data, Openlayer::Internal::Type::Boolean, api_name: :usesProductionData |
#uses_reference_dataset ⇒ Boolean?
Whether the test uses a reference dataset (monitoring mode only).
121 |
# File 'lib/openlayer/models/projects/test_create_params.rb', line 121 optional :uses_reference_dataset, Openlayer::Internal::Type::Boolean, api_name: :usesReferenceDataset |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/projects/test_create_params.rb', line 225
|