Class: Openlayer::Models::Projects::TestCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openlayer/models/projects/test_create_response.rb

Overview

Defined Under Namespace

Modules: Subtype, Type Classes: Threshold

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, comment_count:, creator_id:, date_archived:, date_created:, date_updated:, description:, name:, number:, origin_project_version_id:, subtype:, suggested:, thresholds:, type:, archived: nil, default_to_all_pipelines: nil, delay_window: nil, evaluation_window: nil, exclude_pipelines: nil, include_historical_data: nil, include_pipelines: nil, uses_ml_model: nil, uses_production_data: nil, uses_reference_dataset: nil, uses_training_dataset: nil, uses_validation_dataset: nil) ⇒ Object

Some parameter documentations has been truncated, see Openlayer::Models::Projects::TestCreateResponse for more details.

Parameters:

  • id (String)

    The test id.

  • comment_count (Integer)

    The number of comments on the test.

  • creator_id (String, nil)

    The test creator id.

  • date_archived (Time, nil)

    The date the test was archived.

  • date_created (Time)

    The creation date.

  • date_updated (Time)

    The last updated date.

  • description (Object, nil)

    The test description.

  • name (String)

    The test name.

  • number (Integer)

    The test number.

  • origin_project_version_id (String, nil)

    The project version (commit) id where the test was created.

  • subtype (Symbol, Openlayer::Models::Projects::TestCreateResponse::Subtype)

    The test subtype.

  • suggested (Boolean)

    Whether the test is suggested or user-created.

  • thresholds (Array<Openlayer::Models::Projects::TestCreateResponse::Threshold>)
  • type (Symbol, Openlayer::Models::Projects::TestCreateResponse::Type)

    The test type.

  • archived (Boolean) (defaults to: nil)

    Whether the test is archived.

  • default_to_all_pipelines (Boolean, nil) (defaults to: nil)

    Whether to apply the test to all pipelines (data sources) or to a specific set o

  • delay_window (Float, nil) (defaults to: nil)

    The delay window in seconds. Only applies to tests that use production data.

  • evaluation_window (Float, nil) (defaults to: nil)

    The evaluation window in seconds. Only applies to tests that use production data

  • exclude_pipelines (Array<String>, nil) (defaults to: nil)

    Array of pipelines (data sources) to which the test should not be applied. Only

  • include_historical_data (Boolean, nil) (defaults to: nil)

    Whether to include historical data in the test result. Only applies to tests tha

  • include_pipelines (Array<String>, nil) (defaults to: nil)

    Array of pipelines (data sources) to which the test should be applied. Only appl

  • uses_ml_model (Boolean) (defaults to: nil)

    Whether the test uses an ML model.

  • uses_production_data (Boolean) (defaults to: nil)

    Whether the test uses production data (monitoring mode only).

  • uses_reference_dataset (Boolean) (defaults to: nil)

    Whether the test uses a reference dataset (monitoring mode only).

  • uses_training_dataset (Boolean) (defaults to: nil)

    Whether the test uses a training dataset.

  • uses_validation_dataset (Boolean) (defaults to: nil)

    Whether the test uses a validation dataset.



# File 'lib/openlayer/models/projects/test_create_response.rb', line 185

Instance Attribute Details

#archivedBoolean?

Whether the test is archived.

Returns:

  • (Boolean, nil)


42
# File 'lib/openlayer/models/projects/test_create_response.rb', line 42

optional :archived, Openlayer::Internal::Type::Boolean

#default_to_all_pipelinesBoolean?

Whether to apply the test to all pipelines (data sources) or to a specific set of pipelines. Only applies to tests that use production data.

Returns:

  • (Boolean, nil)


49
50
51
52
# File 'lib/openlayer/models/projects/test_create_response.rb', line 49

optional :default_to_all_pipelines,
Openlayer::Internal::Type::Boolean,
api_name: :defaultToAllPipelines,
nil?: true

#delay_windowFloat?

The delay window in seconds. Only applies to tests that use production data.

Returns:

  • (Float, nil)


58
# File 'lib/openlayer/models/projects/test_create_response.rb', line 58

optional :delay_window, Float, api_name: :delayWindow, nil?: true

#descriptionObject?

The test description.

Returns:

  • (Object, nil)


12
# File 'lib/openlayer/models/projects/test_create_response.rb', line 12

required :description, Openlayer::Internal::Type::Unknown, nil?: true

#evaluation_windowFloat?

The evaluation window in seconds. Only applies to tests that use production data.

Returns:

  • (Float, nil)


65
# File 'lib/openlayer/models/projects/test_create_response.rb', line 65

optional :evaluation_window, Float, api_name: :evaluationWindow, nil?: true

#exclude_pipelinesArray<String>?

Array of pipelines (data sources) to which the test should not be applied. Only applies to tests that use production data.

Returns:

  • (Array<String>, nil)


72
73
74
75
# File 'lib/openlayer/models/projects/test_create_response.rb', line 72

optional :exclude_pipelines,
Openlayer::Internal::Type::ArrayOf[String],
api_name: :excludePipelines,
nil?: true

#include_historical_dataBoolean?

Whether to include historical data in the test result. Only applies to tests that use production data.

Returns:

  • (Boolean, nil)


82
83
84
85
# File 'lib/openlayer/models/projects/test_create_response.rb', line 82

optional :include_historical_data,
Openlayer::Internal::Type::Boolean,
api_name: :includeHistoricalData,
nil?: true

#include_pipelinesArray<String>?

Array of pipelines (data sources) to which the test should be applied. Only applies to tests that use production data.

Returns:

  • (Array<String>, nil)


92
93
94
95
# File 'lib/openlayer/models/projects/test_create_response.rb', line 92

optional :include_pipelines,
Openlayer::Internal::Type::ArrayOf[String],
api_name: :includePipelines,
nil?: true

#nameString

The test name.

Returns:

  • (String)


18
# File 'lib/openlayer/models/projects/test_create_response.rb', line 18

required :name, String

#subtypeSymbol, Openlayer::Models::Projects::TestCreateResponse::Subtype

The test subtype.



24
# File 'lib/openlayer/models/projects/test_create_response.rb', line 24

required :subtype, enum: -> { Openlayer::Models::Projects::TestCreateResponse::Subtype }

#thresholdsArray<Openlayer::Models::Projects::TestCreateResponse::Threshold>



29
30
# File 'lib/openlayer/models/projects/test_create_response.rb', line 29

required :thresholds,
-> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Projects::TestCreateResponse::Threshold] }

#typeSymbol, Openlayer::Models::Projects::TestCreateResponse::Type

The test type.



36
# File 'lib/openlayer/models/projects/test_create_response.rb', line 36

required :type, enum: -> { Openlayer::Models::Projects::TestCreateResponse::Type }

#uses_ml_modelBoolean?

Whether the test uses an ML model.

Returns:

  • (Boolean, nil)


101
# File 'lib/openlayer/models/projects/test_create_response.rb', line 101

optional :uses_ml_model, Openlayer::Internal::Type::Boolean, api_name: :usesMlModel

#uses_production_dataBoolean?

Whether the test uses production data (monitoring mode only).

Returns:

  • (Boolean, nil)


107
# File 'lib/openlayer/models/projects/test_create_response.rb', line 107

optional :uses_production_data, Openlayer::Internal::Type::Boolean, api_name: :usesProductionData

#uses_reference_datasetBoolean?

Whether the test uses a reference dataset (monitoring mode only).

Returns:

  • (Boolean, nil)


113
# File 'lib/openlayer/models/projects/test_create_response.rb', line 113

optional :uses_reference_dataset, Openlayer::Internal::Type::Boolean, api_name: :usesReferenceDataset

#uses_training_datasetBoolean?

Whether the test uses a training dataset.

Returns:

  • (Boolean, nil)


119
# File 'lib/openlayer/models/projects/test_create_response.rb', line 119

optional :uses_training_dataset, Openlayer::Internal::Type::Boolean, api_name: :usesTrainingDataset

#uses_validation_datasetBoolean?

Whether the test uses a validation dataset.

Returns:

  • (Boolean, nil)


125
126
127
# File 'lib/openlayer/models/projects/test_create_response.rb', line 125

optional :uses_validation_dataset,
Openlayer::Internal::Type::Boolean,
api_name: :usesValidationDataset

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openlayer/models/projects/test_create_response.rb', line 289