Class: Openlayer::Models::Projects::TestCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::Projects::TestCreateResponse
- Defined in:
- lib/openlayer/models/projects/test_create_response.rb
Overview
Defined Under Namespace
Modules: Subtype, Type Classes: Threshold
Instance Attribute Summary collapse
-
#archived ⇒ Boolean?
Whether the test is archived.
-
#default_to_all_pipelines ⇒ Boolean?
Whether to apply the test to all pipelines (data sources) or to a specific set of pipelines.
-
#delay_window ⇒ Float?
The delay window in seconds.
-
#description ⇒ Object?
The test description.
-
#evaluation_window ⇒ Float?
The evaluation window in seconds.
-
#exclude_pipelines ⇒ Array<String>?
Array of pipelines (data sources) to which the test should not be applied.
-
#include_historical_data ⇒ Boolean?
Whether to include historical data in the test result.
-
#include_pipelines ⇒ Array<String>?
Array of pipelines (data sources) to which the test should be applied.
-
#name ⇒ String
The test name.
-
#subtype ⇒ Symbol, Openlayer::Models::Projects::TestCreateResponse::Subtype
The test subtype.
- #thresholds ⇒ Array<Openlayer::Models::Projects::TestCreateResponse::Threshold>
-
#type ⇒ Symbol, Openlayer::Models::Projects::TestCreateResponse::Type
The test type.
-
#uses_ml_model ⇒ Boolean?
Whether the test uses an ML model.
-
#uses_production_data ⇒ Boolean?
Whether the test uses production data (monitoring mode only).
-
#uses_reference_dataset ⇒ Boolean?
Whether the test uses a reference dataset (monitoring mode only).
-
#uses_training_dataset ⇒ Boolean?
Whether the test uses a training dataset.
-
#uses_validation_dataset ⇒ Boolean?
Whether the test uses a validation dataset.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, comment_count:, creator_id:, date_archived:, date_created:, date_updated:, description:, name:, number:, origin_project_version_id:, subtype:, suggested:, thresholds:, type:, archived: nil, default_to_all_pipelines: nil, delay_window: nil, evaluation_window: nil, exclude_pipelines: nil, include_historical_data: nil, include_pipelines: nil, uses_ml_model: nil, uses_production_data: nil, uses_reference_dataset: nil, uses_training_dataset: nil, uses_validation_dataset: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TestCreateResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, comment_count:, creator_id:, date_archived:, date_created:, date_updated:, description:, name:, number:, origin_project_version_id:, subtype:, suggested:, thresholds:, type:, archived: nil, default_to_all_pipelines: nil, delay_window: nil, evaluation_window: nil, exclude_pipelines: nil, include_historical_data: nil, include_pipelines: nil, uses_ml_model: nil, uses_production_data: nil, uses_reference_dataset: nil, uses_training_dataset: nil, uses_validation_dataset: nil) ⇒ Object
Some parameter documentations has been truncated, see Openlayer::Models::Projects::TestCreateResponse for more details.
|
|
# File 'lib/openlayer/models/projects/test_create_response.rb', line 185
|
Instance Attribute Details
#archived ⇒ Boolean?
Whether the test is archived.
42 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 42 optional :archived, Openlayer::Internal::Type::Boolean |
#default_to_all_pipelines ⇒ Boolean?
Whether to apply the test to all pipelines (data sources) or to a specific set of pipelines. Only applies to tests that use production data.
49 50 51 52 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 49 optional :default_to_all_pipelines, Openlayer::Internal::Type::Boolean, api_name: :defaultToAllPipelines, nil?: true |
#delay_window ⇒ Float?
The delay window in seconds. Only applies to tests that use production data.
58 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 58 optional :delay_window, Float, api_name: :delayWindow, nil?: true |
#description ⇒ Object?
The test description.
12 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 12 required :description, Openlayer::Internal::Type::Unknown, nil?: true |
#evaluation_window ⇒ Float?
The evaluation window in seconds. Only applies to tests that use production data.
65 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 65 optional :evaluation_window, Float, api_name: :evaluationWindow, nil?: true |
#exclude_pipelines ⇒ Array<String>?
Array of pipelines (data sources) to which the test should not be applied. Only applies to tests that use production data.
72 73 74 75 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 72 optional :exclude_pipelines, Openlayer::Internal::Type::ArrayOf[String], api_name: :excludePipelines, nil?: true |
#include_historical_data ⇒ Boolean?
Whether to include historical data in the test result. Only applies to tests that use production data.
82 83 84 85 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 82 optional :include_historical_data, Openlayer::Internal::Type::Boolean, api_name: :includeHistoricalData, nil?: true |
#include_pipelines ⇒ Array<String>?
Array of pipelines (data sources) to which the test should be applied. Only applies to tests that use production data.
92 93 94 95 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 92 optional :include_pipelines, Openlayer::Internal::Type::ArrayOf[String], api_name: :includePipelines, nil?: true |
#name ⇒ String
The test name.
18 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 18 required :name, String |
#subtype ⇒ Symbol, Openlayer::Models::Projects::TestCreateResponse::Subtype
The test subtype.
24 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 24 required :subtype, enum: -> { Openlayer::Models::Projects::TestCreateResponse::Subtype } |
#thresholds ⇒ Array<Openlayer::Models::Projects::TestCreateResponse::Threshold>
29 30 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 29 required :thresholds, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::Projects::TestCreateResponse::Threshold] } |
#type ⇒ Symbol, Openlayer::Models::Projects::TestCreateResponse::Type
The test type.
36 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 36 required :type, enum: -> { Openlayer::Models::Projects::TestCreateResponse::Type } |
#uses_ml_model ⇒ Boolean?
Whether the test uses an ML model.
101 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 101 optional :uses_ml_model, Openlayer::Internal::Type::Boolean, api_name: :usesMlModel |
#uses_production_data ⇒ Boolean?
Whether the test uses production data (monitoring mode only).
107 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 107 optional :uses_production_data, Openlayer::Internal::Type::Boolean, api_name: :usesProductionData |
#uses_reference_dataset ⇒ Boolean?
Whether the test uses a reference dataset (monitoring mode only).
113 |
# File 'lib/openlayer/models/projects/test_create_response.rb', line 113 optional :uses_reference_dataset, Openlayer::Internal::Type::Boolean, api_name: :usesReferenceDataset |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openlayer/models/projects/test_create_response.rb', line 289
|