Class: Openlayer::Models::TestEvaluateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::TestEvaluateResponse
- Defined in:
- lib/openlayer/models/test_evaluate_response.rb
Overview
Defined Under Namespace
Classes: Task
Instance Attribute Summary collapse
- #message ⇒ String
-
#pipeline_count ⇒ Integer
Number of inference pipelines the test was queued for evaluation on.
-
#requested_end_timestamp ⇒ Integer
The end timestamp you requested (in seconds).
-
#requested_start_timestamp ⇒ Integer
The start timestamp you requested (in seconds).
-
#tasks ⇒ Array<Openlayer::Models::TestEvaluateResponse::Task>
Array of background task information for each pipeline evaluation.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Openlayer::Internal::Type::BaseModel
Instance Attribute Details
#message ⇒ String
10 |
# File 'lib/openlayer/models/test_evaluate_response.rb', line 10 required :message, String |
#pipeline_count ⇒ Integer
Number of inference pipelines the test was queued for evaluation on
16 |
# File 'lib/openlayer/models/test_evaluate_response.rb', line 16 required :pipeline_count, Integer, api_name: :pipelineCount |
#requested_end_timestamp ⇒ Integer
The end timestamp you requested (in seconds)
22 |
# File 'lib/openlayer/models/test_evaluate_response.rb', line 22 required :requested_end_timestamp, Integer, api_name: :requestedEndTimestamp |
#requested_start_timestamp ⇒ Integer
The start timestamp you requested (in seconds)
28 |
# File 'lib/openlayer/models/test_evaluate_response.rb', line 28 required :requested_start_timestamp, Integer, api_name: :requestedStartTimestamp |
#tasks ⇒ Array<Openlayer::Models::TestEvaluateResponse::Task>
Array of background task information for each pipeline evaluation
34 |
# File 'lib/openlayer/models/test_evaluate_response.rb', line 34 required :tasks, -> { Openlayer::Internal::Type::ArrayOf[Openlayer::Models::TestEvaluateResponse::Task] } |