Class: Openlayer::Models::TestEvaluateResponse::Task
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::TestEvaluateResponse::Task
- Defined in:
- lib/openlayer/models/test_evaluate_response.rb
Instance Attribute Summary collapse
-
#pipeline_id ⇒ String
ID of the inference pipeline this task is for.
-
#task_result_id ⇒ String
ID of the background task.
-
#task_result_url ⇒ String
URL to check the status of this background task.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(pipeline_id:, task_result_id:, task_result_url:) ⇒ Object
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/openlayer/models/test_evaluate_response.rb', line 47 class Task < Openlayer::Internal::Type::BaseModel # @!attribute pipeline_id # ID of the inference pipeline this task is for # # @return [String] required :pipeline_id, String, api_name: :pipelineId # @!attribute task_result_id # ID of the background task # # @return [String] required :task_result_id, String, api_name: :taskResultId # @!attribute task_result_url # URL to check the status of this background task # # @return [String] required :task_result_url, String, api_name: :taskResultUrl # @!method initialize(pipeline_id:, task_result_id:, task_result_url:) # @param pipeline_id [String] ID of the inference pipeline this task is for # # @param task_result_id [String] ID of the background task # # @param task_result_url [String] URL to check the status of this background task end |
Instance Attribute Details
#pipeline_id ⇒ String
ID of the inference pipeline this task is for
52 |
# File 'lib/openlayer/models/test_evaluate_response.rb', line 52 required :pipeline_id, String, api_name: :pipelineId |
#task_result_id ⇒ String
ID of the background task
58 |
# File 'lib/openlayer/models/test_evaluate_response.rb', line 58 required :task_result_id, String, api_name: :taskResultId |
#task_result_url ⇒ String
URL to check the status of this background task
64 |
# File 'lib/openlayer/models/test_evaluate_response.rb', line 64 required :task_result_url, String, api_name: :taskResultUrl |