Class: Openlayer::Models::TestListResultsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Openlayer::Models::TestListResultsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openlayer/models/test_list_results_params.rb
Overview
Instance Attribute Summary collapse
-
#end_timestamp ⇒ Float?
Filter for results that use data starting before the end timestamp.
-
#include_insights ⇒ Boolean?
Include the insights linked to each test result.
-
#inference_pipeline_id ⇒ String?
Retrive test results for a specific inference pipeline.
-
#page ⇒ Integer?
The page to return in a paginated query.
-
#per_page ⇒ Integer?
Maximum number of items to return per page.
-
#project_version_id ⇒ String?
Retrive test results for a specific project version.
-
#start_timestamp ⇒ Float?
Filter for results that use data ending after the start timestamp.
-
#status ⇒ Array<String>?
Filter by status(es).
- #test_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(test_id:, end_timestamp: nil, include_insights: nil, inference_pipeline_id: nil, page: nil, per_page: nil, project_version_id: nil, start_timestamp: nil, status: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/openlayer/models/test_list_results_params.rb', line 63
|
Instance Attribute Details
#end_timestamp ⇒ Float?
Filter for results that use data starting before the end timestamp.
19 |
# File 'lib/openlayer/models/test_list_results_params.rb', line 19 optional :end_timestamp, Float |
#include_insights ⇒ Boolean?
Include the insights linked to each test result
25 |
# File 'lib/openlayer/models/test_list_results_params.rb', line 25 optional :include_insights, Openlayer::Internal::Type::Boolean |
#inference_pipeline_id ⇒ String?
Retrive test results for a specific inference pipeline.
31 |
# File 'lib/openlayer/models/test_list_results_params.rb', line 31 optional :inference_pipeline_id, String, nil?: true |
#page ⇒ Integer?
The page to return in a paginated query.
37 |
# File 'lib/openlayer/models/test_list_results_params.rb', line 37 optional :page, Integer |
#per_page ⇒ Integer?
Maximum number of items to return per page.
43 |
# File 'lib/openlayer/models/test_list_results_params.rb', line 43 optional :per_page, Integer |
#project_version_id ⇒ String?
Retrive test results for a specific project version.
49 |
# File 'lib/openlayer/models/test_list_results_params.rb', line 49 optional :project_version_id, String, nil?: true |
#start_timestamp ⇒ Float?
Filter for results that use data ending after the start timestamp.
55 |
# File 'lib/openlayer/models/test_list_results_params.rb', line 55 optional :start_timestamp, Float |
#status ⇒ Array<String>?
Filter by status(es).
61 |
# File 'lib/openlayer/models/test_list_results_params.rb', line 61 optional :status, Openlayer::Internal::Type::ArrayOf[String] |
#test_id ⇒ String
13 |
# File 'lib/openlayer/models/test_list_results_params.rb', line 13 required :test_id, String |