Class: Openlayer::Resources::Governance::Frameworks::Subsections
- Inherits:
-
Object
- Object
- Openlayer::Resources::Governance::Frameworks::Subsections
- Defined in:
- lib/openlayer/resources/governance/frameworks/subsections.rb,
sig/openlayer/resources/governance/frameworks/subsections.rbs
Instance Method Summary collapse
-
#initialize(client:) ⇒ Subsections
constructor
private
A new instance of Subsections.
-
#list_rules(subsection_id, framework_id:, include_results: nil, page: nil, per_page: nil, project_id: nil, status: nil, request_options: {}) ⇒ Openlayer::Models::Governance::Frameworks::SubsectionListRulesResponse
Some parameter documentations has been truncated, see Models::Governance::Frameworks::SubsectionListRulesParams for more details.
Constructor Details
#initialize(client:) ⇒ Subsections
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Subsections.
62 63 64 |
# File 'lib/openlayer/resources/governance/frameworks/subsections.rb', line 62 def initialize(client:) @client = client end |
Instance Method Details
#list_rules(subsection_id, framework_id:, include_results: nil, page: nil, per_page: nil, project_id: nil, status: nil, request_options: {}) ⇒ Openlayer::Models::Governance::Frameworks::SubsectionListRulesResponse
Some parameter documentations has been truncated, see Models::Governance::Frameworks::SubsectionListRulesParams for more details.
List the rules mapped to a subsection of a framework document.
A subsection is usually the level at which a standard states an individual requirement, so this is the endpoint to use when you want to show which rules cover a specific clause.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/openlayer/resources/governance/frameworks/subsections.rb', line 39 def list_rules(subsection_id, params) parsed, = Openlayer::Governance::Frameworks::SubsectionListRulesParams.dump_request(params) query = Openlayer::Internal::Util.encode_query_params(parsed) framework_id = parsed.delete(:framework_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["frameworks/%1$s/subsections/%2$s/rules", framework_id, subsection_id], query: query.transform_keys( include_results: "includeResults", per_page: "perPage", project_id: "projectId" ), model: Openlayer::Models::Governance::Frameworks::SubsectionListRulesResponse, options: ) end |